<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\Components;

use Nette\Application\UI\Control;
use DK\Menu\UI\IControlFactory;
use App\CoreModule\Model\ModuleManager;

/**
 * Komponenta pro vykreslení menu v administraci
 * @package App\Components
 *  
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AdminMenuControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE_PATH = '/../templates/components/AdminMenu/';

    /** @var  IControlFactory */
    private $menuFactory;
    
    /** @var ModuleManager Instance třídy modelu pro práci s moduly. */
    private $moduleManager;

    public function __construct(IControlFactory $menuFactory, ModuleManager $moduleManager)
    {
        $this->menuFactory = $menuFactory;
        $this->moduleManager = $moduleManager;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE_PATH . 'menu.latte');
        $this->template->menu = $this['adminMenu']->getMenu();
        
        $this->template->modulManager = $this->moduleManager;
        
        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Vytváří komponentu, která sestavuje admin menu z menu.neon souborů v jednotlivých modulech
     * @return \DK\Menu\UI\Control
     */
    protected function createComponentAdminMenu()
    {
        return $this->menuFactory->create();
    }


}

/**
 * Interface pro vytvoření pomocné komponenty (AdminMenu) pro vykreslování menu
 * @package App\Components
 */
interface IAdminMenuFactory {

    /**
     * @return AdminMenuControl komponenta pro vykreslování admin menu
     */
    public function create();
}
