<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\Forms;

use App\Model\Enum\MessageType;
use App\Presenters\BasePresenter;
use Nette\Application\UI\Form;
use Nette\Localization\ITranslator;
use Nette\Object;

/**
 * Továrnička na formuláře se společným nastavením.
 * @package App\Forms
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class BaseFormFactory extends Object {

    /**
     * @var ITranslator
     */
    protected $translator;

    /**
     * BaseFormFactory constructor.
     * @param ITranslator $translator
     */
    function __construct(ITranslator $translator) {
        $this->translator = $translator;
    }

    /**
     * @return Form
     */
    public function create() {
        $form = new Form;
        $form->setTranslator($this->translator);
        $form->onError[] = [$this, 'formError'];
        return $form;
    }

    /**
     * Převádí výpis chyb validace formuláře na zprávy na stránce.
     * @param Form $form formulář ze kterého chyby pochází
     */
    public function formError($form) {
        $errors = $form->getErrors();
        $presenter = $form->getPresenter();

        if ($presenter)
            foreach ($errors as $error)
                $presenter->flashMessage($error, MessageType::ERROR);
    }

}
