<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\BlogModule\Components;

use Ublaboo\DataGrid\DataGrid;
use Nette\Application\UI\Control;
use App\BlogModule\Model\ArticleManager;
use App\Model\Enum\MessageType;

/**
 * Komponenta datagridu pro správu článků
 * @package App\BlogModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class ArticleDataGridControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../../../templates/components/DataGrids/dataGrid.latte';
    const TEMPLATE_FB_COL = __DIR__ . '/../templates/components/DataGrids/ArticleDataGrid/facebook.latte';

    /** @var ArticleManager Instance třídy modelu pro práci se stránkami. */
    private $articleManager;

    /**
     * Konstruktor s injectovanými třídami modelu pro práci se stránkami
     * @param ArticleManager     $articleManager   automaticky injektovaná třída modelu pro práci se stránkami
     */
    public function __construct(ArticleManager $articleManager) {
        parent::__construct();
        $this->articleManager = $articleManager;
    }

    /** Vykreslí komponentu formuláře pro správu osob. */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);

        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentDataGrid($name) {
        $grid = new DataGrid($this, $name);
        $grid->setTranslator($this->presenter->translator);
        $grid->setPrimaryKey('url');

        $grid->setDataSource($this->articleManager->getTable());

        $grid->addColumnText('title', 'blog.article.datagrid.column-name')
                ->setSortable();

        $grid->addColumnNumber('url', 'blog.article.datagrid.column-url')
                ->setSortable();

        $grid->addColumnDateTime('date', 'blog.article.datagrid.column-date')
                ->setFormat('d.m.Y H:i')
                ->setSortable();

        /**
         * Odkaz na editaci
         */
        $grid->addColumnText('share', 'blog.article.datagrid.share')
                ->setTemplate(self::TEMPLATE_FB_COL, []);

        $grid->addAction('edit', '', ':Blog:Article:editor')
                ->setIcon('pencil');

        /**
         * Mazani
         */
        $grid->addAction('delete', '', 'deleteArticle!')
                ->setIcon('trash')
                ->setTitle('blog.article.datagrid.action-delete')
                ->setClass('btn btn-xs btn-danger ajax')
                ->setConfirm('blog.article.datagrid.action-delete-confirm', 'title');

        // Tlačítko pro vložení nového článku
        $grid->addToolbarButton(':Blog:Article:editor', 'blog.article.new-article')
                ->setClass('btn btn-xs btn-default');

        return $grid;
    }

    public function handleDeleteArticle($url) {
        $this->articleManager->removeArticle($url);
        // Zaznamení akce do DB
        $this->presenter->logAction('Odstranění článku s url - ' . $url);
        $this->presenter->flashMessage($this->presenter->translator->translate('blog.article.flashes.deleted-success', ['url' => $url]), MessageType::SUCCESS);
        if ($this->presenter->isAjax()) {
            $this->presenter->redrawControl('ajaxNotification');
            $this['dataGrid']->reload();
        } else {
            $this->presenter->redirect('this');
        }
    }

}

interface IArticleDataGridFactory {

    /**
     * @return ArticleDataGridControl
     */
    public function create();
}
