<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\BlogModule\Components;

use App\BlogModule\Model\CategoryManager;
use App\Forms\BaseFormFactory;
use App\Model\Enum\MessageType;
use Nette\Application\Responses\JsonResponse;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Database\Table\ActiveRow;
use Nette\Database\UniqueConstraintViolationException;
use Nette\Utils\ArrayHash;
use Nette\Utils\Json;

/**
 * Komponenta pro vytváření kategorií pro články
 * @package App\BlogModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class CategoryEditorFormControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE_PATH = '/../templates/components/CategoryEditorForm/';

    /**
     * @var CategoryManager
     */
    private $categoryManager;

    /**
     * @var BaseFormFactory
     */
    private $baseFormFactory;

    /**
     * @param CategoryManager $categoryManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(CategoryManager $categoryManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->categoryManager = $categoryManager;
        $this->baseFormFactory = $baseFormFactory;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render($formPath = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE_PATH . 'form.latte');
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentCategoryEditorForm() {
        $form = $this->baseFormFactory->create();
        $form->addText('output');
        $form->addSubmit('submit');

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    public function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();
        try {
            if (($categories = Json::decode($values->output, Json::FORCE_ARRAY)) && $this->categoryManager->saveCategories($categories)) {
                // Zaznamení akce do DB
                $presenter->logAction('Změna v kategorií v blogu');
                $presenter->flashMessage($this->presenter->translator->translate('blog.category.flashes.saved-success'), MessageType::SUCCESS);
            } else {
                $presenter->flashMessage($this->presenter->translator->translate('blog.category.flashes.saved-fail'), MessageType::ERROR);
            }
        } catch (UniqueConstraintViolationException $ex) {
            $presenter->flashMessage($this->presenter->translator->translate('blog.category.flashes.constraint-violation'), MessageType::ERROR);
        }
        $presenter->redirect('this');
    }

    public function setDefaults(array $values) {
        $this['categoryEditorForm']->setDefaults($values);
    }

    /** Vrací JSON s kategoriemi. */
    public function handleGetJson() {
        $categoriesArray = [];

        $categories = $this->categoryManager->getAllCategories();

        array_walk($categories, function (ActiveRow $category) use (&$categoriesArray) {
            $categoriesArray[] = $category->toArray();
        });

        $this->presenter->sendResponse(new JsonResponse($categoriesArray));
    }

}

/**
 * Interface ICategoryEditorFormFactory
 * @package App\BlogModule\Components
 */
interface ICategoryEditorFormFactory {

    /**
     * @return CategoryEditorFormControl
     */
    public function create();
}
