<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\BlogModule\Presenters;

use App\BlogModule\Components\IArticleDataGridFactory;
use App\BlogModule\Components\IArticleFormFactory;
use App\BlogModule\Model\ArticleManager;
use App\BlogModule\Model\CategoryManager;
use App\MediaModule\Components\IImagesFactory;
use App\MediaModule\Components\IUploadFormFactory;
use App\MediaModule\Components\UploadFormControl;

/*
 * @resourceDescription Zpracovává vykreslování článků.
 * @package App\BlogModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */

class ArticlePresenter extends BaseBlogPresenter
{

    /**
     * @var ArticleManager
     */
    private $articleManager;

    /**
     * @var CategoryManager
     */
    private $categoryManager;

    /**
     * @var IUploadFormFactory
     */
    private $uploadFormFactory;

    /**
     * @var IImagesFactory
     */
    private $imagesFactory;

    /**
     * @var IArticleFormFactory
     */
    private $articleFormFactory;

    /**
     * @var IArticleDataGridFactory
     */
    private $articleDataGridFactory;

    public function __construct(
        ArticleManager $articleManager,
        CategoryManager $categoryManager,
        IUploadFormFactory $uploadFormFactory,
        IImagesFactory $imagesFactory,
        IArticleFormFactory $articleFormFactory,
        IArticleDataGridFactory $articleDataGridFactory
    )
    {
        parent::__construct();
        $this->articleManager = $articleManager;
        $this->categoryManager = $categoryManager;
        $this->uploadFormFactory = $uploadFormFactory;
        $this->imagesFactory = $imagesFactory;
        $this->articleFormFactory = $articleFormFactory;
        $this->articleDataGridFactory = $articleDataGridFactory;
    }

    /**
     * @actionName manage
     * @actionDescription Vykreslí seznam článků do šablony administrace
     */
    public function renderManage()
    {
        $this->setLayout('layoutBackend');
        $this->template->articles = $this->articleManager->getArticles();
    }

    public function renderEditor($url)
    {
        $this->setLayout('layoutBackend');
        $this->template->title = $url ? $this->translator->translate('blog.article.edit-article') : $this->translator->translate('blog.article.new-article');
    }

    /**
     * @actionName editor
     * @actionDescription Vykresluje editaci článku podle jeho URL.
     * @param string $url URL adresa článku, který editujeme, pokud není zadána, vytvoří se nový
     */
    public function actionEditor($url)
    {
        // Pokud byla zadána URL, pokusí se článek načíst a předat jeho hodnoty do editačního formuláře, jinak vypíše chybovou hlášku.
        if ($url && ($article = $this->articleManager->getArticle($url))) {
            // IRow je read-only, pro manipulaci s ním ho musíme převést na pole.
            $articlesArray = $article->toArray();
            $articlesArray['categories'] = $this->categoryManager->getArticleCategories($article->article_id);
            // Nastavení hodnot do formuláře
            $this['articleForm']->setDefaults($articlesArray);
            $this->template->article = $article;
        }
    }

    /**
     * @return \App\MediaModule\Components\ImagesControl
     */
    protected function createComponentImages()
    {
        return $this->imagesFactory->create();
    }

    /**
     * @return UploadFormControl
     */
    protected function createComponentUploadForm()
    {
        return $this->uploadFormFactory->create();
    }

    /**
     * @return \App\BlogModule\Components\ArticleFormControl
     */
    protected function createComponentArticleForm()
    {
        return $this->articleFormFactory->create();
    }

    /**
     * @return \App\BlogModule\Components\ArticleDataGridControl
     */
    protected function createComponentArticleDataGrid()
    {
        return $this->articleDataGridFactory->create();
    }

}
