<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CmsModule\Components;

use App\CmsModule\Model\PageManager;
use App\EshopModule\Model\ProductManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use App\Forms\BaseFormFactory;
use Nette\Utils\ArrayHash;
use Nette\Utils\Image;

/**
 * Class PageFormControl
 * @package App\CmsModule\Components
 */
class PageFormControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/PageForm/form.latte';

    /** @var BaseFormFactory Továrnička na formuláře. */
    private $formFactory;

    /**
     * @var PageManager
     */
    private $pageManager;

    /**
     * @var ProductManager
     */
    private $productManager;

    /** Cesta k obrázkům site. */
    const IMAGES_PATH = 'images/pages/';

    /**
     * ContactFormControl constructor.
     * @param BaseFormFactory $formFactory
     */
    public function __construct(BaseFormFactory $formFactory, PageManager $pageManager, ProductManager $productManager) {
        parent::__construct();
        $this->formFactory = $formFactory;
        $this->pageManager = $pageManager;
        $this->productManager = $productManager;
    }

    public function render($formPath = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    public function setDefaults(array $values) {
        $this['pageForm']->setDefaults($values);
    }

    public function createComponentPageForm() {
        $form = $this->formFactory->create();
        $form->addHidden(PageManager::COLUMN_ID);
        $form->addText(PageManager::COLUMN_TITLE, 'page.page.form.title')
                ->setRequired()
                ->getControlPrototype()
                ->addClass('form-control');
        $form->addText(PageManager::COLUMN_URL, 'page.page.form.url')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText(PageManager::COLUMN_SLOGAN, 'page.page.form.slogan')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addSelect(PageManager::COLUMN_TYPE, 'page.page.form.content-type', [
                    'page' => 'page.page.form.types.page',
                    'link' => 'page.page.form.types.link'
                ])
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('template', 'page.page.form.template')
                ->getControlPrototype()
                ->addClass('form-control');

        $productsArray = [];
        $products = $this->productManager->getProducts();
        foreach ($products as $product) {
            $productsArray[$product->{ProductManager::COLUMN_ID}] = $product->{ProductManager::COLUMN_TITLE};
        }

        $form->addSelect(PageManager::COLUMN_PRODUCT, 'page.page.form.product', $productsArray)->setPrompt("--- Žádný ----");

        $form->addSelect(PageManager::COLUMN_PARENT, 'page.page.form.parent', $this->pageManager->getPagesToSelect())->setPrompt("--- Žádná ----");

        $form->addTextarea('perex', 'page.page.form.perex')
                ->getControlPrototype()
                ->addClass('ckeditor')
                ->addClass('form-control');
        $form->addTextarea('content', 'page.page.form.content')
                ->getControlPrototype()
                ->addClass('ckeditor')
                ->addClass('form-control');

        $form->addText('seo_title', 'page.page.form.meta-title')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('seo_description', 'page.page.form.meta-description')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('seo_keywords', 'page.page.form.meta-keywords')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addUpload('listing_image', 'page.page.form.image')
                ->setAttribute('accept', 'image/*')
                ->addRule(Form::IMAGE, 'eshop.common.patterns.images')
                ->addRule(Form::MAX_FILE_SIZE, 'eshop.common.patterns.imageSize', 1024 * 1024 /* v bytech */)
                ->setRequired(FALSE);

        $form->addText('position', 'page.page.form.position')
                ->setRequired(FALSE)
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addCheckbox('menu', 'page.page.form.menu')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addSubmit('submit', 'page.page.form.submit')
                ->setAttribute('id', 'pageSubmit')
                ->getControlPrototype();

        $form->getComponent('submit')
                ->getControlPrototype()
                ->onclick('tinyMCE.triggerSave()');

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->successed($form, $values);
        };

        return $form;
    }

    private function successed(Form $form, ArrayHash $values) {
        // Přepiínač, jeslti stránku vytvářím - nejde to jinak poznat, protože ve values id vždy něco bude
        $create = true;
        if (isset($values->listing_image) && $values->listing_image->hasFile()) {
            $listing_image = $values->listing_image->toImage();
        }

        $presenter = $form->getPresenter();
        $values->offsetUnset('listing_image');

        if (!$values->id) {
            // Když není vyplněné ID - musím z nějakých důvodů unsetnout id, uložit stránku a protože ID zase potřebuji, tak ho setnout zpět
            $page = $this->pageManager->savePage($values);
            $pageId = $page->id;
            $values->id = $pageId;
            // Zaznamení akce do DB
            $presenter->logAction('Vytvoření nové stránky - ' . $values[PageManager::COLUMN_TITLE]);
        } else {
            $pageId = $values->id;
            $create = false;
            // Zaznamení akce do DB
            $presenter->logAction('Editace stránky - ' . $values[PageManager::COLUMN_TITLE]);
        }

        if (isset($listing_image)) {
            $listing_image->save(self::IMAGES_PATH . $pageId . '_0.png', null, Image::PNG);
            $values->listing_image = self::IMAGES_PATH . $pageId . '_0.png';
        }

        // Tady se stránka neukládá znovu, ale jen upravuje - pro obrázky potřebuji Id stránky
        $this->pageManager->savePage($values);

        // Zpráva o úspěchu
        $presenter->flashMessage($presenter->translator->translate('page.page.flashes.saved-success'), MessageType::SUCCESS);

        // Pokud je to ajax, budu testovat, jestli stránku vztvářím, nebo edituji a podle toho přesměrovávám nebo překresluji komponenty
        if ($presenter->isAjax()) {
            // Pokud stránku nevytvářím, ale edituji - překresluji komponenty
            if (!$create) {
                $presenter->redrawControl("ajaxNotification");
            } else { // Pokdu stránku vytvářím, je potřeba redirect
                $presenter->redirect("Page:edit", array("id" => $pageId));
            }
        } else { // Pokud to není ajax, redirectuji
            $presenter->redirect("Page:edit", array("id" => $pageId));
        }
    }

}

/**
 * Interface IPageFormFactory
 * @package App\CmsModule\Components
 */
interface IPageFormFactory {

    /**
     * @return PageFormControl
     */
    public function create();
}
