<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CmsModule\Presenters;

use App\CmsModule\Components\IPageDataGridFactory;
use App\CmsModule\Components\IPageFormFactory;
use App\CmsModule\Components\PageDataGridControl;
use App\CmsModule\Model\PageManager;
use App\MediaModule\Components\IImagesFactory;
use App\MediaModule\Components\ImagesControl;
use App\MediaModule\Components\IUploadFormFactory;
use Codeception\PHPUnit\Constraint\Page;

/**
 * @resourceDescription Zpracovává požadavky na správu webových stránek
 * @package App\CmsModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class PagePresenter extends BaseCmsPresenter
{

    /** Konstanta s hodnotou URL výchozího článku. */
    const DEFAULT_PAGE_URL = '';

    /**
     * @var PageManager
     */
    private $pageManager;

    /**
     * @var IUploadFormFactory
     */
    private $uploadFormFactory;

    /**
     * @var IImagesFactory
     */
    private $imagesFactory;

    /**
     * @var IPageDataGridFactory
     */
    private $pageDataGridFactory;

    /**
     * @var IPageFormFactory
     */
    private $pageFormFactory;

    public function __construct(PageManager $pageManager, IUploadFormFactory $uploadFormFactory, IImagesFactory $imagesFactory, IPageDataGridFactory $pageDataGridFactory, IPageFormFactory $pageFormFactory)
    {
        parent::__construct();
        $this->pageManager = $pageManager;
        $this->uploadFormFactory = $uploadFormFactory;
        $this->imagesFactory = $imagesFactory;
        $this->pageDataGridFactory = $pageDataGridFactory;
        $this->pageFormFactory = $pageFormFactory;
    }

    /**
     * Většina akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender()
    {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName manage
     * @actionDescription Vykresluje přehled všech vytvořených webových stránek
     */
    public function renderManage()
    {
    }

    /**
     * @actionName edit
     * @actionDescription Akce pro tvorbu, případně editaci webové stránky
     * @param int $id id webové stránky, pokud není zadáno, bude vytvářet nová, jinak se edituje
     */
    public function actionEdit($id = null)
    {
        $this->setLayout('layoutBackend');
        $page = $this->pageManager->getPageById($id);
        $this->template->currPage = $page;
        if ($page) {
            $this['pageForm']->setDefaults($page->toArray());
        }
    }

    /**
     * Create datagrid for Pages
     * @return PageDataGridControl
     */
    protected function createComponentPageDataGrid()
    {
        return $this->pageDataGridFactory->create();
    }

    /**
     * @return \App\CmsModule\Components\PageFormControl
     */
    protected function createComponentPageForm()
    {
        return $this->pageFormFactory->create();
    }

    /**
     * @return ImagesControl
     */
    protected function createComponentImages()
    {
        return $this->imagesFactory->create();
    }

    /**
     * @return \App\MediaModule\Components\UploadFormControl
     */
    protected function createComponentUploadForm()
    {
        return $this->uploadFormFactory->create();
    }

}
