<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Components\Charts;

use App\EshopModule\Model\OrderManager;
use App\EshopModule\Model\DiscountLevelsManager;
use App\EshopModule\Model\CurrencyManager;
use App\EshopModule\Model\SettingsManager;
use Nette\Application\UI\Control;
use App\Services\FormatHelperService;

/**
 * Komponenta pro vykreslení headeru stránky
 * @package App\CoreModule\Components\Charts
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class SalesDashboardChartControl extends Control {

    const TEMPLATE_PATH = '/../../templates/components/Charts/SalesDashboardChartControl/';

    /**
     * @var OrderManager 
     */
    private $orderManager;

    /**
     * @var DiscountLevelsManager 
     */
    private $discountLevelsManager;

    /**
     * @var CurrencyManager 
     */
    private $currencyManager;

    /**
     * @var SettingsManager
     */
    private $settingsManager;

    /**
     * @var FormatHelperService Pomocná služba pro formátování data, jména adresy atd.
     */
    private $formatHelperService;

    public function __construct(OrderManager $orderManager, DiscountLevelsManager $discountLevelsManager, CurrencyManager $currencyManager, SettingsManager $settingsManager, FormatHelperService $formatHelperService) {
        parent::__construct();
        $this->orderManager = $orderManager;
        $this->discountLevelsManager = $discountLevelsManager;
        $this->currencyManager = $currencyManager;
        $this->settingsManager = $settingsManager;
        $this->formatHelperService = $formatHelperService;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render() {
        // Nastaví šablonu komponenty
        $this->template->setFile(__DIR__ . self::TEMPLATE_PATH . 'chart.latte');

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Metoda, která získá data pro graf v dashboardu přes Json
     */
    public function handleGetMonthData() {
        $months = array();
        $sales = array();
        $monthsNames = $this->formatHelperService->getChartMonths();

        // Získám číslá posledních 6 měsíců včetně tohoto měsíce
        for ($i = 0; $i < 12; $i++) {
            // Jméno měsíce
            $monthNum = date('n', strtotime("-$i month"));
            
            $monthSales = $this->getTotalMonthSales($monthNum);

            if($monthSales > 0){
                // Přidání do pole pokud jsou tržby větší než 0
                array_push($months, $monthsNames[$monthNum - 1]);
                array_push($sales, $this->getTotalMonthSales($monthNum));
            }
        }

        // Odeslání dat - data předám v opačném pořadí, pro lepší přehlednost výpisu
        $this->presenter->sendJson([
            'labels' => array_reverse($months),
            'series' => [
                ['name' => 'series1', 'data' => array_reverse($sales)],
        ]]);
    }

    /**
     * Pomocná funkce pro vrácení celkové tržby v daném měsící
     * @param int $monthNum číslo měsíce, pro který se bude počítat celková tržba
     * @return inte celková tržba v měsíci
     */
    public function getTotalMonthSales($monthNum) {
        // Součet tržeb pro jednotlivé měsíce
        $totalSales = 0;

        // Získání všech objednávek pro daný měsíc
        $orderThisMonth = $this->orderManager->getOrdersFromMonth($monthNum);

        // Tržby pro daný měsíc
        foreach ($orderThisMonth as $actualOrder) {
            $totalSales += $this->orderManager->getOrderSummary($actualOrder[OrderManager::COLUMN_ID], FALSE)[OrderManager::ATTR_PRICE];
        }

        // Vracím celkové tržby pro daný měsíc s i DPH a měnou, která je dafaultní
        return $this->discountLevelsManager->calculatePrice($totalSales, $this->currencyManager->getDefaultCurrency(), $this->settingsManager->getSettings(), null, null);
    }

}

/**
 * Interface ISalesDashboardChartFactory
 * @package App\CoreModule\Components\Charts
 */
interface ISalesDashboardChartFactory {

    /**
     * @return SalesDashboardChartControl
     */
    public function create();
}
