<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Components\DataGrids;

use App\Model\UserManager;
use App\Model\UserLogManager;
use Ublaboo\DataGrid\DataGrid;
use Nette\Application\UI\Control;

/**
 * Komponenta datagridu pro správu záznamů uživatelských loginů
 * @package App\CoreModule\Components\DataGrids
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class LoginLogDatagridControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../../../../templates/components/DataGrids/dataGrid.latte';

    /** @var UserLogManager Instance třídy modelu pro ukládání přihlašovacích logů do db. */
    private $userLogManager;

    /**
     * Konstruktor s injectovanými třídami modelu pro uživatelskými logy
     * @param UserLogManager $userLogManager  třída modelu pro práci s uživatelskými logy
     */
    public function __construct(UserLogManager $userLogManager) {
        parent::__construct();

        $this->userLogManager = $userLogManager;
    }

    /** Vykreslí komponentu formuláře pro správu osob. */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);

        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentDataGrid($name) {

        $grid = new DataGrid($this, $name);

        /** Localization */
        $grid->setTranslator($this->presenter->translator);

        $grid->setPrimaryKey(UserLogManager::COLUMN_ID);
        // Dotaz na vsechny logy uživatelských akcí, které  jsou logovány ve spojení s údaji od uživatele.
        $grid->setDataSource($this->getDataSource());
        // Uživatelův login
        $grid->addColumnText(UserManager::COLUMN_NAME, 'core.administration.login.loginName')
                ->setSortable();
        $grid->addFilterText(UserManager::COLUMN_NAME, 'core.administration.login.loginName');
        // Datum
        $grid->addColumnDateTime(UserLogManager::COLUMN_DATE, 'eshop.order.management.date')
                ->setFormat('d.m.Y H:i')
                ->setSortable()
                ->setFilterDate();

        return $grid;
    }

    /**
     * Pomocná funkce pro získání dat dat do datagridu
     * @return Selection vrací všechny uživatelské logy přihlášení spojené s údaji pro uživatele
     */
    private function getDataSource() {
        return $this->userLogManager->getLoginTable()
                        ->select('*')
                        ->where(UserManager::TABLE_NAME . '.' . UserManager::COLUMN_ID)
                        ->order(UserLogManager::COLUMN_DATE . ' DESC')
                        ->fetchAll();
    }

}

/**
 * Interface ILoginLogDataGridFactory
 * @package App\CoreModule\Components\DataGrids
 */
interface ILoginLogDataGridFactory {

    /**
     * @return LoginLogDatagridControl
     */
    public function create();
}
