<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Components\Forms;

use App\CoreModule\Model\EmailSettingsManager;
use App\Forms\BaseFormFactory;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Database\UniqueConstraintViolationException;
use Nette\Utils\ArrayHash;

/**
 * Class EmailSettingsFormControl
 * @package App\CoreModule\Components\Forms
 */
class EmailSettingsFormControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE_PATH = '/../../templates/components/Forms/EmailSettingsForm/';

    /**
     * @var EmailSettingsManager
     */
    private $emailSettingsManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * EmailSettingsFormControl constructor.
     * @param EmailSettingsManager $emailSettingsManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(EmailSettingsManager $emailSettingsManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->emailSettingsManager = $emailSettingsManager;
        $this->formFactory = $baseFormFactory;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render($formPath = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE_PATH . 'form.latte');
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentEmailSettingsForm() {
        $form = $this->formFactory->create();
        $form->addHidden(EmailSettingsManager::COLUMN_ID);
        $form->addSelect('email_type', 'core.email.form.choose-type', $this->emailSettingsManager->getEmailTypes());
        $form->addText('email', 'core.email.form.email')
                ->setType('email')
                ->setRequired()
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addSubmit('submit', 'core.email.form.submit')
                ->getControlPrototype();

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    public function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();

        try {
            if($email = $this->emailSettingsManager->saveValues(EmailSettingsManager::TABLE_NAME, EmailSettingsManager::COLUMN_ID, $values)){
                // Zaznamení akce do DB
                $presenter->logAction('Nové nastavení e-mailu - ' . $values[EmailSettingsManager::COLUMN_EMAIL_TYPE]);
                $presenter->flashMessage($this->presenter->translator->translate('core.email.flashes.saved-success'), MessageType::SUCCESS);
            }else{
                $presenter->flashMessage($this->presenter->translator->translate('core.email.flashes.saved-error'), MessageType::ERROR);
            }
        } catch (UniqueConstraintViolationException $ex) {
            $presenter->flashMessage($this->presenter->translator->translate('core.email.flashes.constraint-violation'), MessageType::ERROR);
        }

        if ($presenter->isAjax()) {
            $presenter->redrawControl('ajaxNotification');
            $presenter->redrawControl("emailSettingsSnippet");
            $presenter->redrawControl("emailSettingsForm");
        } else {
            $presenter->redirect("EmailSettings:default");
        }
    }

    public function setDefaults(array $values) {
        $this['emailSettingsForm']->setDefaults($values);
    }

}

/**
 * Interface IEmailSettingsFormFactory
 * @package App\CoreModule\Components\Forms
 */
interface IEmailSettingsFormFactory {

    /**
     * @return EmailSettingsFormControl
     */
    public function create();
}
