<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Components\Forms;

use App\CoreModule\Model\PartnerManager;
use App\Forms\BaseFormFactory;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use Nette\Utils\Image;

/**
 * Class PartnerFormControl
 * @package App\CoreModule\Components\Forms
 */
class PartnerFormControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE_PATH = '/../../templates/components/Forms/PartnerForm/';

    /**
     * @var PartnerManager
     */
    private $partnerManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /** Images path */
    const IMAGES_PATH = 'uploads/partner/';

    /**
     * ArticleFormControl constructor.
     * @param PartnerManager $partnerManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(PartnerManager $partnerManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->partnerManager = $partnerManager;
        $this->formFactory = $baseFormFactory;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render($formPath = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE_PATH . 'form.latte');
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentPartnerForm() {
        $form = $this->formFactory->create();
        $form->setTranslator($this->presenter->translator);
        $form->addHidden(PartnerManager::COLUMN_ID);
        $form->addText(PartnerManager::COLUMN_TITLE, 'core.partner.form.title')
                ->setRequired()
                ->getControlPrototype()
                ->addClass('form-control');
        $form->addText(PartnerManager::COLUMN_URL, 'core.partner.form.url')
                ->setRequired()
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addUpload('image', 'core.partner.form.image')
                ->setAttribute('accept', 'image/*')
                ->addRule(Form::IMAGE, 'eshop.common.patterns.images')
                ->addRule(Form::MAX_FILE_SIZE, 'eshop.common.patterns.imageSize', 1024 * 1024 /* v bytech */)
                ->setRequired(FALSE);


        $form->addSubmit('submit', 'core.partner.form.submit')
                ->getControlPrototype();

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    public function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();
        
        if ($values->image->hasFile()) {
            $image = $values->image->toImage();
        }
        
        $values->offsetUnset('image');
        $values->offsetSet('position', 0);
        $partnerId = $this->partnerManager->saveValues(PartnerManager::TABLE_NAME, PartnerManager::COLUMN_ID, $values)[PartnerManager::COLUMN_ID];

        if (isset($image)) {
            if (!isset($values->id)) {
                $values->id = $partnerId;
            }
            $image->save(self::IMAGES_PATH . $partnerId . '_0.png', null, Image::PNG);
            $values->image = self::IMAGES_PATH . $partnerId . '_0.png';
            $this->partnerManager->saveValues(PartnerManager::TABLE_NAME, PartnerManager::COLUMN_ID, $values)[PartnerManager::COLUMN_ID];
        }
        
        // Zaznamení akce do DB
        $presenter->logAction('Editace/Vytvoření partnera - ' . $values[PartnerManager::COLUMN_TITLE]);

        $presenter->flashMessage($this->presenter->translator->translate('core.partner.flashes.saved-success'), MessageType::SUCCESS);

        if ($this->presenter->isAjax()) {
            $presenter->redrawControl('ajaxNotification');
            $presenter->redrawControl("partnerSnippet");
            $presenter->redrawControl("partnerForm");
        } else {
            $presenter->redirect("Partner:default");
        }
    }

    public function setDefaults(array $values) {
        $this['partnerForm']->setDefaults($values);
    }

}

/**
 * Interface IPartnerFormFactory
 * @package App\CoreModule\Components\Forms
 */
interface IPartnerFormFactory {

    /**
     * @return PartnerFormControl
     */
    public function create();
}
