<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Components\Forms;

use App\CoreModule\Model\SocialManager;
use App\Forms\BaseFormFactory;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use Nette\Utils\Image;

/**
 * Class SocialFormControl
 * @package App\CoreModule\Components\Forms
 */
class SocialFormControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE_PATH = '/../../templates/components/Forms/SocialForm/';

    /**
     * @var SocialManager
     */
    private $socialManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /** Images path */
    const IMAGES_PATH = 'uploads/social/';

    /**
     * SocialFormControl constructor.
     * @param SocialManager $socialManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(SocialManager $socialManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->socialManager = $socialManager;
        $this->formFactory = $baseFormFactory;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render($formPath = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE_PATH . 'form.latte');
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentSocialForm() {
        $form = $this->formFactory->create();
        $form->addHidden(SocialManager::COLUMN_ID);
        $form->addText(SocialManager::COLUMN_TITLE, 'core.social.form.title')
                ->setRequired()
                ->getControlPrototype()
                ->addClass('form-control');
        $form->addText(SocialManager::COLUMN_URL, 'core.social.form.url')
                ->setRequired()
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addUpload('image', 'core.social.form.image')
                ->setAttribute('accept', 'image/*')
                ->addRule(Form::IMAGE, 'eshop.common.patterns.images')
                ->addRule(Form::MAX_FILE_SIZE, 'eshop.common.patterns.imageSize', 1024 * 1024 /* v bytech */)
                ->setRequired(FALSE);


        $form->addSubmit('submit', 'core.social.form.submit')
                ->getControlPrototype();

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    public function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();
        
        if ($values->image->hasFile()) {
            $image = $values->image->toImage();
        }
        
        $values->offsetUnset('image');
        $values->offsetSet('position', 0);
        
        $socialId = $this->socialManager->saveValues(SocialManager::TABLE_NAME, SocialManager::COLUMN_ID, $values)[SocialManager::COLUMN_ID];

        if (isset($image)) {
            if (!isset($values->id)) {
                $values->id = $socialId;
            }
            
            $image->save(self::IMAGES_PATH . $socialId . '_0.png', null, Image::PNG);
            $values->image = self::IMAGES_PATH . $socialId . '_0.png';
            $this->socialManager->saveValues(SocialManager::TABLE_NAME, SocialManager::COLUMN_ID, $values)[SocialManager::COLUMN_ID];
        }
        
        // Zaznamení akce do DB
        $presenter->logAction('Editace/Vytvoření socíální sítě - ' . $values[SocialManager::COLUMN_TITLE]);

        $presenter->flashMessage($this->presenter->translator->translate('core.social.flashes.saved-success'), MessageType::SUCCESS);
        if ($this->presenter->isAjax()) {
            $presenter->redrawControl('ajaxNotification');
            $presenter->redrawControl("socialSnippet");
            $presenter->redrawControl("socialForm");
        } else {
            $presenter->redirect("Social:default");
        }
    }

    public function setDefaults(array $values) {
        $this['socialForm']->setDefaults($values);
    }

}

/**
 * Interface ISocialFormFactory
 * @package App\CoreModule\Components\Forms
 */
interface ISocialFormFactory {

    /**
     * @return SocialFormControl
     */
    public function create();
}
