<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Model;

use App\Model\BaseManager;
use Nette\Database\Table\Selection;
use Nette\InvalidStateException;

/**
 * Třída poskytuje metody pro správu uživatelských rolí.
 * @package App\CoreModule\Model
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class UserRoleManager extends BaseManager {

    /** Konstanty pro tabulku resource. */
    const
            TABLE_NAME_RESOURCE = 'resource',
            COLUMN_RESOURCE_ID = 'resource_id',
            COLUMN_RESOURCE_NAME = 'resource_name',
            COLUMN_RESOURCE_DESRCIPTION = 'resource_description';

    /** Konstanty pro tabulku action. */
    const
            TABLE_ACTION_NAME = 'action',
            COLUMN_ACTION_ID = 'action_id',
            COLUMN_ACTION_NAME = 'action_name',
            COLUMN_ACTION_DESRCIPTION = 'action_description';

    /** Konstanty pro tabulku role. */
    const
            TABLE_ROLE_NAME = 'role',
            COLUMN_ROLE_ID = 'role_id',
            COLUMN_ROLE_NAME = 'role_name',
            COLUMN_ROLE_SLUG = 'role_slug',
            COLUMN_ROLE_DESRCIPTION = 'role_description';

    /*     * Konstanty pro práci s rolemi */
    const
            ROLE_TYPE_ADMIN = 'admin',
            ROLE_TYPE_SUPERADMIN = 'superadmin',
            ROLE_TYPE_GUEST = 'guest';

    /**
     * Aktualizuje akce pro roli, které budou povoleny
     * @param int $roleId    ID role, která se edituje
     * @param array $actions ID akcí, do kterých bude mít role přístup
     */
    public function updateRolePermission($roleId, $resources, $actions) {
        $this->database->table(self::TABLE_ROLE_NAME . '_' . self::TABLE_ACTION_NAME)
                ->where(self::COLUMN_ROLE_ID, $roleId)->delete();

        $rows = array();

        foreach ($actions as $actionId) {
            $action = $this->getById(self::TABLE_ACTION_NAME, self::COLUMN_ACTION_ID, $actionId);

            if (in_array($action[self::COLUMN_RESOURCE_ID], $resources)) {
                $rows[] = array(
                    self::COLUMN_ROLE_ID => $roleId,
                    self::COLUMN_RESOURCE_ID => $action[self::COLUMN_RESOURCE_ID],
                    self::COLUMN_ACTION_ID => $actionId
                );
            } else {
                throw new InvalidStateException('Některý ze zdrojů pro povolené akce nebyl povolen.');
            }
        }

        if(!empty($rows)){
            $this->database->table(self::TABLE_ROLE_NAME . '_' . self::TABLE_ACTION_NAME)->insert($rows);
        }
    }

    /**
     * Vrací role pro formulář - do datagridu, kde můžu setovat uživateli roli - nastavuji mu v tabulce user slug role
     * Role guest musí existovat, ale nechci ji setovat, vybírám vše kromě ní
     * @return array Vracím pole klíčů a hodnot ve tvaru role_slug => role_name
     */
    public function getRolesForForm() {
        return $this->getAllRows(UserRoleManager::TABLE_ROLE_NAME)
                        ->where('NOT ' . self::COLUMN_ROLE_SLUG, self::ROLE_TYPE_GUEST)
                        ->fetchPairs(self::COLUMN_ROLE_SLUG, self::COLUMN_ROLE_NAME);
    }

}
