<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Presenters;

use App\CoreModule\Components\Forms\IEmailSettingsFormFactory;
use App\CoreModule\Model\EmailSettingsManager;
use App\Model\Enum\MessageType;

/**
 * @resourceDescription Zpracovávající nastavení emailů
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class EmailSettingsPresenter extends BaseCorePresenter
{

    /**
     * @var EmailSettingsManager
     */
    private $emailSettingsManager;

    /**
     * @var IEmailSettingsFormFactory
     */
    private $emailSettingsFormFactory;

    public function __construct(EmailSettingsManager $emailSettingsManager, IEmailSettingsFormFactory $emailSettingsFormFactory)
    {
        parent::__construct();
        $this->emailSettingsManager = $emailSettingsManager;
        $this->emailSettingsFormFactory = $emailSettingsFormFactory;
    }

    /**
     * Většina akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender()
    {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName default
     * @actionDescription Přehled vypsaných nastevení emailových adres a jejich typ
     */
    public function renderDefault()
    {
        $this->template->allEmails = $this->emailSettingsManager->getAllPublished(EmailSettingsManager::TABLE_NAME);
        $this->template->emailTypes = $this->emailSettingsManager->getEmailTypes();
    }

    /**
     * @actionName edit
     * @actionDescription Nastavení konrétní emailové adresy
     */
    public function actionEdit($id = null)
    {
        $this->setView('default');
        if ($id) {
            $email = $this->emailSettingsManager->getById(EmailSettingsManager::TABLE_NAME, EmailSettingsManager::COLUMN_ID, $id);
            $this['emailSettingsForm']->setDefaults($email->toArray());
        }
    }

    /**
     * @actionName delete
     * @actionDescription Smazání nastavené emailové adresy
     */
    public function handleDelete($id)
    {
        //$this->emailSettingsManager->clean(EmailSettingsManager::TABLE_NAME, EmailSettingsManager::COLUMN_ID, $id);

        $this->flashMessage("Email byl smazána", MessageType::SUCCESS);

        if ($this->isAjax()) {
            $this->redrawControl('ajaxNotification');
            $this->redrawControl("emailSettingsSnippet");
            $this->redrawControl("emailSettingsForm");
        } else {
            $this->redirect('this');
        }
    }

    /**
     * @return \App\CoreModule\Components\Forms\EmailSettingsFormControl
     */
    protected function createComponentEmailSettingsForm()
    {
        return $this->emailSettingsFormFactory->create();
    }

}
