<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Presenters;

use App\CoreModule\Model\ModuleManager;
use App\CoreModule\Components\DataGrids\IModuleDataGridFactory;
use App\CoreModule\Components\DataGrids\ModuleDatagridControl;

/**
 * @resourceDescription Prsenter pro práci s moduly a jejich aktivností
 * @actionName management
 * @actionDescription Přehled vytvořených modulů a jejich aktivnosti
 * 
 * @package App\CoreModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class ModulePresenter extends BaseCorePresenter {

    /**
     * @var ModuleManager Instance třídy modelu pro práci s moduly.
     */
    private $moduleManager;

    /**
     * @var IModuleDataGridFactory
     */
    private $moduleDataGridFactory;

    public function __construct(ModuleManager $moduleManager, IModuleDataGridFactory $moduleDataGridFactory)
    {
        parent::__construct();
        $this->moduleManager = $moduleManager;
        $this->moduleDataGridFactory = $moduleDataGridFactory;
    }

    /**
     * Většina akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @return ModuleDatagridControl
     */
    protected function createComponentModuleDatagrid() {
        return $this->moduleDataGridFactory->create();
    }

}
