<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Presenters;

use App\CoreModule\Components\DataGrids\IPartnerDataGridFactory;
use App\CoreModule\Components\DataGrids\PartnerDatagridControl;
use App\CoreModule\Components\Forms\IPartnerFormFactory;
use App\CoreModule\Model\PartnerManager;

/**
 * @resourceDescription Presenter pro nastavení partnerů webu.
 * @package App\CoreModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class PartnerPresenter extends BaseCorePresenter
{

    /**
     * @var PartnerManager
     */
    private $partnerManager;

    /**
     * @var IPartnerFormFactory
     */
    private $partnerFormFactory;

    /**
     * @var IPartnerDataGridFactory
     */
    private $partnerDataGridFactory;
    public $socialId;

    public function __construct(PartnerManager $partnerManager, IPartnerFormFactory $partnerFormFactory, IPartnerDataGridFactory $partnerDataGridFactory)
    {
        parent::__construct();
        $this->partnerManager = $partnerManager;
        $this->partnerFormFactory = $partnerFormFactory;
        $this->partnerDataGridFactory = $partnerDataGridFactory;
    }

    /**
     * Většina akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender()
    {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName edit
     * @actionDescription Zobrazení a zároveň i možnost nastavení partnerů společnosti
     */
    public function actionEdit($id = null)
    {
        if ($id) {
            $partner = $this->partnerManager->getById(PartnerManager::TABLE_NAME, PartnerManager::COLUMN_ID, $id);
            $this['partnerForm']->setDefaults($partner->toArray());
        }
        $this->setView('default');
    }

    /**
     * @return PartnerDatagridControl
     */
    protected function createComponentPartnerDatagrid()
    {
        return $this->partnerDataGridFactory->create();
    }

    /**
     * @return \App\CoreModule\Components\Forms\PartnerFormControl
     */
    protected function createComponentPartnerForm()
    {
        return $this->partnerFormFactory->create();
    }

}
