<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Presenters;

use App\CoreModule\Components\DataGrids\ISocialDataGridFactory;
use App\CoreModule\Components\Forms\ISocialFormFactory;
use App\CoreModule\Components\DataGrids\SocialDatagridControl;
use App\CoreModule\Model\SocialManager;

/**
 * @resourceDescription Prsenter pro nastavení sociálních sítí webu
 * @package App\CoreModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class SocialPresenter extends BaseCorePresenter {

    /**
     * @var SocialManager
     */
    private $socialManager;

    /**
     * @var ISocialFormFactory
     */
    private $socialFormFactory;

    /**
     * @var ISocialDataGridFactory
     */
    private $socialDataGridFactory;
    public $socialId;

    public function __construct(SocialManager $socialManager, ISocialFormFactory $socialFormFactory, ISocialDataGridFactory $socialDataGridFactory)
    {
        parent::__construct();
        $this->socialManager = $socialManager;
        $this->socialFormFactory = $socialFormFactory;
        $this->socialDataGridFactory = $socialDataGridFactory;
    }

    /**
     * Většina akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName edit
     * @actionDescription Zobrazení a zároveň možnost nastavení ikon pro sociální sítě
     */
    public function actionEdit($id = null) {
        if ($id) {
            $page = $this->socialManager->getById(SocialManager::TABLE_NAME, SocialManager::COLUMN_ID, $id);
            $this['socialForm']->setDefaults($page->toArray());
        }
        $this->setView('default');
    }

    /**
     * @return SocialDatagridControl
     */
    protected function createComponentSocialDatagrid() {
        return $this->socialDataGridFactory->create();
    }

    /**
     * @return \App\CoreModule\Components\Forms\SocialFormControl
     */
    protected function createComponentSocialForm() {
        return $this->socialFormFactory->create();
    }

}
