<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Presenters;

use App\CoreModule\Components\DataGrids\ActivityLogDatagridControl;
use App\CoreModule\Components\DataGrids\IActivityLogDataGridFactory;
use App\CoreModule\Components\DataGrids\LoginLogDatagridControl;
use App\CoreModule\Components\DataGrids\ILoginLogDataGridFactory;

/**
 * @resourceDescription Prsenter pro práci s užvatelskými logy
 * @actionName activityLogManagement
 * @actionDescription Přehled zaznamenaných logů od užiatelů systému
 * @actionName loginLogManagement
 * @actionDescription Přehled zaznamenaných logů uživatelského přihlášení do systému
 * 
 * @package App\CoreModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class UserLogPresenter extends BaseCorePresenter {

    /** @var IActivityLogDataGridFactory */
    private $activityLogDataGridFactory;

    /** @var ILoginLogDataGridFactory */
    private $loginLogDataGridFactory;

    public function __construct(IActivityLogDataGridFactory $activityLogDataGridFactory, ILoginLogDataGridFactory $loginLogDataGridFactory) {
        parent::__construct();
        $this->activityLogDataGridFactory = $activityLogDataGridFactory;
        $this->loginLogDataGridFactory = $loginLogDataGridFactory;
    }

    /**
     * Většina akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @return ActivityLogDatagridControl
     */
    protected function createComponentActivityLogDatagrid() {
        return $this->activityLogDataGridFactory->create();
    }

    /**
     * @return LoginLogDatagridControl
     */
    protected function createComponentLoginLogDatagrid() {
        return $this->loginLogDataGridFactory->create();
    }

}
