<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\CoreModule\Presenters;

use App\Services\RBACLoader;
use App\CoreModule\Model\UserRoleManager;
use App\CoreModule\Components\DataGrids\IUserRoleDataGridFactory;
use App\CoreModule\Components\DataGrids\UserRoleDatagridControl;
use App\CoreModule\Components\Forms\IPermissionFormFactory;
use App\CoreModule\Components\Forms\PermissionFormControl;
use App\Model\Enum\MessageType;

/**
 * @resourceDescription Prsenter pro práci s uživateli systému - nastavování rolí
 * @package App\CoreModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class UserRolePresenter extends BaseCorePresenter {

    /**
     * @var UserRoleManager Instance třídy modelu pro práci s uživateli.
     */
    private $userRoleManager;

    /**
     * @var RBACLoader Pomocná služba pro automatické načítání zdrojů a akcí z presenterů
     */
    private $rbacLoader;

    /**
     * @var IUserRoleDataGridFactory
     */
    private $userRoleDataGridFactory;

    /**
     * @var IPermissionFormFactory
     */
    private $permissionFormFactory;

    public function __construct(UserRoleManager $userRoleManager, RBACLoader $RBACLoader, IUserRoleDataGridFactory $userRoleDataGridFactory, IPermissionFormFactory $permissionFormFactory) {
        parent::__construct();
        $this->userRoleManager = $userRoleManager;
        $this->rbacLoader = $RBACLoader;
        $this->userRoleDataGridFactory = $userRoleDataGridFactory;
        $this->permissionFormFactory = $permissionFormFactory;
    }

    /**
     * Všechny akcí v tomto presenteru využívá layoutBackend, proto ho zde nastavíme pro všechny akce.
     * Pokud budeme potřebovat jiný layout, dá se změnit v renderXX nebo actionXX metodě
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName management
     * @actionDescription Akce pro práci s uživatelskými rolemi - přehled rolí
     */
    public function actionManagement() {
        $this->rbacLoader->run();
    }

    /**
     * @actionName manage
     * @actionDescription Akce pro práci s uživatelskými rolemi: výpis aktivním zdrojů a akcí - nastavení oprávnění pro roli
     */
    public function actionManage($role_id) {
        // Pole pro hodnoty, podle kterého se nastaví defauiltní hodnoty
        $defaultValues = array();

        // Id role pro editaci
        if ($role_id) {
            $role_slug = $this->userRoleManager->getById(UserRoleManager::TABLE_ROLE_NAME, UserRoleManager::COLUMN_ROLE_ID, $role_id)[UserRoleManager::COLUMN_ROLE_SLUG];

            // Pokud chci editovat super admina - ten ma veskere opravneni povelene v autorizatoru
            if ($role_slug == UserRoleManager::ROLE_TYPE_SUPERADMIN) {
                $this->flashMessage($this->translator->translate('core.common.noRoleModified'), MessageType::ERROR);
                $this->redirect(':management');
            }

            $rows = $this->userRoleManager->getAllRowsById(UserRoleManager::TABLE_ROLE_NAME . '_' . UserRoleManager::TABLE_ACTION_NAME, UserRoleManager::COLUMN_ROLE_ID, $role_id);
            foreach ($rows as $row) {
                // Resource přidám jen jednou - hodnota se kdyžtak přepíše, protože zapisuji na určitou pozici
                $defaultValues['resource' . $row[UserRoleManager::COLUMN_RESOURCE_ID]] = true;
                // Akce je tam vždy pro každou roli max jednou
                $defaultValues['action' . $row[UserRoleManager::COLUMN_ACTION_ID]] = true;
            }
            // Přidám i hodnotu role_id pro pozdějiší účely
            $defaultValues[UserRoleManager::COLUMN_ROLE_ID] = $role_id;
            $this['permissionForm']->setDefaults($defaultValues);
        }
    }

    public function renderManage($role_id) {
        $this->template->role = $this->userRoleManager->getById(UserRoleManager::TABLE_ROLE_NAME, UserRoleManager::COLUMN_ROLE_ID, $role_id);
    }

    /**
     * @return UserRoleDatagridControl
     */
    protected function createComponentUserRoleDatagrid() {
        return $this->userRoleDataGridFactory->create();
    }

    /**
     * @return PermissionFormControl
     */
    protected function createComponentPermissionForm() {
        return $this->permissionFormFactory->create();
    }

}
