<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EmailModule\Components;

use App\EmailModule\Model\EmailManager;
use Ublaboo\DataGrid\DataGrid;
use Nette\Application\UI\Control;
use App\Model\Enum\MessageType;

/**
 * Class EmailDataGridControl
 * @package App\EmailModule\Components
 */
class EmailDataGridControl extends Control
{

    const TEMPLATE = '/../../../templates/components/DataGrids/dataGrid.latte';

    /**
     * @var EmailManager
     */
    private $emailManager;

    public function __construct(EmailManager $emailManager)
    {
        parent::__construct();
        $this->emailManager = $emailManager;
    }

    public function render()
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->render();
    }

    public function createComponentDataGrid($name)
    {
        $grid = new DataGrid($this, $name);

        $grid->setPrimaryKey('id');

        $grid->setDataSource($this->emailManager->getTable()->where(EmailManager::COLUMN_VALID, 1));

        $grid->addColumnText('email', 'email.email.emailAddress')
            ->setSortable();

        $grid->addColumnDateTime('date', 'blog.article.datagrid.column-date')
            ->setFormat('d.m.Y H:i')
            ->setSortable();

        /**
         * Mazani
         */
        $grid->addAction('delete', '', 'deleteEmail!')
            ->setIcon('trash')
            ->setTitle('email.email.datagrid.action-delete')
            ->setClass('btn btn-xs btn-danger ajax')
            ->setConfirm('email.email.datagrid.action-delete-confirm', 'email');


        $grid->setTranslator($this->presenter->translator);

        return $grid;
    }

    public function handleDeleteEmail($id)
    {
        $this->emailManager->removeEmail($id);
        // Zaznamení akce do DB
        $this->presenter->logAction('Smazání e-mailu ze sběru e-mailu - ' . $id);
        $this->presenter->flashMessage($this->presenter->translator->translate('email.email.flashes.deleted-success', ['id' => $id]), MessageType::SUCCESS);
        if ($this->presenter->isAjax()) {
            $this->presenter->redrawControl('flashes');
            $this['dataGrid']->reload();
        } else {
            $this->presenter->redirect('this');
        }
    }



}

/**
 * Interface IEmailDataGridFactory
 * @package App\EmailModule\Components
 */
interface IEmailDataGridFactory
{
    /**
     * @return EmailDataGridControl
     */
    public function create();
}
