<?php

namespace App\EmailModule\Model;

use App\Model\BaseManager;
use Nette\Database\Context;
use Nette\Database\UniqueConstraintViolationException;
use Nette\Utils\ArrayHash;

class EmailManager extends BaseManager {

    const
            TABLE_NAME = 'emails',
            COLUMN_ID = 'id',
            COLUMN_EMAIL = 'email',
            COLUMN_TOKEN = 'token',
            COLUMN_VALID = 'valid';

    /**
     * EmailManager constructor.
     * @param Context $database
     */
    public function __construct(Context $database) {
        parent::__construct($database);
    }

    /**
     * Vrátí tabulku jako zdroj pro DataGrid
     */
    public function getTable() {
        return $this->database->table(self::TABLE_NAME);
    }

    /**
     * @param ArrayHash $data
     * @throws EmailExistsException
     * @return bool|int|\Nette\Database\Table\IRow
     */
    public function addEmail(ArrayHash $data) {
        if (!$this->emailExists($data->email)) {
            return $this->database->table(self::TABLE_NAME)->insert($data);
        } else {
            throw new EmailExistsException('Je nám to líto, ale tento email se již nachází v naší databázi.');
        }
    }

    public function validateToken($token) {
        return $this->database->table(self::TABLE_NAME)->where(self::COLUMN_TOKEN, $token)->update(['valid' => 1]);
    }

    private function emailExists($email) {
        $email = $this->database->table(self::TABLE_NAME)
                ->where(self::COLUMN_EMAIL, $email)
                ->where(self::COLUMN_VALID, 1)
                ->fetch();
        if ($email) {
            return true;
        } else {
            return false;
        }
    }

    public function removeEmail($id) {
        $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $id)->delete();
    }

}

/**
 * Class EmailExistsException
 * @package App\EmailModule\Model
 */
class EmailExistsException extends UniqueConstraintViolationException {

    public function __construct($message = "", $code = 0, \Exception $previous = null) {
        parent::__construct($message, $code, $previous);
    }

}
