<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\DataGrids;

use App\EshopModule\Model\AttributeManager;
use App\Model\Enum\MessageType;
use Ublaboo\DataGrid\DataGrid;
use Nette\Application\UI\Control;

/**
 * Komponenta datagridu pro správu produktů
 * @package App\EshopModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AttributeDataGridControl extends Control
{

    const TEMPLATE = '/../../../../templates/components/DataGrids/dataGrid.latte';

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    public function __construct(AttributeManager $attributeManager)
    {
        parent::__construct();
        $this->attributeManager = $attributeManager;
    }

    public function render()
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->render();
    }

    public function createComponentDataGrid($name)
    {
        $grid = new DataGrid($this, $name);
        $grid->setPrimaryKey(AttributeManager::COLUMN_ID);
        $grid->setDataSource($this->attributeManager->getAttributes());

        $grid->addColumnText(AttributeManager::COLUMN_NAME, 'eshop.product.attribute.datagrid.name')
            ->setSortable();

        $grid->addColumnText(AttributeManager::COLUMN_TYPE, 'eshop.product.attribute.datagrid.type')
            ->setSortable()
            ->setReplacement(AttributeManager::$TYPES);

        $grid->addGroupAction('eshop.product.attribute.datagrid.delete')->onSelect[] = [$this, 'deleteAttributes'];

        /**
         * Odkaz na editaci
         */
        $grid->addAction('edit', '', ':Eshop:Attribute:editor')
            ->setIcon('pencil');

        /**
         * Mazani
         */
        $grid->addAction('delete', '', 'deleteAttribute!')
            ->setIcon('trash')
            ->setTitle('eshop.common.delete')
            ->setClass('btn btn-xs btn-danger ajax')
            ->setConfirm($this->presenter->translator->translate('eshop.product.attribute.datagrid.deleteConfirm', ['name' => AttributeManager::COLUMN_NAME]));

        // Tlačítko pro vložení nového atributu
        $grid->addToolbarButton(':Eshop:Attribute:editor', 'eshop.attribute.createAttribute')
            ->setClass('btn btn-xs btn-default');

        /**
         * Localization
         */
        $grid->setTranslator($this->presenter->translator);

        return $grid;
    }

    /**
     * Odstranění atributu.
     * @param int $attribute_id ID atributu
     */
    public function handleDeleteAttribute($attribute_id)
    {
        $presenter = $this->presenter;
        $this->attributeManager->removeAttribute($attribute_id);
        // Zaznamení akce do DB
        $presenter->logAction('Smazání atributu produktu - ' . $attribute_id);
        $presenter->flashMessage(
            $presenter->translator->translate('eshop.product.attribute.datagrid.deleteSuccessSingle',
                ['id' => $attribute_id]),
            MessageType::SUCCESS);

        if ($presenter->isAjax()) {
            $presenter->redrawControl('ajaxNotification');
            $this['dataGrid']->reload();
        } else {
            $presenter->redirect('this');
        }
    }

    /**
     * Hromadné odstranění produktů.
     * @param int[] $ids Pole ID atributu ke smazani
     */
    public function deleteAttributes($ids = [])
    {
        $presenter = $this->presenter;
        foreach ($ids as $id) {
            $this->attributeManager->removeAttribute($id);
        }
        $idList = implode(',', $ids);
        // Zaznamení akce do DB
        $presenter->logAction('Hromadné smazání atributů produktů - ' . $idList);
        $presenter->flashMessage($presenter->translator->translate('eshop.product.attribute.datagrid.deleteSuccessAll', ['listy' => $idList]), MessageType::SUCCESS);
        if ($presenter->isAjax()) {
            $presenter->redrawControl('ajaxNotification');
            $this['dataGrid']->reload();
        } else {
            $presenter->redirect('this');
        }
    }

}

/**
 * Interface IAttributeDataGridFactory
 * @package App\EshopModule\Components\DataGrids
 */
interface IAttributeDataGridFactory
{
    /**
     * @return AttributeDataGridControl
     */
    public function create();
}
