<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\DataGrids;
use App\EshopModule\Model\AttributeManager;
use Nette\Application\UI\Control;
use Ublaboo\DataGrid\DataGrid;
use App\Model\Enum\MessageType;

/**
 * Komponenta datagridu pro správu hodnot atributu
 * @package App\EshopModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AttributeValuesDataGridControl extends Control
{

    const TEMPLATE = '/../../../../templates/components/DataGrids/dataGrid.latte';

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    /**
     * @var int
     */
    private $attributeId;

    public function __construct(AttributeManager $attributeManager)
    {
        parent::__construct();
        $this->attributeManager = $attributeManager;
    }

    public function setAttribute($id)
    {
        $this->attributeId = $id;
    }

    public function render()
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->render();
    }

    public function createComponentDataGrid($name)
    {
        $grid = new DataGrid($this, $name);
        $grid->setPrimaryKey(AttributeManager::COLUMN_VALUES_ID);
        $grid->setDataSource($this->attributeManager->getAttributeValues($this->attributeId));

        $grid->addColumnText(AttributeManager::COLUMN_VALUES_VALUE, 'eshop.product.attribute.value')
            ->setSortable();

        /**
         * Mazani
         */
        $grid->addAction('delete', '', 'deleteValue!')
            ->setIcon('trash')
            ->setTitle('eshop.common.delete')
            ->setClass('btn btn-xs btn-danger ajax')
            ->setConfirm($this->presenter->translator->translate('eshop.product.attribute.datagrid.deleteValueConfirm', ['name' => AttributeManager::COLUMN_VALUES_VALUE]));

        /**
         * Localization
         */
        $grid->setTranslator($this->presenter->translator);

        return $grid;
    }

    /**
     * Odstranění atributu.
     * @param int $attribute_values_id ID atributu
     */
    public function handleDeleteValue($attribute_values_id)
    {
        $presenter = $this->presenter;
        $this->attributeManager->removeValue($attribute_values_id);
        // Zaznamení akce do DB
        $presenter->logAction('Smazání hodnoty atributu - ' . $attribute_values_id);
        $presenter->flashMessage($presenter->translator->translate('eshop.product.attribute.datagrid.deleteValueSuccess', ['id' => $attribute_values_id]), MessageType::SUCCESS);
        if ($presenter->isAjax()) {
            $presenter->redrawControl('ajaxNotification');
            $this['dataGrid']->reload();
        } else {
            $presenter->redirect('this');
        }
    }

}

/**
 * Interface IAttributeValuesDataGridFactory
 * @package App\EshopModule\Components
 */
interface IAttributeValuesDataGridFactory
{
    /**
     * @return AttributeValuesDataGridControl
     */
    public function create();
}
