<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\DataGrids;

use App\EshopModule\Model\SettingsManager;
use App\Model\PersonManager;
use App\Model\UserManager;
use Nette\Application\UI\Control;
use Ublaboo\DataGrid\DataGrid;

/**
 * Komponenta datagridu pro správu produktů
 * @package App\EshopModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class CustomerDataGridControl extends Control {

    const TEMPLATE = '/../../../../templates/components/DataGrids/dataGrid.latte';

    /**
     * @var PersonManager
     */
    private $personManager;

    /**
     * @var SettingsManager
     */
    private $settingsManager;

    public function __construct(PersonManager $personManager, SettingsManager $settingsManager) {
        parent::__construct();
        $this->personManager = $personManager;
        $this->settingsManager = $settingsManager;
    }

    public function render() {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->render();
    }

    public function createComponentDataGrid($name) {
        $grid = new DataGrid($this, $name);

        /** Localization */
        $grid->setTranslator($this->presenter->translator);

        $grid->setPrimaryKey(PersonManager::COLUMN_ID);
        // Dotaz na vsechny osoby, které nejsou firmy - company name is NULL. Musim spojit tabulky s person detail a user
        $grid->setDataSource($this->getDataSource());
        // Jméno osoby
        $grid->addColumnText(PersonManager::COLUMN_FIRST_NAME, 'eshop.person.labels.name')
                ->setReplacement(['' => '-----'])
                ->setSortable();
        $grid->addFilterText(PersonManager::COLUMN_FIRST_NAME, 'eshop.person.labels.name');
        // Příjmení osoby
        $grid->addColumnText(PersonManager::COLUMN_LAST_NAME, 'eshop.person.labels.lastName')
                ->setReplacement(['' => '-----'])
                ->setSortable();
        $grid->addFilterText(PersonManager::COLUMN_LAST_NAME, 'eshop.person.labels.lastName');
        // Název firmy
        $grid->addColumnText(PersonManager::COLUMN_COMPANY_NAME, 'eshop.person.labels.companyName')
                ->setReplacement(['' => '-----'])
                ->setSortable();
        $grid->addFilterText(PersonManager::COLUMN_COMPANY_NAME, 'eshop.person.labels.companyName');
        // Login do systému
        $grid->addColumnText(\App\Model\UserManager::COLUMN_NAME, 'eshop.person.labels.registrated')
                ->setReplacement(['' => 'bez registrace'])
                ->setSortable();

        // Utracená částka
        $grid->addColumnNumber(PersonManager::COLUMN_TOTAL_AMOUNT, 'eshop.person.labels.totalCash')
                ->setSortable()
                ->setRenderer(function ($item) {
                    $priceComponent = $this->presenter->getComponent('price');
                    $price = $priceComponent->renderPriceForBackend($item[PersonManager::COLUMN_TOTAL_AMOUNT], $this->settingsManager->getSettings());
                    return $price;
                });

        /**
         * Odkaz na editaci
         */
        $grid->addAction('edit', '', ':Eshop:Person:personDetail')
                ->setIcon('pencil');

        return $grid;
    }

    /**
     * Pomocná funkce pro získání dat dat do datagridu
     * @return Selection vrací všechny uživatelsky dokončené ojednávky spojené s údaji pro osoby
     */
    private function getDataSource() {
        return $this->personManager->getTable()
                ->select('*')
                ->whereOr([
                    PersonManager::TABLE_DETAIL_NAME . '.' . PersonManager::COLUMN_PERSON_DETAIL_ID,
                    UserManager::TABLE_NAME . '.' . UserManager::COLUMN_ID,
                    UserManager::TABLE_NAME . '.' . UserManager::COLUMN_ID => NULL
                ])
                ->fetchAll();
    }

}

interface ICustomersDataGridFactory {

    /**
     * @return CustomerDataGridControl
     */
    public function create();
}
