<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\AttributeManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;
use Nette\Database\UniqueConstraintViolationException;

/**
 * Class AttributeFormControl
 * @package App\EshopModule\Forms
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AttributeFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @param AttributeManager $attributeManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(AttributeManager $attributeManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->attributeManager = $attributeManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values) {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null) {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * @return Form Formulář pro správu článku
     */
    protected function createComponentForm() {
        $form = $this->formFactory->create();
        $form->addHidden(AttributeManager::COLUMN_ID);
        $form->addText(AttributeManager::COLUMN_NAME, 'eshop.orderMethods.form.name')->setRequired();
        $form->addHidden(AttributeManager::COLUMN_TYPE)->setDefaultValue('select');

        $form->addSubmit('submit', 'eshop.order.form.orderForm.label.save')
                ->setAttribute('id', 'atributteSubmit');
        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();
        
        try{
            $this->attributeManager->saveValues(AttributeManager::TABLE_NAME, AttributeManager::COLUMN_ID, $values);
             // Zaznamení akce do DB
            $presenter->logAction('Vytvořeni/Editace atributu produktu ' . $values[AttributeManager::COLUMN_NAME]);
            $presenter->flashMessage($presenter->translator->translate('eshop.product.attribute.flashes.save'), MessageType::SUCCESS);
        }  catch (UniqueConstraintViolationException $ex){
            $presenter->flashMessage($presenter->translator->translate('eshop.product.attribute.flashes.saveError'), MessageType::ERROR);
        }
       
        $presenter->redirect(':Eshop:Attribute:');
    }

}

interface IAttributeFromFactory {

    /**
     * @return AttributeFormControl
     */
    public function create();
}
