<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\AttributeManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;

/**
 * Class AttributeValueFormControl
 * @package App\EshopModule\Forms
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AttributeValueFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @param AttributeManager $attributeManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(AttributeManager $attributeManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->attributeManager = $attributeManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values) {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null) {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    protected function createComponentForm() {
        $form = $this->formFactory->create();

        $form->addHidden(AttributeManager::COLUMN_VALUES_ATTRIBUTE);
        $form->addText(AttributeManager::COLUMN_VALUES_VALUE, 'eshop.product.attribute.value')->setRequired();

        $form->addSubmit('submit', 'eshop.product.attribute.add')
                ->setAttribute('id', 'attributeValueSubmit');
        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values) {
        $presenter = $this->presenter;

        $value = $this->attributeManager->saveValue($values);
        // Zaznamení akce do DB
        $presenter->logAction('Vytvořeni/Editace hodntoty atributu produktu ' . $values[AttributeManager::COLUMN_VALUES_VALUE]);
        $presenter->flashMessage($presenter->translator->translate('eshop.product.attribute.flashes.save'), MessageType::SUCCESS);
        $presenter->redirect(':Eshop:Attribute:editor', $values->{AttributeManager::COLUMN_VALUES_ATTRIBUTE});
    }

}

interface IAttributeValueFormFactory {

    /**
     * @return AttributeValueFormControl
     */
    public function create();
}
