<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\CurrencyManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;

/**
 * Class CurrencyDefaultFormControl - formulář pro přidávání nové měny
 * @package App\EshopModule\Forms
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class CurrencyDefaultFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var CurrencyManager
     */
    private $currencyManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @param CurrencyManager $currencyManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(CurrencyManager $currencyManager, BaseFormFactory $baseFormFactory)
    {
        parent::__construct();
        $this->currencyManager = $currencyManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values)
    {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null)
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Vytváří a vrací komponentu formuláře pro správu defaultní měny
     * @return Form formulář pro správu defaultní měny
     */
    protected function createComponentForm() {
        $form = $this->formFactory->create();

        $form->addSelect('default_currency', 'eshop.currency.form.defalultCurrencyForm.default', $this->currencyManager->getCurrencyList())
                ->setRequired();

        $form->addSubmit('submit', 'eshop.common.btns.send')
                ->setAttribute('id', 'defaultCurrencySubmit')
                ->getControlPrototype();

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    /**
     * Funkce se vykonaná při úspěšném odeslání formuláře pro správu defaultní měny.
     * @param Form $form        formulář pro správu defualní měny
     * @param ArrayHash $values odeslané hodnoty formuláře
     */
    private function succeeded($form, $values) {
        $presenter = $form->getPresenter();

        // Uložení měny    
        $currencyName = $this->currencyManager->saveDefaultCurrency($values);
        
        // Zaznamení akce do DB
        $presenter->logAction('Změna výchozí měny na ' . $currencyName);

        // Zpráva o infu
        $presenter->flashMessage($presenter->translator->translate('eshop.currency.flashes.setDefaultCurrency', ['currencyName' => $currencyName]), MessageType::SUCCESS);

        if ($presenter->isAjax()) {
            $presenter->redrawControl("ajaxNotification");
            $presenter->redrawControl("defaultCurrencyForm");
        } else {
            $presenter->redirect(':Eshop:Currency:management');
        }
    }

}

interface ICurrencyDefaultFormFactory
{
    /**
     * @return CurrencyDefaultFormControl
     */
    public function create();
}
