<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\CurrencyManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;

/**
 * Class CurrencyFormControl - formulář pro přidávání nové měny
 * @package App\EshopModule\Forms
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class CurrencyFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var CurrencyManager
     */
    private $currencyManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @param CurrencyManager $currencyManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(CurrencyManager $currencyManager, BaseFormFactory $baseFormFactory)
    {
        parent::__construct();
        $this->currencyManager = $currencyManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values)
    {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null)
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    protected function createComponentForm() {
        $form = $this->formFactory->create();

        $form->addHidden('currency_id');

        $form->addText('currency_name', 'eshop.currency.form.currencyForm.label.name')
                ->setRequired()
                ->setAttribute('placeholder', 'eshop.currency.form.currencyForm.placeholder.name')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('currency_code', 'eshop.currency.form.currencyForm.label.code')
                ->setAttribute('placeholder', 'eshop.currency.form.currencyForm.placeholder.code')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('exchange_rate', 'eshop.currency.form.currencyForm.label.exchange')
                ->setRequired()
                ->setType('number')
                ->setAttribute('placeholder', 'eshop.currency.form.currencyForm.placeholder.exchange')
                ->setDefaultValue(0)->addRule(Form::FLOAT)
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('currency_symbol', 'eshop.currency.form.currencyForm.label.symbol')
                ->setAttribute('placeholder', 'eshop.currency.form.currencyForm.placeholder.symbol')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addSubmit('submit', 'eshop.common.btns.send')
                ->setAttribute('id', 'currencySubmit')
                ->getControlPrototype();

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    /**
     * Funkce se vykonaná při úspěšném odeslání formuláře pro správu měn.
     * @param Form $form        formulář pro správu měn
     * @param ArrayHash $values odeslané hodnoty formuláře
     */
    private function succeeded($form, $values) {
        $presenter = $form->getPresenter();

        // Uložení měny    
        $this->currencyManager->saveCurrency($values);
        
        // Zaznamení akce do DB
        $presenter->logAction('Vytvoření/Editace měny ' . $values[CurrencyManager::COLUMN_NAME]);

        // Zpráva o infu
        $presenter->flashMessage($presenter->translator->translate('eshop.currency.flashes.saveCurrency', ['currencyName' => $values[CurrencyManager::COLUMN_NAME]]), MessageType::SUCCESS);

        // Nepoužívat ajax, protože kdž edituju měnu, tak ji skrývám a vytvářím novou kvůli fkaturám - potřebuji reload stránky
        if ($presenter->isAjax()) {
            $presenter->redrawControl("ajaxNotification");
            $presenter->redrawControl("currencyForm");
            $presenter->redrawControl("currenciesSnippet");
        } else {
            $presenter->redirect(':Eshop:Currency:management');
        }
    }

}

interface ICurrencyFormFactory
{
    /**
     * @return CurrencyFormControl
     */
    public function create();
}
