<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\DiscountLevelsManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;

/**
 * Class DiscountLevelsFormControl
 * @package App\EshopModule\Forms
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class DiscountLevelsFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var DiscountLevelsManager
     */
    private $discountLevelsManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @param DiscountLevelsManager $discountLevelsManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(DiscountLevelsManager $discountLevelsManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->discountLevelsManager = $discountLevelsManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values) {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null) {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * @return Form
     */
    protected function createComponentForm() {
        $form = $this->formFactory->create();

        $form->addSelect('type', 'eshop.discountLevels.form.label.choice', $this->discountLevelsManager->getDiscountTypes());

        $form->addText('discount', 'eshop.discountLevels.form.label.percentage')
                ->setType('number')
                ->setRequired()
                ->addRule(Form::FLOAT)
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addGroup($this->presenter->translator->translate('eshop.discountLevels.form.label.settingUser'))->setOption('id', 'user_discount-controls');
        $form->addText('price', 'eshop.discountLevels.form.label.minPrice')
                ->setType('number')
                ->setRequired(FALSE)
                ->getControlPrototype()
                ->addClass('form-control')
                ->addCondition(Form::FILLED)
                ->addRule(Form::FLOAT);

        $form->addGroup($this->presenter->translator->translate('eshop.discountLevels.form.label.settingDiscout'))->setOption('id', 'discount_coupon-controls');
        $form->addText('coupon_code', 'eshop.discountLevels.labels.code')
                ->setRequired(FALSE)
                ->getControlPrototype()
                ->addClass('form-control');
        $form->addText('limit_usages', 'eshop.discountLevels.form.label.limitUsages')
                ->setType('number')
                ->setRequired(FALSE)
                ->getControlPrototype()
                ->addClass('form-control')
                ->addCondition(Form::FILLED)
                ->addRule(Form::FLOAT);
        $form->addDate('limit_date', 'eshop.discountLevels.form.label.limitDate', 'Y-m-d')
                ->getControlPrototype()
                ->setRequired(FALSE)
                ->addClass('form-control');

        $form->addGroup($this->presenter->translator->translate('eshop.discountLevels.form.label.settingQuantityDiscount'))->setOption('id', 'quantity_discount-controls');
        $form->addText('quantity', 'eshop.discountLevels.form.label.minQuantity')
                ->setType('number')
                ->setRequired(FALSE)
                ->getControlPrototype()
                ->addClass('form-control')
                ->addCondition(Form::FILLED)
                ->addRule(Form::FLOAT);

        $form->setCurrentGroup();

        $form->addSubmit('submit', 'eshop.common.btns.send')
                ->getControlPrototype();

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    /**
     * @param Form $form
     * @param ArrayHash $values
     */
    private function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();

        if ($values['price'] == '') {
            $values->offsetUnset('price');
        }

        if ($values['limit_usages'] == '') {
            $values->offsetUnset('limit_usages');
        }

        if ($values['quantity'] == '') {
            $values->offsetUnset('quantity');
        }

        if ($values['coupon_code'] == '') {
            $values->offsetUnset('coupon_code');
        }

        // Zaznamení akce do DB
        $presenter->logAction('Vytvoření ' . $values[DiscountLevelsManager::COLUMN_DISCOUNT] . '% slevy, typ ' . $values[DiscountLevelsManager::COLUMN_TYPE]);

        $this->discountLevelsManager->addDiscount($values);
        $presenter->flashMessage($presenter->translator->translate("eshop.discountLevels.flashes.saveSuccess"), MessageType::SUCCESS);

        if ($presenter->isAjax()) {
            $presenter->redrawControl("ajaxNotification");
            $presenter->redrawControl("discountsSnippet");
            $presenter->redrawControl("discountLevelsForm");
        } else {
            $presenter->redirect('this');
        }
    }

}

interface IDiscountLevelsFormFactory {

    /**
     * @return DiscountLevelsFormControl
     */
    public function create();
}
