<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\ProductAttributeManager;
use App\EshopModule\Model\ProductManager;
use Instante\Bootstrap3Renderer\BootstrapRenderer;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;

/**
 * Class ProductVariantFormControl
 * @package App\EshopModule\Forms
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class ProductVariantFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var ProductAttributeManager
     */
    private $productAttributeManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @param ProductManager $productManager
     * @param ProductAttributeManager $productAttributeManager
     * @param BaseFormFactory $baseFormFactory
     */
    public function __construct(ProductManager $productManager, ProductAttributeManager $productAttributeManager, BaseFormFactory $baseFormFactory) {
        $this->productManager = $productManager;
        $this->productAttributeManager = $productAttributeManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values) {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null) {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Vykreslí komponentu.
        $this->template->render();
    }

    protected function createComponentForm() {
        $form = $this->formFactory->create();
        $form->setRenderer(new BootstrapRenderer);

        $form->addHidden('parent_id')->setDefaultValue($this->presenter->productId);

        /**
         * Load attributes and their values to use in variants
         */
        $attributesArr = [];
        $attributes = $this->productAttributeManager->getProductAttributesForVariations($this->presenter->productId);
        foreach ($attributes as $attribute) {
            $attributesArr[$attribute->attribute_id]['name'] = $attribute->attribute->name;
            $attributesArr[$attribute->attribute_id]['values'][$attribute->attribute_values_id] = $attribute->attribute_values->value;
        }

        foreach ($attributesArr as $attributeId => $attribute) {
            $form->addSelect('attribute_' . $attributeId, $attribute['name'], $attribute['values']);
        }

        $product = $this->productManager->getProductFromId($this->presenter->productId);

        $form->addText('price', 'eshop.orderMethods.form.price')->setDefaultValue($product->price);
        $form->addSubmit('save', 'eshop.order.form.orderForm.label.save');


        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values) {
        $parentProduct = $this->productManager->getProductFromId($this->presenter->productId);


        $variant = $parentProduct->toArray();
        unset($variant[ProductManager::COLUMN_ID]);
        $variant[ProductManager::COLUMN_URL] = $variant[ProductManager::COLUMN_URL] . '-var' . rand(0, 255);
        $variant[ProductManager::COLUMN_TYPE] = ProductManager::TYPE_VARIATION;
        $variant[ProductManager::COLUMN_PARENT] = $values->parent_id;
        $variant[ProductManager::COLUMN_PRICE] = $values->price;

        $variantId = $this->productManager->saveProduct($variant);
        $attributes = $this->productAttributeManager->getProductAttributesForVariations($parentProduct->product_id)->group(ProductAttributeManager::COLUMN_ATTRIBUTE);
        $this->productAttributeManager->removeProductAttributes($variantId);
        foreach ($attributes as $attribute) {
            $this->productAttributeManager->saveProductAttribute($variantId, $attribute->attribute_id, $values['attribute_' . $attribute->attribute_id], 0);
        }

        // Zaznamení akce do DB
        $form->getPresenter()->logAction('Vytvoření varianty produktu ' . $values[ProductManager::COLUMN_URL]);
    }

}

interface IProductVariantFormFactory {

    /**
     * @return ProductVariantFormControl
     */
    public function create();
}
