<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\AttributeManager;
use App\EshopModule\Model\ProductAttributeManager;
use App\EshopModule\Model\ProductManager;
use App\Forms\BaseFormFactory;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Model\Enum\MessageType;

/**
 * Class SimpleProductAttributeFormControl
 * @package App\EshopModule\Forms
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class SimpleProductAttributeFormControl extends Control
{

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../../templates/components/Forms/SimpleProductAttributeForm/form.latte';

    /** @var BaseFormFactory Továrnička na formuláře. */
    private $formFactory;

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var ProductAttributeManager
     */
    private $productAttributeManager;

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    public function __construct(ProductManager $productManager, ProductAttributeManager $productAttributeManager, AttributeManager $attributeManager, BaseFormFactory $baseFormFactory)
    {
        parent::__construct();
        $this->productManager = $productManager;
        $this->attributeManager = $attributeManager;
        $this->productAttributeManager = $productAttributeManager;
        $this->formFactory = $baseFormFactory;
    }

    /**
     * @param null $formPath
     */
    public function render($formPath = null)
    {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);
        $this->template->formPath = $formPath;

        // Atributy
        $this->template->attributes = sizeof($this->attributeManager->getAttributes());
        // Konkrétní hodnoty pro atributy do forluáře
        $this->template->formAttributes = sizeof($this->attributeManager->getAllRows(AttributeManager::TABLE_NAME_VALUES));

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * @return Form
     */
    protected function createComponentSimpleProductAttributeForm()
    {
        $form = $this->formFactory->create();
        //$form->elementPrototype->setAttribute('class', 'ajax');

        $form->addHidden('product_id');

        $attributes = $this->attributeManager->getAttributes();
        foreach ($attributes as $attribute) {
            $form->addSelect('attribute_' . $attribute->attribute_id, $attribute->name, $this->attributeManager->getAttributeValuesToForm($attribute->attribute_id));
        }

        $form->addSubmit('submit', 'Uložit vlastnosti')
                ->setAttribute('id', 'simpleProductVariantSubmit');

        //$form->getRenderer()->setRenderMode(RenderModeEnum::VERTICAL);

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values)
    {
        $presenter = $form->getPresenter();

        $attributes = $this->attributeManager->getAttributes();
        $this->productAttributeManager->removeProductAttributes($values['product_id']);
        foreach ($attributes as $attribute) {
            $this->productAttributeManager->saveProductAttribute($values['product_id'], $attribute->attribute_id, $values['attribute_' . $attribute->attribute_id], 0);
        }
        
        // Zaznamení akce do DB
        $presenter->logAction('Vytvoření atributu pro jednoduchý produktu ' .$values[ProductManager::COLUMN_ID]);

        //$this->productAttributeManager->saveProductAttributes($values['product_id'], $attributesArray);
        
        $presenter->flashMessage($presenter->translator->translate('eshop.product.flashes.saveSuccess'), MessageType::SUCCESS);
        $presenter->redirect('this');
    }

    public function setDefaults(array $defaults)
    {
        $this['simpleProductAttributeForm']->setDefaults($defaults);
    }

}

interface ISimpleProductAttributeFormFactory {

    /**
     * @return SimpleProductAttributeFormControl
     */
    public function create();
}
