<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\AttributeManager;
use App\EshopModule\Model\ProductAttributeManager;
use App\EshopModule\Model\ProductManager;
use App\Forms\BaseFormFactory;
use Instante\Bootstrap3Renderer\BootstrapRenderer;
use Instante\Bootstrap3Renderer\RenderModeEnum;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use App\Model\Enum\MessageType;

/**
 * Class VariableProductAttributeFormControl
 * @package App\EshopModule\Forms
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class VariableProductAttributeFormControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../../templates/components/Forms/VariableProductAttributeForm/form.latte';

    /** @var BaseFormFactory Továrnička na formuláře. */
    private $formFactory;

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var ProductAttributeManager
     */
    private $productAttributeManager;

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    public function __construct(ProductManager $productManager, ProductAttributeManager $productAttributeManager, AttributeManager $attributeManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->productManager = $productManager;
        $this->attributeManager = $attributeManager;
        $this->productAttributeManager = $productAttributeManager;
        $this->formFactory = $baseFormFactory;
    }

    /**
     * @param null $formPath
     */
    public function render($formPath = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);
        $this->template->formPath = $formPath;

        // Atributy
        $this->template->attributes = sizeof($this->attributeManager->getAttributes());
        // Konkrétní hodnoty pro atributy do forluáře
        $this->template->formAttributes = sizeof($this->attributeManager->getAllRows(AttributeManager::TABLE_NAME_VALUES));

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Vytváří a vrací komponentu formuláře pro hodnocení produktu.
     * @return Form formulář pro hodnocení produktu
     */
    protected function createComponentVariableProductAttributeForm() {
        $form = $this->formFactory->create();
        $form->setRenderer(new BootstrapRenderer);
        //$form->elementPrototype->setAttribute('class', 'ajax');

        $form->addHidden('product_id');

        $attributes = $this->attributeManager->getAttributes();

        foreach ($attributes as $attribute) {
            $form->addCheckboxList('attribute_' . $attribute->attribute_id, $attribute->name, $this->attributeManager->getAttributeValuesToForm($attribute->attribute_id))
                    ->getControlPrototype()
                    ->setAttribute('data-toggle', 'checkbox');

            $form->addCheckbox('variants_' . $attribute->attribute_id, 'Použít pro varianty')
                    ->getControlPrototype()
                    ->setAttribute('data-toggle', 'checkbox');
        }

        $form->addSubmit('submit', 'Uložit vlastnost')
                ->setAttribute('id', 'setAtrributeSubmit');

        $form->getRenderer()->setRenderMode(RenderModeEnum::VERTICAL);

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };

        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();
        $attributes = $this->attributeManager->getAttributes();
        foreach ($attributes as $attribute) {
            $attributesArray[$attribute->attribute_id] = $values['attribute_' . $attribute->attribute_id];
            $attributesArray[$attribute->attribute_id]['variant'] = $values['variants_' . $attribute->attribute_id];
        }
        $this->productAttributeManager->saveProductAttributes($values['product_id'], $attributesArray);

        // Zaznamení akce do DB
        $presenter->logAction('Vytvoření atributů pro variabilní produkt ' . $values[ProductManager::COLUMN_ID]);
        
        $presenter->flashMessage($presenter->translator->translate('eshop.product.flashes.setAttributesSuccess'), MessageType::SUCCESS);
        $presenter->redirect('this');
    }

    public function setDefaults(array $defaults) {
        $this['variableProductAttributeForm']->setDefaults($defaults);
    }

}

interface IVariableProductAttributeFormFactory {

    /**
     * @return \App\EshopModule\Components\Forms\VariableProductAttributeFormControl
     */
    public function create();
}
