<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Components\Forms;

use App\EshopModule\Model\CategoryManager;
use App\EshopModule\Model\ProductManager;
use App\Model\Enum\MessageType;
use Instante\Bootstrap3Renderer\BootstrapRenderer;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Database\UniqueConstraintViolationException;
use Nette\Utils\ArrayHash;
use App\Forms\BaseFormFactory;

/**
 * Class VariantFormControl
 * @package App\EshopModule\Forms
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class VariantFormControl extends Control {

    const TEMPLATE = '/../../templates/components/Forms/form.latte';

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var CategoryManager
     */
    private $categoryManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    public function __construct(ProductManager $productManager, CategoryManager $categoryManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->productManager = $productManager;
        $this->categoryManager = $categoryManager;
        $this->formFactory = $baseFormFactory;
    }

    public function setDefaults($values) {
        $this['form']->setDefaults($values);
    }

    public function render($formPath = null) {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        $this->template->render();
    }

    protected function createComponentForm() {
        $form = $this->formFactory->create();
        $form->setRenderer(new BootstrapRenderer);

        $form->addText('title', 'eshop.product.form.labels.productName')
                ->setRequired();

        // Form::URL funguje pouze pro absolutní adresy.
        $form->addHidden('url', 'eshop.product.form.labels.url');


        $form->addHidden('product_id');
        $form->addText('code', 'eshop.product.form.labels.code');

        $form->addHidden('type')->setDefaultValue('variation');

        $form->addText('short_description', 'eshop.product.form.labels.shortDescription')
                ->setRequired();


        $form->addText('cart_label', 'eshop.product.form.labels.cartDescription');

        $form->addTextArea('description', '')
                ->getControlPrototype()
                ->addClass('form-control');

        $form->addText('price', 'eshop.product.form.labels.price')
                ->setRequired()
                ->setDefaultValue(0)->addRule(Form::FLOAT);

        $form->addText('old_price', 'eshop.product.form.labels.oldPrice')
                ->setDefaultValue(0)
                ->addRule(Form::FLOAT)
                ->setRequired(FALSE);

        $form->addSubmit('submit', 'eshop.common.btns.send')
                ->getControlPrototype()
                ->addClass('btn btn-fill btn-info');

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();

        try {
            $productId = $this->productManager->saveProduct($values);

            $presenter->flashMessage($presenter->translator->translate('eshop.product.flashes.saveSuccess'), MessageType::SUCCESS);

            // Zaznamení akce do DB
            $presenter->logAction('Editace varianty produktu ' . $values[ProductManager::COLUMN_TITLE]);

            $presenter->redirect(':Eshop:ProductVariant:edit', $productId);
        } catch (UniqueConstraintViolationException $ex) {
            $presenter->flashMessage($presenter->translator->translate('eshop.product.flashes.saveError'), MessageType::ERROR);
        }
    }

}

interface IVariantFormFactory {

    /**
     * @return VariantFormControl
     */
    public function create();
}
