<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Model;

use App\Model\BaseManager;
use Nette\Utils\ArrayHash;

/**
 * Správce atributů.
 * @package App\EshopModule\Model
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AttributeManager extends BaseManager  {

	/** Konstanty pro manipulaci s modelem. */
	const
		TABLE_NAME = 'attribute',
		COLUMN_ID = 'attribute_id',
		COLUMN_NAME = 'name',
		COLUMN_TYPE = 'type',
		COLUMN_ITEMS = 'items',
		COLUMN_UNIT = 'unit';

	const
		TABLE_NAME_VALUES = 'attribute_values',
		COLUMN_VALUES_ID = 'attribute_values_id',
		COLUMN_VALUES_ATTRIBUTE = 'attribute_id',
		COLUMN_VALUES_VALUE = 'value';



	public static $TYPES = ['select' => 'Select', 'text' => 'Textové pole'];

	/**
	 * @return \Nette\Database\Table\Selection
	 */
	public function getAttributes()
	{
		return $this->database->table(self::TABLE_NAME);
	}

	public function getAttributesToSelect()
	{
		return $this->database->table(self::TABLE_NAME)->fetchPairs(self::COLUMN_ID, self::COLUMN_NAME);
	}

	/**
	 * @param $attributeId
	 * @return bool|mixed|\Nette\Database\Table\IRow
	 */
	public function getAttribute($attributeId)
	{
		return $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $attributeId)->fetch();
	}

	/**
	 * @param $valueId
	 * @return bool|mixed|\Nette\Database\Table\IRow
	 */
	public function getValue($valueId)
	{
		return $this->database->table(self::TABLE_NAME_VALUES)->where(self::COLUMN_VALUES_ID, $valueId)->fetch();
	}

	/**
	 * @param $attributeId
	 * @return \Nette\Database\Table\Selection
	 */
	public function getAttributeValues($attributeId)
	{
		return $this->database->table(self::TABLE_NAME_VALUES)->where(self::COLUMN_VALUES_ATTRIBUTE, $attributeId);
	}

	/**
	 * @param $attributeId
	 * @return \Nette\Database\Table\Selection
	 */
	public function getAttributeValuesToForm($attributeId)
	{
		return $this->getAttributeValues($attributeId)->fetchPairs(AttributeManager::COLUMN_VALUES_ID, AttributeManager::COLUMN_VALUES_VALUE);
	}

	/**
	 * @param $attributeId
	 * @return int
	 */
	public function removeAttribute($attributeId)
	{
		return $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $attributeId)->delete();
	}

	/**
	 * @param ArrayHash $values
	 * @return bool|int|mixed|\Nette\Database\Table\IRow
	 */
	public function saveValue(ArrayHash $values)
	{
		return $this->database->table(self::TABLE_NAME_VALUES)->insert($values);
	}

	/**
	 * @param $valueId
	 * @return int
	 */
	public function removeValue($valueId)
	{
		return $this->database->table(self::TABLE_NAME_VALUES)->where(self::COLUMN_VALUES_ID, $valueId)->delete();
	}

}
