<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Model;

use App\Model\BaseManager;

/**
 * Správce atributů produktů.
 * @package App\EshopModule\Model
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class ProductAttributeManager extends BaseManager  {

	/** Konstanty pro manipulaci s modelem. */
	const
		TABLE_NAME = 'product_attribute',
		COLUMN_ID = 'product_attribute_id',
		COLUMN_PRODUCT = 'product_id',
		COLUMN_ATTRIBUTE = 'attribute_id',
		COLUMN_VALUE = 'attribute_values_id',
        COLUMN_VARIANT = 'for_variant';

	/**
	 * @param $productId
	 * @return \Nette\Database\Table\Selection
	 */
	public function getProductAttributes($productId)
	{
		return $this->database->table(self::TABLE_NAME)->where(self::COLUMN_PRODUCT, $productId);
	}

	/**
	 * @param $productId
	 * @param $attributeId
	 * @return bool|mixed|\Nette\Database\Table\IRow
	 */
	public function getProductAttribute($productId, $attributeId)
	{
		return $this->getProductAttributes($productId)->where(self::COLUMN_ATTRIBUTE, $attributeId)->fetch();
	}

	public function removeProductAttributes($productId)
    {
        $this->getProductAttributes($productId)->delete();
    }


	/**
	 * @param $productId
	 * @param $attributeId
	 * @param $value
     * @param $variant
	 * @return bool|int|mixed|\Nette\Database\Table\IRow
	 */
	public function saveProductAttribute($productId, $attributeId, $value, $variant)
	{
        return $this->database->table(self::TABLE_NAME)->insert([
            self::COLUMN_PRODUCT => $productId,
            self::COLUMN_ATTRIBUTE => $attributeId,
            self::COLUMN_VALUE => $value,
            self::COLUMN_VARIANT => $variant
        ]);
	}

    /**
     * @param $productId
     * @param array $attributes
     */
	public function saveProductAttributes($productId, $attributes = [])
    {
        $this->removeProductAttributes($productId);
        foreach ($attributes as $attributeId => $values) {
            $variant = 0;
            if($values['variant'] == TRUE){
                $variant = 1;
            }
            unset($values['variant']);
            foreach ($values as $value) {
                $this->saveProductAttribute($productId, $attributeId, $value, $variant);
            }
        }
    }

    public function getProductAttributesForVariations($productId)
    {
        return $this->getProductAttributes($productId)->where(self::COLUMN_VARIANT, 1);
    }

}
