<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Model;

use App\Model\BaseManager;
use Nette\Database\Context;
use Nette\Database\Table\Selection;
use Nette\Database\UniqueConstraintViolationException;
use Nette\Utils\ArrayHash;

/**
 * Správce recenzí na produkty.
 * @package App\EshopModule\Model
 *
 * @author Jan Vodák <vodak at ideatech.cz>
 */
class ProductReviewManager extends BaseManager {

    /** Konstanty pro manipulaci s modelem. */
    const
            TABLE_NAME = 'product_review',
            COLUMN_ID = 'review_id';

    /**
     * Vrátí všechny recenze k danému produktu.
     * @param int $productId ID produktu
     * @return Selection recenze k danému produktu
     */
    public function getReviews($productId) {
        return $this->database->table(self::TABLE_NAME)
                        ->where(ProductManager::COLUMN_ID, $productId)
                        ->order(self::COLUMN_ID . ' DESC');
    }

    /**
     * Přidá k produktu recenzi.
     * @param array|ArrayHash $review recenze
     * @throws UniqueConstraintViolationException Pokud se daný uživatel pokusí hodnotit stejný produkt vícekrát - odchytává presenter.
     */
    public function addReview($review) {
        // Přidá aktuální datum a čas.
        $review['sent'] = Context::literal('NOW()'); 
        $this->database->table(self::TABLE_NAME)->insert($review);
    }

}
