<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Model;

use App\Model\BaseManager;
use Nette\Database\Context;
use Nette\Utils\ArrayHash;
use Nette\Utils\Image;
use App\Model\PersonManager;
use App\Model\Enum\Status;

/**
 * Spravuje účetní nastavení e-shopu.
 * @package App\EshopModule\Model
 * 
 * @author Jan Vodák <jan at ideatech.cz>
 */
class SettingsManager extends BaseManager {

    /** Konstanty pro manipulaci s modelem. */
    const
            TABLE_NAME = 'accounting_settings',
            COLUMN_ID = 'settings_id',
            COLUM_SIGNATURE = 'signature',
            COLUMN_VALID_FROM = "valid_from",
            COLUMN_VALID_TO = "valid_to",
            COLUMN_VAT = 'vat',
            COLUMN_ACCOUNTANT = 'accountant_detail_id',
            COLUMN_SELLER = 'seller_id';

    /** Konstanty pro pomocné atributy. */
    const
            ATTR_VAT_PAYER = 'vat_payer',
            ATTR_IMAGE_NAME = 'name';

    /** Cesta k obrázkům s podpisy. */
    const IMAGES_PATH = 'uploads/signatures/';

    /**
     * Vrátí účetní nastavení pro dané datum, včetně informace, zda je daný dodavatel plátcem DPH. 
     * Pokud není zadané datum, bere se aktuální období.
     * @param null|string $date datum v textové podobě a databázovém formátu (Y-m-d H:i:s) nebo null pro aktuální datum
     * @return false|ArrayHash účetní nastavení pro dané období(datum od, datum do, vlikost DPH, id účetního a id prodejce) + tax number
     *                          nebo false, pokud účetní nastavení pro dané datum neexistuje
     */
    public function getSettings($date = null) {
        if (is_null($date)) {
            $date = Context::literal('NOW()');
        }

        // Hledám aktuální účetní nastavení, které není smazané
        $settings = $this->database->table(self::TABLE_NAME)
                ->where(self::COLUMN_VALID_FROM . " <= DATE(?) AND " . self::COLUMN_VALID_TO . " >= DATE(?)", $date, $date)
                ->where(self::COLUMN_STATUS, Status::PUBLISHED)
                ->fetch();

        if (!$settings) {
            return false;
        }

        $settingsArray = ArrayHash::from($settings);

        //offsetSet vytvori novou polozku v poli s ideckem vat_payer a hodnotou z COLUMN_TAX_NUMBER to je napr. CZ4369875214 
        //hodnotu ziska z tabulky TABLE_DETAIL_NAME = person_detail, propoji to ID osoby ktera je vedena jako ucetni
        $settingsArray->offsetSet(
                self::ATTR_VAT_PAYER, isset($settings->ref(
                                PersonManager::TABLE_DETAIL_NAME, self::COLUMN_ACCOUNTANT)[PersonManager::COLUMN_TAX_NUMBER]
                )
        );

        return $settingsArray;
    }

    /**
     * Přidá nastavení.
     * @param array|ArrayHash $settings  nastavení
     * @param Image           $signature obrázek s podpisem, který se bude používat ve fakturách
     */
    public function addSettings($settings, $signature) {
        $row = $this->database->table(self::TABLE_NAME)->insert($settings);
        if ($signature) {
            $signature->resize(250, NULL);
            $signature->save(self::IMAGES_PATH . $row[self::COLUMN_ID] . '.png', NULL, Image::PNG);
        }
    }

    /**
     * Odstraní dané nastavení.
     * @param int $settingsId ID nastavení
     */
    public function deleteSettings($settingsId) {
        //$this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $settingsId)->delete();
        $this->clean(self::TABLE_NAME, self::COLUMN_ID, $settingsId);

        // Odstranění podpisu.
        $path = self::IMAGES_PATH . (int) $settingsId . '.png';
        if (file_exists($path))
            unlink($path);
    }

}
