<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\DataGrids\AttributeDataGridControl;
use App\EshopModule\Components\DataGrids\AttributeValuesDataGridControl;
use App\EshopModule\Components\DataGrids\IAttributeDataGridFactory;
use App\EshopModule\Components\DataGrids\IAttributeValuesDataGridFactory;
use App\EshopModule\Components\Forms\IAttributeFromFactory;
use App\EshopModule\Components\Forms\IAttributeValueFormFactory;
use App\EshopModule\Model\AttributeManager;
/**
 * @resourceDescription Zpracovává požadavky na nastavení atributů produktů
 * @actionName default
 * @actionDescription Přehled všech atributů pro produkty
 * @package App\EshopModule\Presenters
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class AttributePresenter extends BaseEshopPresenter
{

    /**
     * @var AttributeManager
     */
    private $attributeManager;

    /**
     * @var IAttributeDataGridFactory
     */
    private $attributeDataGridFactory;

    /**
     * @var IAttributeValuesDataGridFactory
     */
    private $attributeValuesDataGridFactory;

    /**
     * @var IAttributeFromFactory
     */
    private $attributeFormFactory;

    /**
     * @var IAttributeValueFormFactory
     */
    private $attributeValueFormFactory;

    public function __construct(
        AttributeManager $attributeManager,
        IAttributeDataGridFactory $attributeDataGridFactory,
        IAttributeValuesDataGridFactory $attributeValuesDataGridFactory,
        IAttributeFromFactory $attributeFromFactory,
        IAttributeValueFormFactory $attributeValueFormFactory)
    {
        parent::__construct();
        $this->attributeManager = $attributeManager;
        $this->attributeDataGridFactory = $attributeDataGridFactory;
        $this->attributeValuesDataGridFactory = $attributeValuesDataGridFactory;
        $this->attributeFormFactory = $attributeFromFactory;
        $this->attributeValueFormFactory = $attributeValueFormFactory;
    }

    public function beforeRender()
    {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName editor
     * @actionDescription editace atributů produktu
     * @param null $attribute_id
     */
    public function actionEditor($attribute_id = null)
    {
        // Pokud byla zadána URL, pokusí se atribut načíst a předat jeho hodnoty do editačního formuláře, jinak vypíše chybovou hlášku.
        if ($attribute_id && ($attribute = $this->attributeManager->getAttribute($attribute_id))) {
            $this->template->attribute = $attribute;
            $this['attributeForm']->setDefaults($attribute);
            $this['attributeValuesForm']->setDefaults(['attribute_id' => $attribute_id]);
            $this['attributeValuesDataGrid']->setAttribute($attribute_id);
        }
    }

    /**
     * @param $attribute_id
     */
    public function renderEditor($attribute_id)
    {
        $this->template->title = $attribute_id ? $this->translator->translate('eshop.attribute.editAttribute') : $this->translator->translate('eshop.attribute.newAttribute');
    }

    /**
     * @return \App\EshopModule\Components\Forms\AttributeFormControl
     */
    protected function createComponentAttributeForm()
    {
        return $this->attributeFormFactory->create();
    }

    /**
     * @return \App\EshopModule\Components\Forms\AttributeValueFormControl
     */
    protected function createComponentAttributeValuesForm()
    {
        return $this->attributeValueFormFactory->create();
    }

    /**
     * @return AttributeDataGridControl
     */
    protected function createComponentAttributeDataGrid()
    {
        return $this->attributeDataGridFactory->create();
    }

    /**
     * @return AttributeValuesDataGridControl
     */
    protected function createComponentAttributeValuesDataGrid()
    {
        return $this->attributeValuesDataGridFactory->create();
    }

}
