<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\Forms\IDiscountLevelsFormFactory;
use App\EshopModule\Model\DiscountLevelsManager;
use App\EshopModule\Components\Forms\DiscountLevelsFormControl;
use App\Model\Enum\MessageType;

/**
 * @resourceDescription Zpracovává uživatelské slevy a určité částky, od kterých se budou používat, věrnostní klub
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class DiscountLevelsPresenter extends BaseEshopPresenter {

    /**
     * @var DiscountLevelsManager
     */
    private $discountLevelsManager;

    /**
     * @var IDiscountLevelsFormFactory
     */
    private $discountLevelsFormFactory;

    public function __construct(DiscountLevelsManager $discountLevelsManager, IDiscountLevelsFormFactory $discountLevelsFormFactory) {
        parent::__construct();
        $this->discountLevelsManager = $discountLevelsManager;
        $this->discountLevelsFormFactory = $discountLevelsFormFactory;
    }

    /**
     * Nastavení layoutu pro backend. Metoda se volá před render metodami.
     * Všechny metody presneteru jsou součástí backendu - jeden layout
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
        $this->template->title = $this->translator->translate('eshop.settings.title');
    }

    /**
     * @actionName userDiscountManagement
     * @actionDescription Administrace nastavení pro uživatelské slevové hladiny.
     * Předá do šablony všechny uživatelské slevy
     */
    public function renderUserDiscountManagement() {
        $this->fillTemplateWithData($this->translator->translate('eshop.discountLevels.titleUser'), DiscountLevelsManager::TYPE_USER_DISCOUNT);
    }

    public function actionCouponDiscountManagement() {
        $defaultDiscount = DiscountLevelsManager::TYPE_DISCOUNT_COUPON;
        $this['discountLevelsForm']->setDefaults(
                array(
                    DiscountLevelsManager::COLUMN_TYPE => $defaultDiscount
                )
        );
    }

    /**
     * @actionName couponDiscountManagement
     * @actionDescription Administrace nastavení pro uživatelské slevové hladiny.
     * Předá do šablony všechny uživatelské slevy
     */
    public function renderCouponDiscountManagement() {
        $this->fillTemplateWithData($this->translator->translate('eshop.discountLevels.titleCoupon'), DiscountLevelsManager::TYPE_DISCOUNT_COUPON);
    }

    /**
     * Administrace nastavení pro uživatelské slevové hladiny.
     * Předá do šablony všechny uživatelské slevy
     */
    public function renderQuantityDiscountManagement() {
        $this->fillTemplateWithData($this->translator->translate('eshop.discountLevels.titleQuantity'), DiscountLevelsManager::TYPE_QUANTITY_DISCOUNT);
    }

    /**
     * @actionName deleteMethod
     * @actionDescription Smazání jednotlivé položky ze slev
     */
    public function handleDeleteMethod($id) {
        $this->discountLevelsManager->removeDiscount($id);

        // Zaznamení akce do DB
        $this->logAction('Smazání slevy s ID ' . $id);

        $this->presenter->flashMessage($this->translator->translate('eshop.discountLevels.flashes.deleteSucces'), MessageType::SUCCESS);

        if ($this->presenter->isAjax()) {
            $this->presenter->redrawControl('ajaxNotification');
            $this->redrawControl("discountsSnippet");
        } else {
            $this->presenter->redirect('this');
        }
    }

    /**
     * @return DiscountLevelsFormControl
     */
    protected function createComponentDiscountLevelsForm() {
        return $this->discountLevelsFormFactory->create();
    }

    /**
     * VVšechny akce se budou vypisovat do jednoho view - default
     * @param string $headerManagementDiscount  podnadpis nad datagridem (tabulkou pro výpis měn)
     * @param string $discountType              typ slev, které se do stránky předají 
     */
    public function fillTemplateWithData($headerManagementDiscount, $discountType) {
        $this->template->headerManagementDiscount = $headerManagementDiscount;
        $this->template->headerNewMethod = $this->translator->translate('eshop.discountLevels.newDiscount');
        $this->template->levels = $this->discountLevelsManager->getAllDiscountsByType($discountType);
    }

}
