<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\Forms\IPaymentMethodsFormFactory;
use App\EshopModule\Model\PaymentMethodsManager;
use App\EshopModule\Components\Forms\PaymentMethodsFormControl;
use App\Model\Enum\MessageType;

/**
 * @resourceDescription Zpracovává požadavky na tvobu, editace a přehled metod plateb za objednávky.
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class PaymentMethodsPresenter extends BaseEshopPresenter {

    /**
     * @var PaymentMethodsManager Instance třídy modelu pro práci s metodami platby.
     */
    private $paymentMethodsManager;

    /**
     * @var IPaymentMethodsFormFactory
     */
    private $paymentMethodsFormFactory;

    public function __construct(PaymentMethodsManager $paymentMethodsManager, IPaymentMethodsFormFactory $paymentMethodsFormFactory) {
        parent::__construct();
        $this->paymentMethodsManager = $paymentMethodsManager;
        $this->paymentMethodsFormFactory = $paymentMethodsFormFactory;
    }

    /**
     * Nastavení layoutu pro backend. Metoda se volá před render metodami.
     * Všechny metody presneteru jsou součástí backendu - jeden layout
     * Nastavím data do šablony podle toho, o jakou akci se jedná
     * Pokud je to management nebo mage pro metody platby nastavím konkretní data pro platby, jinak data pro platby
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');

        $this->template->title = $this->translator->translate('eshop.settings.title');
        $this->template->headerManagementMethod = $this->translator->translate('eshop.orderMethods.payment.titlePayment');
        $this->template->methods = $this->paymentMethodsManager->getAllPublished(PaymentMethodsManager::TABLE_NAME);
    }

    /**
     * @actionName manage
     * @actionDescription Editace způsobu platby - naplnění formáláře.
     * Naplní formulář hodnotami, pokud editujeme existující metodu a nastavím metodu do komponenty pro obrázky
     * @param string $id ID metody, kterou editujeme; pokud není zadán, přidá se metoda jako nová
     */
    public function actionManage($id) {
        if ($id && ($method = $this->paymentMethodsManager->getById(PaymentMethodsManager::TABLE_NAME, PaymentMethodsManager::COLUMN_ID, $id))) {
            // IRow je read-only, pro manipulaci s ním ho musíme převést na pole.
            $methodArray = $method->toArray();
            // Nastavení hodnot do formuláře
            $this['methodForm']->setDefaults($methodArray);
        } else {
            // Zamezím editaci skryté metody - get product nic nevrátí, pokud je metoda už skrytá
            $this->redirect('PaymentMethods:management');
        }
    }

    /**
     * Editace metody
     * Použije se stejná šablona jako pro výpis všech metod platby, jen do formuláře se dosadí hodnoty.
     * Líší se pouze v nadpisu
     */
    public function renderManage() {
        $this->setView('management');

        $this->template->headerNewMethod = $this->translator->translate('eshop.orderMethods.payment.editPayment');
    }

    /**
     * @actionName management
     * @actionDescription Přehled a editace způsobů plateb za objednávky
     */
    public function renderManagement() {
        $this->template->headerNewMethod = $this->translator->translate('eshop.orderMethods.payment.newPayment');
    }

    /**
     * @actionName deleteMethod
     * @actionDescription Akce pro smazání metody platby
     */
    public function handleDeleteMethod($id) {
        $methodName = $this->paymentMethodsManager->clean(PaymentMethodsManager::TABLE_NAME, PaymentMethodsManager::COLUMN_ID, $id);

        // Zaznamení akce do DB
        $this->logAction('Smazání metody platby ' . $methodName);
        
        $this->presenter->flashMessage($this->translator->translate('eshop.orderMethods.flashes.deleteSuccess', ['methodName' => $methodName]), MessageType::SUCCESS);

        if ($this->presenter->isAjax()) {
            $this->presenter->redrawControl('ajaxNotification');
            $this->redrawControl("methodsSnippet");
            //$this['productDatagrid']->reload();
        } else {
            $this->presenter->redirect('this');
        }
    }

    /**
     * @return PaymentMethodsFormControl
     */
    protected function createComponentMethodForm() {
        return $this->paymentMethodsFormFactory->create();
    }

}
