<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\DataGrids\IProductDataGridFactory;
use App\EshopModule\Components\Forms\IProductFormFactory;;
use App\EshopModule\Components\Forms\ISimpleProductAttributeFormFactory;
use App\EshopModule\Components\Forms\IVariableProductAttributeFormFactory;
use App\EshopModule\Components\DataGrids\ProductDataGridControl;
use App\EshopModule\Components\Forms\ProductFormControl;
use App\EshopModule\Components\Forms\VariableProductAttributeFormControl;
use App\EshopModule\Model\CategoryManager;
use App\EshopModule\Model\ProductAttributeManager;
use App\EshopModule\Model\ProductManager;
use App\MediaModule\Components\IImagesFactory;
use App\MediaModule\Components\ImagesControl;
use App\MediaModule\Components\IUploadFormFactory;

/**
 * @resourceDescription Zpracováná požadavky na produkty v eshopu - celková manipulace s produkty.
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class ProductPresenter extends BaseEshopPresenter {

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var CategoryManager
     */
    private $categoryManager;

    /**
     * @var ProductAttributeManager
     */
    private $productAttributeManager;

    /**
     * @var IImagesFactory
     */
    private $imagesFactory;

    /**
     * @var IUploadFormFactory
     */
    private $uploadFormFactory;

    /**
     * @var IProductFormFactory
     */
    private $productFormFactory;

    /**
     * @var IVariableProductAttributeFormFactory
     */
    private $variableProductAttributeFormFactory;

    /**
     * @var ISimpleProductAttributeFormFactory
     */
    private $simpleProductAttributeFormFactory;

    /**
     * @var IProductDataGridFactory
     */
    private $productDataGridFactory;

    public $productId;


    public function __construct(
        ProductManager $productManager,
        CategoryManager $categoryManager,
        ProductAttributeManager $productAttributeManager,
        IImagesFactory $imagesFactory,
        IUploadFormFactory $uploadFormFactory,
        IProductFormFactory $productFormFactory,
        IVariableProductAttributeFormFactory $variableProductAttributeFormFactory,
        ISimpleProductAttributeFormFactory $simpleProductAttributeFormFactory,
        IProductDataGridFactory $productDataGridFactory)
    {
        parent::__construct();
        $this->productManager = $productManager;
        $this->categoryManager = $categoryManager;
        $this->productAttributeManager = $productAttributeManager;
        $this->imagesFactory = $imagesFactory;
        $this->uploadFormFactory = $uploadFormFactory;
        $this->productFormFactory = $productFormFactory;
        $this->variableProductAttributeFormFactory = $variableProductAttributeFormFactory;
        $this->simpleProductAttributeFormFactory = $simpleProductAttributeFormFactory;
        $this->productDataGridFactory = $productDataGridFactory;
    }

    /**
     * @return ImagesControl
     */
    protected function createComponentImages() {
        return $this->imagesFactory->create();
    }

    /**
     * @return \App\MediaModule\Components\UploadFormControl
     */
    protected function createComponentUploadForm() {
        return $this->uploadFormFactory->create();
    }

    /**
     * @actionName management
     * @actionDescription Vykreslení managementu (výpisu všech) produktů.
     */
    public function renderManagement() {
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName manage
     * @actionDescription Správa produktu - editace nebo vytvoření nového produktu
     * Naplní formulář hodnotami, pokud editujeme existující produkt a nastavím produkt do komponenty pro obrázky
     * @param string $url URL adresa produktu, který editujeme; pokud není zadána, přidá se produkt jako nový
     */
    public function actionManage($url) {
        $this->setLayout('layoutBackend');
        if ($url && ($product = $this->productManager->getProduct($url))) {
            // IRow je read-only, pro manipulaci s ním ho musíme převést na pole.
            $productArray = $product->toArray();
            $productArray['categories'] = $this->categoryManager->getProductCategories($product->product_id);
            // Nastavení hodnot do formuláře
            $this['productForm']->setDefaults($productArray);


            $this->productId = $product->product_id;
            $this->template->product = $product;

            if ($product->type == ProductManager::TYPE_VARIABLE) {
                $attributes = $this->productAttributeManager->getProductAttributes($product->product_id);
                foreach ($attributes as $attribute) {
                    $attributesArray['attribute_' . $attribute->attribute_id][] = $attribute->attribute_values_id;
                    $attributesArray['variants_' . $attribute->attribute_id] = $attribute->for_variant;
                }
                $attributesArray['product_id'] = $product->product_id;
                $this['variableProductAttributeForm']->setDefaults($attributesArray);
            } else {
                $attributes = $this->productAttributeManager->getProductAttributes($product->product_id);
                foreach ($attributes as $attribute) {
                    $attributesArray['attribute_' . $attribute->attribute_id] = $attribute->attribute_values_id;
                }
                $attributesArray['product_id'] = $product->product_id;
                $this['simpleProductAttributeForm']->setDefaults($attributesArray);
            }
        }
    }

    /**
     * Správa produktu - část pro předávání věcí do šablony.
     * @param string $url URL adresa produktu, který editujeme; pokud není zadána, přidá se produktu jako nový
     */
    public function renderManage($url) {
        $this->template->title = $url ? $this->translator->translate('eshop.product.editProduct') : $this->translator->translate('eshop.product.newProduct');
    }

    /**
     * @return ProductFormControl
     */
    protected function createComponentProductForm() {
        return $this->productFormFactory->create();
    }

    /**
     * @return VariableProductAttributeFormControl
     */
    protected function createComponentVariableProductAttributeForm() {
        return $this->variableProductAttributeFormFactory->create();
    }

    /**
     * @return \App\EshopModule\Components\Forms\SimpleProductAttributeFormControl
     */
    protected function createComponentSimpleProductAttributeForm() {
        return $this->simpleProductAttributeFormFactory->create();
    }

    /**
     * @return ProductDataGridControl
     */
    protected function createComponentProductDataGrid() {
        return $this->productDataGridFactory->create();
    }


}
