<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\DataGrids\IProductVariantsDataGridFactory;
use App\EshopModule\Components\DataGrids\ProductVariantsDataGridControl;
use App\EshopModule\Components\Forms\IProductVariantFormFactory;
use App\EshopModule\Components\Forms\IVariantFormFactory;
use App\EshopModule\Components\Forms\ProductVariantFormControl;
use App\EshopModule\Components\Forms\VariantFormControl;
use App\EshopModule\Model\CategoryManager;
use App\EshopModule\Model\ProductAttributeManager;
use App\EshopModule\Model\ProductManager;
use App\MediaModule\Components\IImagesFactory;
use App\MediaModule\Components\ImagesControl;
use App\MediaModule\Components\IUploadFormFactory;
use App\Model\Enum\MessageType;

/**
 * @resourceDescription Zpracováná požadavky na produkty v eshopu - manipulace s variantami produktů.
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class ProductVariantPresenter extends BaseEshopPresenter {

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var CategoryManager
     */
    private $categoryManager;

    /**
     * @var ProductAttributeManager
     */
    private $productAttributeManager;

    /**
     * @var IImagesFactory
     */
    private $imagesFactory;

    /**
     * @var IUploadFormFactory
     */
    private $uploadFormFactory;

    /**
     * @var IProductVariantsDataGridFactory
     */
    private $productVariantsDataGridFactory;

    /**
     * @var IProductVariantFormFactory
     */
    private $productVariantFormFactory;

    /**
     * @var IVariantFormFactory
     */
    private $variantFormFactory;

    public $productId;


    public function __construct(
        ProductManager $productManager,
        CategoryManager $categoryManager,
        ProductAttributeManager $productAttributeManager,
        IImagesFactory $imagesFactory,
        IUploadFormFactory $uploadFormFactory,
        IProductVariantsDataGridFactory $productVariantsDataGridFactory,
        IProductVariantFormFactory $productVariantFormFactory,
        IVariantFormFactory $variantFormFactory)
    {
        parent::__construct();
        $this->productManager = $productManager;
        $this->categoryManager = $categoryManager;
        $this->productAttributeManager = $productAttributeManager;
        $this->imagesFactory = $imagesFactory;
        $this->uploadFormFactory = $uploadFormFactory;
        $this->productVariantsDataGridFactory = $productVariantsDataGridFactory;
        $this->productVariantFormFactory = $productVariantFormFactory;
        $this->variantFormFactory = $variantFormFactory;
    }

    /**
     * @return ImagesControl
     */
    protected function createComponentImages() {
        return $this->imagesFactory->create();
    }

    /**
     * @return \App\MediaModule\Components\UploadFormControl
     */
    protected function createComponentUploadForm() {
        return $this->uploadFormFactory->create();
    }

    /**
     * @actionName editVariation
     * @actionDescription Editace varianty produktu
     */
    public function actionEdit($product_id) {
        $this->setLayout('layoutBackend');
        $product = $this->productManager->getProductFromId($product_id);
        $this->template->product = $product;
        $this['variantForm']->setDefaults($product);
        $this->template->title = $this->translator->translate('eshop.product.titleEditVariation');
    }

    /**
     * @actionName variants
     * @actionDescription Přehled variant konrétního produktu
     */
    public function actionManagement($productId) {
        $this->productId = $productId;
    }

    public function renderManagement($productId) {
        $this->setLayout('layoutBackend');
        $this->template->title = $this->translator->translate('eshop.product.title');

        $variants = $this->productManager->getVariants($productId)->fetchAll();
        $attributes = [];
        foreach ($variants as $num => $variant) {
            $attributes[$num] = $this->productAttributeManager->getProductAttributes($variant['product_id']);
        }
        $this->template->variants = $variants;
        $this->template->attributes = $attributes;
    }

    /**
     * @return ProductVariantFormControl
     */
    protected function createComponentProductVariantForm() {
        return $this->productVariantFormFactory->create();
    }

    /**
     * @return VariantFormControl
     */
    protected function createComponentVariantForm() {
        return $this->variantFormFactory->create();
    }

    /**
     * Create datagrid for Products
     * @return ProductVariantsDataGridControl
     */
    protected function createComponentProductVariantsDatagrid() {
        return $this->productVariantsDataGridFactory->create();
    }

    /**
     * @actionName deleteVariation
     * @actionDescription Smazání varianty produktu
     * @param int $id id varianty prodktu
     */
    public function actionDelete($id) {
        $product = $this->productManager->getProductFromId($id);
        $this->productManager->removeVariation($id);
        // Zaznamení akce do DB
        $this->logAction('Smazání varianty produktu ' . $id);
        $this->presenter->flashMessage( $this->translator->translate('eshop.product.deleteVariantSuccess', ['id' => $id]), MessageType::SUCCESS);

        $this->presenter->redirect('Product:variants', $product->parent_id);
    }


}
