<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\Forms\ISettingsFormFactory;
use App\Model\Enum\MessageType;
use App\EshopModule\Model\SettingsManager;
use App\EshopModule\Components\Forms\SettingsFormControl;
use App\Services\FormatHelperService;

/**
 * @resourceDescription Zpracovává požadavky na účetní nastavení.
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class SettingsPresenter extends BaseEshopPresenter {

    /**
     * @var SettingsManager Instance třídy modelu pro práci s účetním nastavením v e-shopu.
     */
    private $settingsManager;

    /**
     * @var FormatHelperService Pomocná služba pro formátování data, jména adresy atd.
     */
    private $formatHelperService;

    /**
     * @var ISettingsFormFactory
     */
    private $settingsFormFactory;

    public function __construct(SettingsManager $settingsManager, FormatHelperService $formatHelperService, ISettingsFormFactory $settingsFormFactory) {
        parent::__construct();
        $this->settingsManager = $settingsManager;
        $this->formatHelperService = $formatHelperService;
        $this->settingsFormFactory = $settingsFormFactory;
    }

    /**
     * Nastavení layoutu pro backend. Metoda se volá před render metodami.
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');
    }

    /**
     * @actionName default
     * @actionDescription Přehled a editace nastavení - účetní, prodejce, podpis, platnost
     */
    public function renderDefault() {
        $this->template->addFilter('name', [$this->formatHelperService, 'formatName']);
        $this->template->allSettings = $this->settingsManager->getAllPublished(SettingsManager::TABLE_NAME)->order(SettingsManager::COLUMN_VALID_FROM . ' DESC');
    }

    /**
     * @actionName delete
     * @actionDescription Odstranění nastavení.
     * @param int $id ID nastavení
     */
    public function handleDelete($id) {
        $this->settingsManager->deleteSettings($id);
        
        // Zaznamení akce do DB
        $this->logAction('Smazání účetního nastavení s ID ' . $id);
        
        $this->flashMessage($this->translator->translate('eshop.settings.flashes.deleteSuccess'), MessageType::SUCCESS);

        if ($this->isAjax()) {
            $this->redrawControl('ajaxNotification');
            $this->redrawControl("settingsSnippet");
            $this->redrawControl("settingsForm");
        } else {
            $this->redirect('this');
        }
    }

    /**
     * @return SettingsFormControl
     */
    protected function createComponentSettingsForm() {
        return $this->settingsFormFactory->create();
    }

}
