<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\EshopModule\Presenters;

use App\EshopModule\Components\Forms\IShippingMethodsFormFactory;
use App\EshopModule\Model\ShippingMethodsManager;
use App\EshopModule\Components\Forms\ShippingMethodsFormControl;
use App\Model\Enum\MessageType;

/**
 * @resourceDescription Zpracovává požadavky na nastvení metod doručení produktů - tvorba a editace, přehled.
 * @package App\EshopModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class ShippingMethodsPresenter extends BaseEshopPresenter {

    /**
     * @var ShippingMethodsManager Instance třídy modelu pro práci s metodami dopravy.
     */
    private $shippingMethodsManager;

    /**
     * @var IShippingMethodsFormFactory
     */
    private $shippingMethodsFormFactory;

    public function __construct(ShippingMethodsManager $shippingMethodsManager, IShippingMethodsFormFactory $shippingMethodsFormFactory) {
        parent::__construct();
        $this->shippingMethodsManager = $shippingMethodsManager;
        $this->shippingMethodsFormFactory = $shippingMethodsFormFactory;
    }

    /**
     * Nastavení layoutu pro backend. Metoda se volá před render metodami.
     * Všechny metody presneteru jsou součástí backendu - jeden layout
     */
    public function beforeRender() {
        parent::beforeRender();
        $this->setLayout('layoutBackend');

        $this->template->title = $this->translator->translate('eshop.settings.title');
        $this->template->headerManagementMethod = $this->translator->translate('eshop.orderMethods.transport.titleTransport');
        $this->template->methods = $this->shippingMethodsManager->getAllPublished(ShippingMethodsManager::TABLE_NAME);
    }

    /**
     * @actionName manage
     * @actionDescription Editace způsobu dopravy
     * Naplní formulář hodnotami, pokud editujeme existující metodu a nastavím metodu do komponenty pro obrázky
     * @param string $id ID metody, kterou editujeme; pokud není zadán, přidá se metoda jako nová
     */
    public function actionManage($id) {
        if ($id && ($method = $this->shippingMethodsManager->getById(ShippingMethodsManager::TABLE_NAME, ShippingMethodsManager::COLUMN_ID, $id))) {
            // IRow je read-only, pro manipulaci s ním ho musíme převést na pole.
            $methodArray = $method->toArray();
            // Nastavení hodnot do formuláře
            $this['methodForm']->setDefaults($methodArray);
        } else {
            // Zamezím editaci skryté metody - get product nic nevrátí, pokud je metoda už skrytá
            $this->redirect('ShippingMethods:management');
        }
    }

    /**
     * Editace metody
     * Použije se stejná šablona jako pro výpis všech metod dopravy, jen do formuláře se dosadí hodnoty. 
     * Líší se pouze v nadpisu
     */
    public function renderManage() {
        $this->setView('management');

        $this->template->headerNewMethod = $this->translator->translate('eshop.orderMethods.transport.editTransport');
    }

    /**
     * @actionName management
     * @actionDescription Přehled a editace nastavení pro dopravy
     */
    public function renderManagement() {
        $this->template->headerNewMethod = $this->translator->translate('eshop.orderMethods.transport.newTransport');
    }

    /**
     * @actionName deleteMethod
     * @actionDescription Smazání položky pro nastavení dopravy
     */
    public function handleDeleteMethod($id) {
        $methodName = $this->shippingMethodsManager->clean(ShippingMethodsManager::TABLE_NAME, ShippingMethodsManager::COLUMN_ID, $id);

        // Zaznamení akce do DB
        $this->logAction('Smazání způsobu dopravy ' . $methodName);
        
        $this->presenter->flashMessage($this->translator->translate('eshop.orderMethods.flashes.deleteSuccess', ['methodName' => $methodName]), MessageType::SUCCESS);

        if ($this->presenter->isAjax()) {
            $this->presenter->redrawControl('ajaxNotification');
            $this->redrawControl("methodsSnippet");
            //$this['productDatagrid']->reload();
        } else {
            $this->presenter->redirect('this');
        }
    }

    /**
     * @return ShippingMethodsFormControl
     */
    protected function createComponentMethodForm() {
        return $this->shippingMethodsFormFactory->create();
    }

}
