<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use Nette\Application\UI\Control;
use App\Components\IPriceControlFactory;
use App\MediaModule\Components\IMainImageFactory;
use Nette\Utils\ArrayHash;
use Nette\Security\User;

/**
 * Componenta pro vykreslení a správu modálu při přidání produktu do košíku
 * @package App\FrontModule\Component
 *  
 * @author Jan Vodák <jan at ideatech.cz>
 */
class AddedProductModalControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/AddedProductModal/modal.latte';

    /** @var IPriceControlFactory Instance třídy továrničky na tvorbu komponent pro vykreslování ceny. */
    private $priceControlFactory;

    /** @var IMainImageFactory */
    private $mainImageFactory;

    /**
     * Konstruktor komponenty pro vykreslení modalu.
     */
    public function __construct(IPriceControlFactory $priceControlFactory, IMainImageFactory $mainImageFactory) {
        parent::__construct();
        
        $this->priceControlFactory = $priceControlFactory;
        $this->mainImageFactory = $mainImageFactory;
    }

    /**
     * Výchozí metoda pro vykreslení modalu při přidání produktu do košíku
     * @param ArrayHash         $addedProduct Description
     * @param null|ArrayHash    $settings Descriptio
     * @param null|User $user   $user Description
     */
    public function render($addedProduct, $settings, $user) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);

        // Předá přidaný produktu pro vykreslení do šablony.
        $this->template->addedProduct = $addedProduct;
        // Předá nastavení pro komponentu price pro vykreslení do šablony.
        $this->template->settings = $settings;
        // Předá uživatele pro komponentu price pro vykreslení do šablony.
        $this->template->user = $user;

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Vytváří a vrací komponentu pro vykreslení ceny.
     * @return PriceControl komponenta pro vykreslení ceny
     */
    protected function createComponentPrice() {
        return $this->priceControlFactory->create();
    }

    /**
     * @return MainImageControl
     */
    protected function createComponentMainImage() {
        return $this->mainImageFactory->create();
    }

}

/**
 * Interface pro vytvoření pomocné komponenty pro vykreslování modalu s využitím autowiringu.
 * Autowiring spočívá v implementaci pomocí interface a definici v configu, kde si v settings volám setr a nastavují měnu
 * Automatiké vytvoření se všemi závislostmi injectovanými pomocí DI klasicky v kontruktoru + přes metodu createComponent a zavolání create
 * 
 * @package App\FrontModule\Component
 */
interface IAddedProductModalControlFactory {

    /**
     * Vrací novou pomocnou komponentu pro vykreslování modalu s automaticky inejectovanými závislostmi.
     * @return AddedProductModalControl pomocná komponenta pro vykreslení modalu
     */
    public function create();
}
