<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\Forms\BaseFormFactory;
use App\Model\Enum\MessageType;
use App\Model\UserManager;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use Nette\Security\AuthenticationException;

/**
 * Komponenta pro změnu uživatelského hesla
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class ChangePasswordFormControl extends Control {

    /** Cesta k souborům šablon pro tuto komponentu. */
    const TEMPLATE_PATH = '/../templates/components/ChangePasswordForm/';

    /** Cesta ke globální šabloně formulářů. */
    const FORM_PATH = __DIR__ . '/../../../templates/components/form.latte';

    /**
     * @var UserManager
     */
    private $userManager;

    /**
     * @var BaseFormFactory
     */
    private $baseFormFactory;

    public function __construct(UserManager $userManager, BaseFormFactory $baseFormFactory) {
        parent::__construct();
        $this->userManager = $userManager;
        $this->baseFormFactory = $baseFormFactory;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE_PATH . 'form.latte');

        //Předání do šablony cestu pro automatické vykreslení formuláře
        $this->template->formPath = self::FORM_PATH;

        $this['changePasswordForm']->setDefaults(array(UserManager::COLUMN_ID => $this->presenter->getUser()->getId()));

        // Vykreslí komponentu.
        $this->template->render();
    }

    public function createComponentChangePasswordForm() {
        $form = $this->baseFormFactory->create();

        //Skryté pole pro případné ID uživatele - pokud vytvářím nového uživatele z adminu, toto mi pomáhá při zpracování formu
        $form->addHidden('user_id');

        $form->addPassword('old_password', 'Stávající heslo')
                ->setRequired();

        $form->addPassword('password', 'Nové heslo')
                ->setAttribute('title', 'Zadejte heslo alespoň na 6 znaků.')
                ->setRequired()
                ->addRule(Form::PATTERN, 'Heslo nesmí obsahovat diakritiku a musí být dlouhé alespoň 6 znaků.', '.{6,}');
        $form->addPassword('password_repeat', 'Nové heslo znovu')
                ->setOmitted()
                ->setAttribute('title', 'Zadejte heslo alespoň na 6 znaků.')
                ->setRequired()
                ->addRule(Form::EQUAL, 'Hesla nesouhlasí.', $form['password']);


        $form->addSubmit('submit', 'Potvrdit')
                ->setAttribute('id', 'changeUserPasswordSubmit');
        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    private function succeeded(Form $form, ArrayHash $values) {
        $presenter = $form->getPresenter();

        try {
            $this->userManager->changePassword($values);
            $presenter->flashMessage('Heslo bylo úspěšně změněno', MessageType::SUCCESS);
        } catch (AuthenticationException $ex) {
            $presenter->flashMessage($ex->getMessage(), MessageType::ERROR);
        }

        if ($presenter->isAjax()) {
            // Překreslím snippet s ajaxovýma zprávama
            $presenter->redrawControl("ajaxNotification");
        } else {
            // Není to ajax - překreslení stránky
            $presenter->redirect('this');
        }
    }

}

/**
 * Interface IChangePasswordFormFactory
 * @package App\FrontModule\Components
 */
interface IChangePasswordFormFactory {

    /**
     * @return ChangePasswordFormControl
     */
    public function create();
}
