<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use App\Forms\BaseFormFactory;

/**
 * Komponenta pro filtrování produktů
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class FilterFormControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/FilterForm/form.latte';

    /** @var BaseFormFactory Továrnička na formuláře. */
    private $formFactory;

    /**
     * FilterFormControl constructor.
     * @param BaseFormFactory $formFactory
     */
    public function __construct(BaseFormFactory $formFactory) {
        parent::__construct();
        $this->formFactory = $formFactory;
    }
    
     /**
     * Pomocná metoda pro předávání defaultních hodnot
     * Metoda se volá z presenteru úplně stejně jak předtím
     * Provolání metod
     * @param Array $values Defaultní hodnoty pro formulář
     */
    public function setDefaults(Array $values){
        // Nastavení výchozí hodnoty formuláře pro hodnocení produktu.
        $this['filterForm']->setDefaults($values);
    }

    /** Vykreslí komponentu formuláře pro přidání hodnocení k produktu. */
    public function render($formPath) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        
        $this->template->formPath = $formPath;

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Vytváří a vrací komponentu formuláře pro filtrování produktů.
     * Parametry filteru zůstávájí v URL a URL pak zpracovává :Product:default a podle toho zobrazuje produkty
     * @return Form formulář pro filtrování produktů
     */
    protected function createComponentFilterForm() {
        $form = $this->formFactory->create();
        // Odesílání metodou $_GET, aby filtrovací parametry zůstaly v URL adrese
        $form->setMethod(Form::GET);
        $form->addHidden('phrase');
        $form->addSelect('order_by', 'Řadit podle', array(
            'rating' => 'Hodnocení',
            'lowest_price' => 'Nejnižší ceny',
            'highest_price' => 'Nejvyšší ceny',
            'newest' => 'Nejnovější'
        ))->setRequired();
        $form->addText('start_price', 'Cena od')->setType('number');
        $form->addText('end_price', 'Cena do')->setType('number');
        $form->addCheckbox('in_stock', 'Skladem');
        $form->addSubmit('filter', 'Filtrovat');
        return $form;
    }

}

/**
 * Interface IFilterFormControl
 * @package App\FrontModule\Components
 */
interface IFilterFormFactory {

    /**
     * @return FilterFormControl
     */
    public function create();
}
