<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\FrontModule\Components\IHeaderSearchFormFactory;
use App\FrontModule\Components\IPageMenuFactory;
use App\FrontModule\Components\INewsletterFormFactory;
use App\Services\FormatHelperService;
use Nette\Application\UI\Control;
use App\EshopModule\Model\SettingsManager;
use App\Model\PersonManager;
use App\CoreModule\Model\SocialManager;
use App\CoreModule\Model\PartnerManager;

/**
 * Komponenta pro vykreslení footeru stránky
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class FooterControl extends Control {

    const TEMPLATE_PATH = '/../templates/components/Footer/';

    /** @var SettingsManager Instance třídy modelu pro práci s účetním nastavením. */
    private $settingsManager;
    
    /**
     * @var PersonManager Instance třídy modelu pro práci s osobami v e-shopu. 
     */
    private $personManager;
    
     /**
     * @var SocialManager
     */
    private $socialManager;

    /**
     * @var PartnerManager
     */
    private $partnerManager;

    /**
     * @var IPageMenuFactory
     */
    private $pageMenuFactory;

    /**
     * @var IHeaderSearchFormFactory 
     */
    private $headerSearchFormControl;

    /**
     * @var INewsletterFormFactory
     */
    private $newsletterFormFactory;
    
    /**
     * @var FormatHelperService Pomocná služba pro formátování data, jména adresy atd.
     */
    private $formatHelperService;

    /**
     * FooterControl constructor.
     * @param IPageMenuFactory $pageMenuFactory
     * @param IHeaderSearchFormFactory $headerSearchFormControl
     * @param INewsletterFormFactory $newsletterFormFactory
     * @param FormatHelperService $formatHelperService
     * @param SettingsManager $settingsManager
     * @param PersonManager $personManager
     * @param SocialManager $socialManager
     * @param PartnerManager $partnerManager
     */
    public function __construct(IPageMenuFactory $pageMenuFactory, IHeaderSearchFormFactory $headerSearchFormControl, INewsletterFormFactory $newsletterFormFactory, FormatHelperService $formatHelperService, SettingsManager $settingsManager, PersonManager $personManager, SocialManager $socialManager, PartnerManager $partnerManager) {
        parent::__construct();
        $this->pageMenuFactory = $pageMenuFactory;
        $this->headerSearchFormControl = $headerSearchFormControl;
        $this->newsletterFormFactory = $newsletterFormFactory;
        $this->formatHelperService = $formatHelperService;
        $this->settingsManager = $settingsManager;
        $this->personManager = $personManager;
        $this->socialManager = $socialManager;
        $this->partnerManager = $partnerManager;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render() {
        // Nastaví šablonu komponenty
        $this->template->setFile(__DIR__ . self::TEMPLATE_PATH . 'footer.latte');
        
        // Předání sociálních sítí a partnerů do šablony
        $this->template->social = $this->socialManager->getAll();
        $this->template->partners = $this->partnerManager->getAll();

        // Výchozí nastavení
        $setting = $this->settingsManager->getSettings();
        
        if($setting){
            // Údaje prodejce
            $seller = $this->personManager->getPerson($setting[SettingsManager::COLUMN_SELLER]);
            $sellerDetail = $seller->ref(PersonManager::TABLE_DETAIL_NAME, PersonManager::COLUMN_PERSON_DETAIL_ID);
            $sellerAddress = $seller->ref(PersonManager::TABLE_ADDRESS_NAME, PersonManager::COLUMN_ADDRESS_ID);
            
            // Předání proměnných do šablony
            $this->template->setting = $setting;
            $this->template->sellerDetail = $sellerDetail;
            $this->template->sellerAddress = $sellerAddress;
        }else{
            // Předání proměnných do šablony
            $this->template->setting = null;
            $this->template->sellerDetail = null;
            $this->template->sellerAddress = null;
        }

        // Přidání filteru pro formátování jména
        $this->template->addFilter('name', [$this->formatHelperService, 'formatName']);
        // Přidání filteru pro adresy
        $this->template->addFilter('address', [$this->formatHelperService, 'formatAddress']);

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * @return \App\FrontModule\Components\PageMenuControl
     */
    protected function createComponentPageMenu() {
        return $this->pageMenuFactory->create();
    }

    /**
     * @return \App\FrontModule\Components\HeaderSearchFormFactory
     */
    protected function createComponentHeaderSearchForm() {
        return $this->headerSearchFormControl->create();
    }

    /**
     * @return \App\FrontModule\Components\NewsletterFormControl
     */
    protected function createComponentNewsletterForm() {
        return $this->newsletterFormFactory->create();
    }

}

/**
 * Interface IFooterFactory
 * @package App\FrontModule\Components
 */
interface IFooterFactory {

    /**
     * @return FooterControl
     */
    public function create();
}
