<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\Components\IPriceControlFactory;
use App\FrontModule\Components\IHeaderSearchFormFactory;
use App\EshopModule\Model\OrderManager;
use App\EshopModule\Model\CurrencyManager;
use App\EshopModule\Model\SettingsManager;
use Nette\Application\UI\Control;
use App\Model\Enum\MessageType;

/**
 * Komponenta pro vykreslení headeru stránky
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class HeaderControl extends Control {

    const TEMPLATE_PATH = '/../templates/components/Header/';

    /**
     * @var OrderManager
     */
    private $orderManager;

    /**
     * @var CurrencyManager
     */
    private $currencyManager;

    /**
     * @var IPageMenuFactory
     */
    private $pageMenuFactory;

    /**
     * @var IPriceControlFactory
     */
    private $priceControlFactory;

    /**
     * @var IHeaderSearchFormFactory 
     */
    private $headerSearchFormControl;

    /**
     * @var SettingsManager
     */
    private $settingsManager;

    /**
     * HeaderControl constructor.
     * @param OrderManager $orderManager
     * @param CurrencyManager $currencyManager
     * @param IPageMenuFactory $pageMenuFactory
     * @param IPriceControlFactory $priceControlFactory
     * @param SettingsManager $settingsManager
     * @param IHeaderSearchFormFactory $headerSearchFormControl
     */
    public function __construct(OrderManager $orderManager, CurrencyManager $currencyManager, IPageMenuFactory $pageMenuFactory, IPriceControlFactory $priceControlFactory, SettingsManager $settingsManager, IHeaderSearchFormFactory $headerSearchFormControl) {
        parent::__construct();
        $this->orderManager = $orderManager;
        $this->currencyManager = $currencyManager;
        $this->pageMenuFactory = $pageMenuFactory;
        $this->priceControlFactory = $priceControlFactory;
        $this->settingsManager = $settingsManager;
        $this->headerSearchFormControl = $headerSearchFormControl;
    }

    /**
     * Výchozí metoda pro vykreslení komponenty
     */
    public function render() {
        // Nastaví šablonu komponenty
        $this->template->setFile(__DIR__ . self::TEMPLATE_PATH . 'header.latte');
        $this->template->cart = $this->orderManager->getOrderSummary();
        // Předání měn a kurzů do šablony
        $this->template->currencies = $this->currencyManager->getAllCurrencies(); // Výpis měn pro zvolení
        // Pomocná prom. pro výpis class u měn
        $this->template->actualCurrency = $this->currencyManager->getActualCurrency();
        
        // Fakturační nastavení
        $this->template->settings = $this->settingsManager->getSettings();
        
        if ($this->presenter->getUser()->isLoggedIn()) {
            // Pokud je uživatel přihlášený, získám si jeho jméno
            $this->template->username = $this->presenter->getUser()->getIdentity()->username;
           
        }else{
            $this->template->username = null;
        }

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * @return PageMenuControl
     */
    protected function createComponentPageMenu() {
        return $this->pageMenuFactory->create();
    }

    /**
     * @return \App\Components\PriceControl
     */
    protected function createComponentPrice() {
        return $this->priceControlFactory->create();
    }

    /**
     * @return IHeaderSearchFormFactory
     */
    protected function createComponentHeaderSearchForm() {
        return $this->headerSearchFormControl->create();
    }

    /**
     * Nastavím do cookies aktuální měnu a obnovím stránku.
     * Defaultní je česká měna
     * Vše hlavní se děje v komponentě price, kde se pracuje s cenami a měnami.
     * Všechny výpisy cen a součtu cen v objednávkách - celková objednávka i v adminu tuto komponentu využívají
     * @param int $currencyId id měny, která se uloží do cookies
     */
    public function handleSetCurrency($currencyId) {
        $this->currencyManager->createCurrencyCookie($currencyId);
        $this->presenter->flashMessage('Měna byla úspěšně nastavena.',  MessageType::SUCCESS);
        $this->redirect('this');
    }

}

/**
 * Interface IHeaderFactory
 * @package App\FrontModule\Components
 */
interface IHeaderFactory {

    /**
     * @return HeaderControl
     */
    public function create();
}
