<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use App\Forms\BaseFormFactory;
use Nette\Utils\ArrayHash;

/**
 * Komponenta pro vykreslení formuláře na hledání produktů umístěného v hlavičce
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class HeaderSearchFormControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/HeaderSearchForm/form.latte';

    /** @var BaseFormFactory Továrnička na formuláře. */
    private $formFactory;

    /**
     * HeaderSearchFormControl constructor.
     * @param BaseFormFactory $formFactory
     */
    public function __construct(BaseFormFactory $formFactory) {
        parent::__construct();
        $this->formFactory = $formFactory;
    }

    /** Vykreslí komponentu formuláře pro správu osob. */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(__DIR__ . self::TEMPLATE);

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Vytváří a vrací komponentu formuláře pro vyhledávání produktů.
     * Nemusím vyplňovat všechny informace jako label nebo placeholder - vykresluji ručně
     * @return Form formulář pro vyhledávání produktů
     */
    public function createComponentHeaderSearchForm() {
        $form = $this->formFactory->create();
        $form->addText('phrase')->setRequired();
        $form->addSubmit('send')
                ->setAttribute('id', 'headerSearchSubmit');
        $form->onSuccess[] = [$this, 'headerSearchFormSucceeded'];
        return $form;
    }

    /**
     * Funkce se vykonaná při úspěšném odeslání formuláře pro vyhledávání produktů.
     * @param Form $form formulář pro vyhledávání produktů
     * @param ArrayHash $values odeslané hodnoty formuláře
     */
    public function headerSearchFormSucceeded($form, $values) {
        $presenter = $form->getPresenter();
        $presenter->redirect(':Front:Product:', ['phrase' => $values->phrase]);
    }

}

/**
 * Interface IContactCityFormFactory
 * @package App\FrontModule\Components
 */
interface IHeaderSearchFormFactory {

    /**
     * @return HeaderSearchFormControl
     */
    public function create();
}
