<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\EmailModule\Model\EmailExistsException;
use App\EmailModule\Model\EmailManager;
use App\Forms\BaseFormFactory;
use App\Mailing\NewsletterMail;
use App\Services\MailFactory;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Http\Response;
use Nette\Utils\ArrayHash;
use Nette\Utils\DateTime;
use App\Model\Enum\MessageType;

/**
 * Class NewsletterFormControl
 * @package App\FrontModule\Components
 * 
 * @author Jan Vodák <jan at ideatech.cz>
 */
class NewsletterFormControl extends Control {

    const TEMPLATE_PATH = '/../templates/components/NewsletterForm/';
    
    /** Cesta ke globální šabloně formulářů. */
    const FORM_PATH = __DIR__ . '/../../../templates/components/form.latte';

    /**
     * @var BaseFormFactory
     */
    private $baseFormFactory;

    /**
     * @var EmailManager
     */
    private $emailManager;

    /**
     * @var MailFactory
     */
    private $mailFactory;

    /**
     * @var Response
     */
    private $httpResponse;

    /**
     * NewsletterFormControl constructor.
     * @param BaseFormFactory $baseFormFactory
     * @param EmailManager $emailManager
     * @param MailFactory $mailFactory
     * @param Response $httpResponse
     */
    public function __construct(BaseFormFactory $baseFormFactory, EmailManager $emailManager, MailFactory $mailFactory, Response $httpResponse) {
        parent::__construct();
        $this->baseFormFactory = $baseFormFactory;
        $this->emailManager = $emailManager;
        $this->mailFactory = $mailFactory;
        $this->httpResponse = $httpResponse;
    }

    public function render() {
        $this->template->setFile(__DIR__ . self::TEMPLATE_PATH . 'form.latte');
        
        $this->template->formPath = self::FORM_PATH;
        
        $this->template->render();
    }

    public function createComponentNewsletterForm() {
        $form = $this->baseFormFactory->create();
        $form->elementPrototype->addAttributes(['class' => 'ajax']);

        $form->addText('email', 'Email')
                ->setType('email')
                ->addRule(Form::EMAIL, 'Email musí být ve správném tvaru.')
                ->setRequired()
                ->getControlPrototype()
                ->addAttributes(['class' => 'form-control', 'placeholder' => 'Váš email']);
         $form->addCheckbox('agreement', 'Souhlasím se zasíláním novinek na email')
                ->setRequired('Je potřeba souhlasit s podmínkami')
                ->setDefaultValue(true);

        $form->addSubmit('submit', 'Odeslat')
                ->getControlPrototype()
                ->setAttribute('id', 'newsletterSubmit')
                ->addAttributes(['class' => 'button-blue-cart']);

        $form->onSuccess[] = function (Form $form, ArrayHash $values) {
            $this->succeeded($form, $values);
        };
        return $form;
    }

    /**
     * @param Form $form
     * @param ArrayHash $values
     */
    private function succeeded(Form $form, ArrayHash $values) {
        try {
            $data = ArrayHash::from([
                        'email' => $values->email,
                        'date' => new DateTime(),
                        'source' => 'NewsletterForm',
                        'token' => sha1($values->email . 'NewsletterForm' . random_int(0, 255)),
                        'valid' => 0
            ]);
            $row = $this->emailManager->addEmail($data);

            /** @var NewsletterMail $email */
            $email = $this->mailFactory->createByType(NewsletterMail::class, ['token' => $data->token, 'recipient' => $values->email]);
            $email->send();

            $this->httpResponse->setCookie('newsletterForm', 1, '100 years', null, null, null, false);

            $this->presenter->flashMessage('Děkujeme za Váš zájem, na email jsme Vám poslali potvrzení.', MessageType::SUCCESS);
        } catch (EmailExistsException $e) {
            $this->presenter->flashMessage($e->getMessage(), 'danger');
        }

        $this->presenter->redrawControl('ajaxNotification');
    }

}

/**
 * Interface INewsletterFormFactory
 * @package App\FrontModule\Components
 */
interface INewsletterFormFactory {

    /**
     * @return NewsletterFormControl
     */
    public function create();
}
