<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\Components\IPriceControlFactory;
use App\MediaModule\Components\IMainImageFactory;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use App\Forms\BaseFormFactory;
use Nette\Utils\ArrayHash;
use App\EshopModule\Model\OrderManager;
use App\EshopModule\Model\ShippingMethodsManager;
use App\EshopModule\Model\PaymentMethodsManager;

/**
 * Komponenta pro přidávání metody dopravy a platby do objednávky
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class OrderMethodsFormControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/OrderMethodsForm/form.latte';

    /** @var BaseFormFactory Továrnička na formuláře. */
    private $formFactory;

    /** @var OrderManager */
    private $orderManager;

    /** @var ShippingMethodsManager */
    private $shippingMethodsManager;
    
    /** @var PaymentMethodsManager */
    private $paymentMethodsManager;

    /**
     * @var IMainImageFactory Instance třídy pro práci s hlavním obrázkem
     */
    private $mainImageFactory;

    /** @var IPriceControlFactory Instance třídy továrničky na tvorbu komponent pro vykreslování ceny. */
    private $priceControlFactory;

    /**
     * OrderMethodsFormControl constructor.
     * @param BaseFormFactory $formFactory
     * @param OrderManager $orderManager
     * @param ShippingMethodsManager $shippingMethodsManager
     * @param PaymentMethodsManager $paymentMethodsManager
     * @param IMainImageFactory $mainImageFactory
     * @param IPriceControlFactory $priceControlFactory
     */
    public function __construct(BaseFormFactory $formFactory, OrderManager $orderManager, ShippingMethodsManager $shippingMethodsManager, PaymentMethodsManager $paymentMethodsManager, IMainImageFactory $mainImageFactory, IPriceControlFactory $priceControlFactory) {
        parent::__construct();
        $this->formFactory = $formFactory;
        $this->orderManager = $orderManager;
        $this->shippingMethodsManager = $shippingMethodsManager;
        $this->paymentMethodsManager = $paymentMethodsManager;
        $this->mainImageFactory = $mainImageFactory;
        $this->priceControlFactory = $priceControlFactory;
    }

    /** Vykreslí komponentu formuláře pro přidání metod dopravy a platby do objednávky. */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(__DIR__ . self::TEMPLATE);

        // Vykreslí komponentu.
        $this->template->render();
    }

    /**
     * Pomocná metoda pro předávání defaultních hodnot
     * Metoda se volá z presenteru úplně stejně jak předtím
     * Provolání metod
     * @param Array $values Defaultní hodnoty pro formulář
     */
    public function setDefaults(Array $values) {
        // Nastavení výchozí hodnoty formuláře pro hodnocení produktu.
        $this['reviewForm']->setDefaults($values);
    }

    /**
     * Vytváří a vrací komponentu formuláře pro výběr platební metody.
     * @return Form formulář pro výběr platební metody
     */
    protected function createComponentPaymentForm() {
        $form = $this->formFactory->create();

        //$shipping_methods = $this->productManager->getPaymentMethods();
        $shipping_methods = $this->shippingMethodsManager->getShippingMethods($this->orderManager->getOrderSummary());
        $payment_methods = $this->paymentMethodsManager->getPaymentMethods($this->orderManager->getOrderSummary());

        $deliveryProductId = $this->orderManager->getOrder()->delivery_product_id;
        $form->addRadioList('delivery_product_id', 'Způsob dopravy', $shipping_methods);
        //->setDefaultValue($deliveryProductId ? $deliveryProductId : key($shipping_methods));

        $paymentProductId = $this->orderManager->getOrder()->payment_product_id;
        $form->addRadioList('payment_product_id', 'Způsob platby', $payment_methods);
        //->setDefaultValue($paymentProductId ? $paymentProductId : key($payment_methods));

        $form->addSubmit('submit', 'Pokračovat na sohrn objednávky')
                ->setAttribute('id', 'orderMethodsSubmit');
        $form->onSuccess[] = [$this, 'paymentFormSucceeded'];

        return $form;
    }

    /**
     * Funkce se vykonaná při úspěšném odeslání formuláře pro výběr platební metody.
     * @param Form      $form   formulář pro výběr platební metody
     * @param ArrayHash $values odeslané hodnoty formuláře
     */
    public function paymentFormSucceeded($form, $values) {
        $presenter = $form->getPresenter();

        $this->orderManager->setDeliveryProduct($values->delivery_product_id);
        $this->orderManager->setPaymentProduct($values->payment_product_id);

        $presenter->redirect(':Front:Order:summary');
    }

    /**
     * @return \App\MediaModule\Components\MainImageControl
     */
    protected function createComponentMainImage() {
        return $this->mainImageFactory->create();
    }

    /**
     * @return \App\Components\PriceControl
     */
    protected function createComponentPrice() {
        return $this->priceControlFactory->create();
    }

}

/**
 * Interface IOrderMethodsFormFactory
 * @package App\FrontModule\Components
 */
interface IOrderMethodsFormFactory {

    /**
     * @return OrderMethodsFormControl
     */
    public function create();
}
