<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use Nette\Application\UI\Control;
use Nette\Security\User;

/**
 * Komponenta pro vykreslení průchodu stavu objednávky - košík -zákazník - platba - rekapitulace
 * @package App\EshopModule\Components
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class OrderStateControl extends Control
{

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/OrderState/order.latte';

    /** Konstanty reprezentující stav objednávky. */
    const
        STATE_CART = 1,
        STATE_USER = 2,
        STATE_PAYMENT = 3,
        STATE_RECAPITULATION = 4;

    /** @var User Uživatel. */
    private $user;

    /**
     * Konstruktor komponenty pro vykreslení stavu objednávky.
     * @param User $user automaticky injektovaná třída uživatele
     */
    public function __construct(User $user)
    {
        parent::__construct();
        $this->user = $user;
    }

    /**
     * Vykresluje komponentu stavu objednávky - defaultně košík.
     * @param int $state aktuální stav objednávky - index stavu reprezentován konstanami 1-4
     */
    public function render($state = self::STATE_CART)
    {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);

        // Předává parametry do šablony.
        // Pole položek widgetu - položka má ikonu, titulek, odkaz viditelnost
        $this->template->items = [
            [
                'icon' => 'shopping-cart',
                'title' => 'Košík',
                'href' => ':Front:Order:',
                'visible' => true,
            ],
            // Pokud je uživatel přihlášený, nebude podstupovat krok vyplnění údajů a proto zde ikona nebude.
            // Update: Moznost zmenit dodaci udaje, tudiz se ikona nove zobrazi vzdy.
            [
                'icon' => 'user',
                'title' => 'Dodací údaje',
                'href' => (!$this->user->isLoggedIn() ? ':Front:Person:register' : ':Front:Person:manageInOrder'),
                'visible' => true,
            ],
            [
                'icon' => 'credit-card',
                'title' => 'Doprava a platby',
                'href' => ':Front:Order:payment',
                'visible' => true,
            ],
            [
                'icon' => 'list-alt',
                'title' => 'Souhrn',
                'href' => ':Front:Order:summary',
                'visible' => true,
            ],
        ];

        // Mám konstany 1-4, pole se indexuje od 0 => potřebuju 0-3
        $this->template->state = --$state;

        // Vykreslí komponentu.
        $this->template->render();
    }

}
