<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\CmsModule\Model\PageManager;
use Nette\Application\UI\Control;

/**
 * Komponenta pro vykreslení menu stránek
 * @package App\FrontModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class PageMenuControl extends Control {

	/** Cesta k souborům šablon pro tuto komponentu. */
	const TEMPLATE_PATH = '/../templates/components/PageMenu/';

	/** @var  PageManager */
	private $pageManager;

	public function __construct( PageManager $pageManager ) {
		parent::__construct();
		$this->pageManager = $pageManager;
	}

	/**
	 * Výchozí metoda pro vykreslení komponenty
	 */
	public function render( $params ) {
		// Nastaví šablonu komponenty

		$this->template->setFile( __DIR__ . self::TEMPLATE_PATH . 'menu.latte' );
		$this->template->items    = $this->pageManager->getPagesToMenu();
		$this->template->position = $params['position'];
		if ( isset( $params['name'] ) ) {
			$this->template->name = $params['name'];
		}

		// Vykreslí komponentu.
		$this->template->render();
	}

}

/**
 * Interface pro vytvoření pomocné komponenty (PageMenu) pro vykreslování menu
 * @package App\FrontModule\Components
 */
interface IPageMenuFactory {

	/**
	 * @return PageMenuControl komponenta pro vykreslování page menu
	 */
	public function create();
}
