<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use Nette\Application\UI\Control;
use Nette\Http\Request;
use Nette\Http\UrlScript;
use Nette\Utils\Paginator;

/**
 * Komponenta pro správu a vykreslování stránkování.
 * @package App\FrontModule\Components
 *
 * @author Jan Vodák <vodak at ideatech.cz>
 */
class PaginationControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/Pagination/pagination.latte';

    /** @var int Rozmezí počtu stránek kolem aktuální stránky. Default: 5 */
    private $radius = 5;

    /** @var Paginator Pomocná Nette třída pro řešení stránkovací matematiky. */
    private $paginator;

    /** @var UrlScript Pomocná Nette třída pro reprezentaci a práci s URL. */
    private $url;

    /**
     * Konstruktor komponenty pro správu a vykreslování stránkování.
     * @param Request $request automaticky injektovaná třída pro aktuální HTTP dotaz na aplikaci
     */
    public function __construct(Request $request) {
        parent::__construct();
        $this->paginator = new Paginator();
        $this->url = $request->getUrl();
    }

    /**
     * Nastavuje rozmezí počtu stránek kolem aktuální stránky
     * @param int $radius nová hodnota rozmezí počtu stránek kolem aktuální stránky
     */
    public function setRadius($radius) {
        if (is_numeric($radius)) {
            $this->radius = (int) $radius;
        }
    }

    /**
     * Getter, který vrací přímou referenci na pomocnou třídu Nette pro řešení stránkovací matematiky.
     * @return Paginator pomocná Nette třída pro řešení stránkovací matematiky
     */
    public function &getPaginator() {
        return $this->paginator;
    }

    /**
     * Nastavuje počet prvků na stránku přes paginator.
     * @param int $itemsPerPage počet prvků na stránku
     */
    public function setItemsPerPage($itemsPerPage) {
        $this->paginator->setItemsPerPage($itemsPerPage);
    }

    /** Vykresluje komponentu pro správu a vykreslování stránkování. */
    public function render() {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);
        
        // Deklarace pomocných proměných.
        $page = $this->paginator->getPage();
        $pages = $this->paginator->getPageCount();

        // Předává parametry do šablony.
        $this->template->page = $page;
        $this->template->pages = $pages;
        // Jsem na straně 20, radius je 5, vypisu kolem aktualni 20. strany 5 stránek po 15 (left je poslední strana vlevo)
        $this->template->left = $page - $this->radius >= 1 ? $page - $this->radius : 1;
        $this->template->right = $page + $this->radius <= $pages ? $page + $this->radius : $pages;
        $this->template->url = $this->url;
        
        // Vykreslí komponentu.
        $this->template->render();
    }

}

/**
 * Továrnička pro vytvoření komponenty pro správu a vykreslování stránkování s využitím autowiringu - viz PriceControl.
 * @package App\FrontModule\Components
 */
interface IPaginationControlFactory {

    /**
     * Vrací novou komponentu pro správu a vykreslování stránkování s automaticky inejectovanými závislostmi.
     * @return PaginationControl komponenta pro správu a vykreslování stránkování
     */
    public function create();
}
