<?php

namespace App\FrontModule\Components;

use App\Components\IPriceControlFactory;
use App\EshopModule\Model\SettingsManager;
use Nette\Application\UI\Control;
use Nette\Database\Table\IRow;

class ProductBlockControl extends Control
{

    const TEMPLATE = '/../templates/components/ProductBlock/control.latte';
    const TEMPLATE_JS = '/../templates/components/ProductDetail/javascript.latte';

    /**
     * @var IPriceControlFactory
     */
    private $priceControlFactory;

    /**
     * @var SettingsManager
     */
    private $settingsManager;

    /**
     * @var IRow
     */
    private $product;

    public function __construct(IRow $product,
                                IPriceControlFactory $priceControlFactory,
                                SettingsManager $settingsManager)
    {
        parent::__construct();
        $this->product = $product;
        $this->priceControlFactory = $priceControlFactory;
        $this->settingsManager = $settingsManager;
    }

    public function render()
    {
        $this->template->setFile(__DIR__.self::TEMPLATE);
        $this->template->product = $this->product;
        $this->template->settings = $this->settingsManager->getSettings();
        $this->template->render();
    }

    protected function createComponentRating()
    {
        return new RatingControl();
    }

    protected function createComponentPrice()
    {
        return $this->priceControlFactory->create();
    }


}

/**
 * Interface IProductBlockFactory
 * @package App\FrontModule\Components
 */
interface IProductBlockFactory
{
    /**
     * @param IRow $product
     * @return ProductBlockControl
     */
    public function create(IRow $product);
}


