<?php

namespace App\FrontModule\Components;

use App\Components\IPriceControlFactory;
use App\EshopModule\Model\ProductAttributeManager;
use App\EshopModule\Model\ProductManager;
use App\EshopModule\Model\ProductReviewManager;
use App\EshopModule\Model\SettingsManager;
use App\MediaModule\Components\IGalleryFactory;
use Nette\Application\UI\Control;
use Nette\Database\Table\IRow;
use Nette\Database\Table\Selection;
use Nette\Utils\ArrayHash;

class ProductDetailControl extends Control
{

    const TEMPLATE = '/../templates/components/ProductDetail/control.latte';
    const TEMPLATE_JS = '/../templates/components/ProductDetail/javascript.latte';

    /**
     * @var IReviewFormFactory
     */
    private $reviewFormFactory;

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var ProductAttributeManager
     */
    private $productAttributeManager;

    /**
     * @var ProductReviewManager
     */
    private $productReviewManager;

    /**
     * @var IReviewFactory
     */
    private $reviewFactory;

    /**
     * @var IGalleryFactory
     */
    private $galleryFactory;

    /**
     * @var IPriceControlFactory
     */
    private $priceControlFactory;

    /**
     * @var SettingsManager
     */
    private $settingsManager;

    /**
     * @var ICartFormFactory
     */
    private $cartFormFactory;

    /**
     * @var IRow
     */
    private $product;

    /**
     * @var IRow
     */
    private $selectedVariant;

    public function __construct(IRow $product,
                                IReviewFormFactory $reviewFormFactory,
                                ProductManager $productManager,
                                ProductAttributeManager $productAttributeManager,
                                ProductReviewManager $productReviewManager,
                                IReviewFactory $reviewFactory,
                                IGalleryFactory $galleryFactory,
                                IPriceControlFactory $priceControlFactory,
                                SettingsManager $settingsManager,
                                ICartFormFactory $cartFormFactory)
    {
        parent::__construct();
        $this->product = $product;
        $this->reviewFormFactory = $reviewFormFactory;
        $this->productManager = $productManager;
        $this->productAttributeManager = $productAttributeManager;
        $this->productReviewManager = $productReviewManager;
        $this->reviewFactory = $reviewFactory;
        $this->galleryFactory = $galleryFactory;
        $this->priceControlFactory = $priceControlFactory;
        $this->settingsManager = $settingsManager;
        $this->cartFormFactory = $cartFormFactory;
    }

    public function render($formPath = null)
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE);
        $this->template->formPath = $formPath;
        // Nastavení výchozí hodnoty formuláře pro hodnocení produktu.
        $this['reviewForm']->setDefaults(['product_id' => $this->product->getPrimary()]);

        // Zkontrolujeme zda produkt neni variabilni a pripadne nacteme varianty
        if ($this->product->type === ProductManager::TYPE_VARIABLE) {
            /** @var Selection $variants */
            $variants = $this->productManager->getVariants($this->product->product_id);
            $attributesArray = [];
            foreach ($variants as $variant) {
                $attributes = $this->productAttributeManager->getProductAttributes($variant->product_id);
                foreach ($attributes as $attribute) {
                    $attributesArray[$attribute->attribute->name][$variant->product_id] = $attribute->attribute_values->value;
                }
            }
            $this->template->attributes = $attributesArray;
        }

        // Předání parametrů do šablony.
        $this->template->product = $this->product;
        $this->template->reviews = $this->productReviewManager->getReviews($this->product->product_id);

        $this->template->settings = $this->settingsManager->getSettings();

        if($this->selectedVariant !== null) {
            $this->template->selectedVariant = $this->selectedVariant;
            $this['cartForm']->setDefaultVariant($this->selectedVariant->getPrimary());
        }

        // Definuje komponentu, která se vykreslí v rámci formuláře pro psaní recenzí.
        // Nezadám žáadny parametr - vykreslí se šablona pro udělování hodnoceni
        $this->template->ratingWidget = ArrayHash::from(['name' => 'rating', 'after' => 'product_id']);
        $this->template->render();
    }

    public function renderJs()
    {
        $this->template->setFile(__DIR__ . self::TEMPLATE_JS);
        $this->template->render();
    }

    public function handleSelectVariant($variantId)
    {
        $this->selectedVariant = $this->productManager->getProductFromId($variantId);

        $this->redrawControl();
    }

    protected function createComponentReviewForm()
    {
        return $this->reviewFormFactory->create();
    }

    protected function createComponentRating()
    {
        return new RatingControl();
    }

    protected function createComponentReview()
    {
        return $this->reviewFactory->create();
    }

    protected function createComponentGallery()
    {
        return $this->galleryFactory->create();
    }

    protected function createComponentPrice()
    {
        return $this->priceControlFactory->create();
    }

    protected function createComponentCartForm()
    {
        return $this->cartFormFactory->create();
    }


}

/**
 * Interface IProductDetailFactory
 * @package App\FrontModule\Components
 */
interface IProductDetailFactory
{
    /**
     * @param IRow $product
     * @return ProductDetailControl
     */
    public function create(IRow $product);
}


