<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Components;

use App\Model\PersonManager;
use App\Model\UserManager;
use Nette\Application\UI\Control;
use Nette\Database\Table\ActiveRow;
use Nette\Database\Table\IRow;
use App\Services\FormatHelperService;

/**
 * Komponenta pro vykreslení recenze produktu.
 * @package App\EshopModule\Components
 * 
 * @author Jan Vodák <jan at ideatech.cz>
 */
class ReviewControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../templates/components/Review/review.latte';

    /**
     * @var FormatHelperService Pomocná služba pro formátování data, jména adresy atd.
     */
    private $formatHelperService;

    /**
     * ReviewControl constructor.
     * @param FormatHelperService $formatHelperService
     */
    public function __construct(FormatHelperService $formatHelperService) {
        $this->formatHelperService = $formatHelperService;
    }

    /**
     * Vykreslí recenzi produktu.
     * @param IRow $review recenze produktu
     */
    public function render(IRow $review) {
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE); // Nastaví šablonu komponenty.
        // Předává parametry do šablony.
        $this->template->review = $review;
        /** @var ActiveRow $user */
        $user = $review->ref(UserManager::TABLE_NAME);
        $person = $user->related(PersonManager::TABLE_NAME)->fetch();
        $this->template->personName = $person ? PersonManager::getName($person->ref(PersonManager::TABLE_DETAIL_NAME)) : $user->username;
        $this->template->prettyDateTime = $this->formatHelperService->prettyDateTime($review['sent']);
        $this->template->render(); // Vykreslí komponentu.
    }

}

/**
 * Interface IReviewFactory
 * @package App\FrontModule\Components
 */
interface IReviewFactory {

    /**
     * @return ReviewControl
     */
    public function create();
}
