<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Presenters;

use App\BlogModule\Model\ArticleManager;
use App\BlogModule\Model\CategoryManager;
use App\FrontModule\Components\ArticleCategoryControl;
use App\MediaModule\Components\IGalleryFactory;
use App\MediaModule\Components\IMainImageFactory;
use App\MediaModule\Model\FileManager;
use App\MediaModule\Model\FileRelationsManager;

/*
 * @resourceDescription Zpracovává vykreslování článků ve frontendové části.
 * @package App\FrontModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */

class ArticlePresenter extends BaseFrontPresenter {
    
    /** URL stránky z ROUTERU, který se na ni odkazuje a bude použita pro vyhledání stránky a nastavení SEO elementů */
    const PAGE_URL = 'aktuality';

    /**
     * @var ArticleManager
     */
    private $articleManager;

    /**
     * @var CategoryManager
     */
    private $categoryManager;

    /**
     * @var IGalleryFactory
     */
    private $galleryFactory;

    /**
     * @var FileRelationsManager
     */
    private $fileRelationsManager;

    /**
     * @var FileManager
     */
    private $fileManager;

    /**
     * @var IMainImageFactory
     */
    private $mainImageFactory;

    /**
     * ArticlePresenter constructor.
     * @param ArticleManager $articleManager
     * @param CategoryManager $categoryManager
     * @param IGalleryFactory $galleryFactory
     * @param FileRelationsManager $fileRelationsManager
     * @param FileManager $fileManager
     * @param IMainImageFactory $mainImageFactory
     */
    public function __construct(ArticleManager $articleManager, CategoryManager $categoryManager, IGalleryFactory $galleryFactory, FileRelationsManager $fileRelationsManager, FileManager $fileManager, IMainImageFactory $mainImageFactory)
    {
        parent::__construct();
        $this->articleManager = $articleManager;
        $this->categoryManager = $categoryManager;
        $this->galleryFactory = $galleryFactory;
        $this->fileRelationsManager = $fileRelationsManager;
        $this->fileManager = $fileManager;
        $this->mainImageFactory = $mainImageFactory;
    }


    /**
     * @actionName default
     * @actionDescription výpis jednotlivého příspěvku článku/aktualita/blogu na webu
     * @param String|null $url url adresa článku
     */
    public function renderDefault($url = null) {
        $this->template->article = $this->articleManager->getArticle($url);
        $images = $this->fileRelationsManager->getEntityImages('article_id', $this->template->article->article_id);
        $images = iterator_to_array($images);
        if ($images) {
            $first_img = $this->fileManager->getById(FileManager::TABLE_NAME, FileManager::COLUMN_ID, array_values($images)[0]);
        } else {
            $first_img = null;
        }

        // Nastavím do šablony SEO elementy, které získám z konrétního příspěvku
        $this->setPageSeoElements(null, $this->template->article->seo_title, $this->template->article->seo_description, $this->template->article->seo_keywords);

        $this->template->page->image = $first_img;

        $this->template->randomArticles = $this->articleManager->getRandomArticles(3);
        $this->template->count = $this->articleManager->getTable()->count("*");
    }

    /**
     * @actionName list
     * @actionDescription výpis všech článků/aktualit/blogu na webu
     * @param string|null $url url adresa
     */
    public function renderList($url = null) {
        // Nastavím do šablony SEO elementy ze stránky z DB, kterou najdu podle URL, nebo výchozí, které do metody zadávám
        $this->setPageSeoElements(self::PAGE_URL, 'Aktuality', 'Stránka s aktualitami webu', 'aktuality');

        $categories = $this->categoryManager->getCategories();
        $articles = [];

        foreach ($categories as $category) {
            $articles[$category['category']->category_id] = $this->articleManager->getArticles($category['category']->url);
        }
        $this->template->articles = $articles;
        $this->template->categories = $this->categoryManager->getCategories();
    }

    protected function createComponentGallery() {
        return $this->galleryFactory->create();
    }

    protected function createComponentMainImage() {
        return $this->mainImageFactory->create();
    }

    /**
     * Vytváří komponentu, která se stará o rekurzivní vykreslení stromového navigačního menu kategorií.
     * @return ArticleCategoryControl komponenta menu kategorií
     */
    protected function createComponentCategoryMenu() {
        return new ArticleCategoryControl();
    }

}
