<?php

namespace App\FrontModule\Presenters;

use App\EmailModule\Model\EmailManager;
use App\FrontModule\Components\IProductBlockFactory;

/**
 * @resourceDescription EmailPresenter - zpracovává požadavky na sběr emailu z frontendové části
 * @package App\FrontModule\Presenters
 */
class EmailPresenter extends BaseFrontPresenter {

    /**
     * @var EmailManager
     */
    private $emailManager;

    /**
     * @var IProductBlockFactory
     */
    private $productBlockFactory;

    /**
     * EmailPresenter constructor.
     * @param EmailManager $emailManager
     * @param IProductBlockFactory $productBlockFactory
     */
    public function __construct(EmailManager $emailManager, IProductBlockFactory $productBlockFactory) {
        parent::__construct();
        $this->emailManager = $emailManager;
        $this->productBlockFactory = $productBlockFactory;
    }

    /**
     * @actionName confirm
     * @actionDescription potvrzení na webu zadání emailové adresy
     */
    public function actionConfirm($token) {
        $num = $this->emailManager->validateToken($token);
        if ($num > 0) {
            $this->flashMessage('Slevový kód naleznete níže. Děkujeme za Váš nákup');
        } else {
            $this->flashMessage('Neplatný token', 'danger');
            $this->redirect('Page:');
        }
    }

    protected function createComponentProductBlock() {
        return new Multiplier(function ($itemId) {
            $productBlock = $this->productBlockFactory->create($this->productManager->getProductFromId($itemId));
            return $productBlock;
        });
    }

}
