<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\FrontModule\Presenters;

use App\BlogModule\Model\ArticleManager;
use App\CmsModule\Model\PageManager;
use App\EshopModule\Model\ProductManager;
use IPub\Images\TImages;
use Nette\Application\BadRequestException;

/**
 * @resourceDescription Třída pro vykreslování jednotlivých stránek ve frontendové části
 * @package App\FrontModule\Presenters
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class PagePresenter extends BaseFrontPresenter {

    use TImages;

    /** Konstanta s hodnotou URL výchozího článku. */
    const DEFAULT_PAGE_URL = '';

    /**
     * @var PageManager
     */
    private $pageManager;

    /**
     * @var ProductManager
     */
    private $productManager;

    /**
     * @var ArticleManager
     */
    private $articleManager;

    /**
     * PagePresenter constructor.
     * @param PageManager $pageManager
     * @param ProductManager $productManager
     * @param ArticleManager $articleManager
     */
    public function __construct(PageManager $pageManager, ProductManager $productManager, ArticleManager $articleManager)
    {
        parent::__construct();
        $this->pageManager = $pageManager;
        $this->productManager = $productManager;
        $this->articleManager = $articleManager;
    }


    /**
     * @actionName default
     * @actionDescription Výpis jednotlivé stránky, která je vytvořena v administraci do fronendové části (web)
     */
    public function renderDefault($url = null) {
        $this->setLayout('layout');
        
        // Pokud není zadaná URL, vykreslí se výchozí článek.
        if (!$url) {
            $url = self::DEFAULT_PAGE_URL;
        } 

        // Pokusí se načíst článek s danou URL a pokud nebude nalezen, vyhodí chybu 404.
        if (!($page = $this->pageManager->getPage($url))) {
            throw new BadRequestException();
        }

        $this->template->page = $page;

        $children = $this->pageManager->getChildren($page->id);
        $this->template->subpages = $children;

        $this->template->products = $this->productManager->getProducts(['not_in_category' => 20]);
        $this->template->frontProduct = $this->productManager->getProduct('vodni-kefirove-kultury');

        if ($page->product !== null) {
            $this->template->assignedProduct = $this->productManager->getProductFromId($page->product);
            $this->template->aticles = $this->articleManager->getArticlesByCategoryId($this->template->assignedProduct->blog_category);
            $this->template->articleCount = $this->articleManager->getTable()->count("*");
        }
       
        $this->setView($page->template);
    }

}
