<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Components;

use Nette\Database\ForeignKeyConstraintViolationException;
use Ublaboo\DataGrid\DataGrid;
use Nette\Application\UI\Control;
use App\MediaModule\Model\FileManager;

/**
 * Komponenta datagridu pro správu stránek
 * @package App\MediaModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class FileDataGridControl extends Control {

    /** Cesta k souboru šablony pro tuto komponentu. */
    const TEMPLATE = '/../../../templates/components/DataGrids/dataGrid.latte';
    const TEMPLATE_COL_PREVIEW = __DIR__ . '/../templates/components/DataGrids/FileDataGrid/colPreview.latte';

    /** @var FileManager */
    private $fileManager;

    public function __construct(FileManager $fileManager) {
        parent::__construct();
        $this->fileManager = $fileManager;
    }

    public function render() {
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);
        $this->template->render();
    }

    public function createComponentDataGrid($name) {
        $grid = new DataGrid($this, $name);
        /** Localization */
        $grid->setTranslator($this->presenter->translator);

        $grid->setPrimaryKey(FileManager::COLUMN_ID);
        $grid->setDataSource($this->fileManager->getTable());

        $grid->addColumnText(FileManager::COLUMN_NAME, 'Název souboru');
        $grid->addColumnText('preview', 'Náhled')
                ->setTemplate(self::TEMPLATE_COL_PREVIEW, []);
        $grid->addColumnDateTime(FileManager::COLUMN_DATE, 'Datum nahrání');

        /** Odkaz na editaci */
        $grid->addAction('edit', '', ':Cms:Page:edit')
                ->setIcon('pencil');

        /** Mazani */
        $grid->addAction('delete', '', 'deleteFile!')
                ->setIcon('trash')
                ->setTitle('Smazat')
                ->setClass('btn btn-xs btn-danger ajax')
                ->setConfirm('Opravdu chcete smazat stránku %s?', FileManager::COLUMN_TITLE);

        return $grid;
    }

    public function handleDeleteFile($media_id) {
        try {
            $this->fileManager->deleteFile($media_id);
            $this->presenter->flashMessage("Soubor s ID:[$media_id] byl smazán", 'info');
        } catch (ForeignKeyConstraintViolationException $e) {
            $this->presenter->flashMessage("Soubor nemohl být smazán, protože je přiřazen k obsahu na webu.", 'danger');
        }

        if ($this->presenter->isAjax()) {
            $this->presenter->redrawControl('flashes');
            $this['DataGrid']->reload();
        } else {
            $this->presenter->redirect('this');
        }
    }

}

interface IFileDataGridFactory {

    /**
     * @return FileDataGridControl
     */
    public function create();
}
