<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Components;

use App\MediaModule\Model\FileRelationsManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;

/**
 * Class ImagesControl
 * @package App\MediaModule\Components
 */
class ImagesControl extends Control {

    /**
     * @var FileRelationsManager
     */
    protected $fileRelationsManager;

    /** Cesta k souboru šablony pro tuto komponentu. */
    protected $templateFile = '/../templates/components/Images/images.latte';

    /**
     * ImagesControl constructor.
     * @param FileRelationsManager $fileRelationsManager
     */
    public function __construct(FileRelationsManager $fileRelationsManager) {
        parent::__construct();
        $this->fileRelationsManager = $fileRelationsManager;
    }

    public function render($entity, $entityId, $type = null) {
        // Nastaví šablonu komponenty.
        $this->template->setFile(dirname(__FILE__) . $this->templateFile);

        // Předává parametry do šablony.
        $this->template->entity = $entity;
        $this->template->entityId = $entityId;
        $this->template->images = $this->fileRelationsManager->getEntityImages($entity, $entityId, $type);

        // Vykreslí komponentu.
        $this->template->render();
    }

    public function handleDeleteImage($entity, $entity_id, $index) {
        $this->fileRelationsManager->removeEntityImage($entity, $entity_id, $index);

        //Získam si presenter, ve ktereém byla komponenta vyvolána
        $presenter = $this->getPresenter();
        
        $presenter->flashMessage('Obrázek byl úspěšně smazán', MessageType::SUCCESS);

        if ($presenter->isAjax()) {
            $presenter->redrawControl('gallerySnippet');
            $presenter->redrawControl('backgeroundSnippet');
            $presenter->redrawControl('ajaxNotification');
        } else {
            $presenter->redirect('this');
        }
    }

    public function handleMainImage($entity, $entity_id, $index) {
        $this->fileRelationsManager->setMain($entity, $entity_id, $index);
        $presenter = $this->getPresenter();
        
        $presenter->flashMessage('Obrázek byl úspěšně nahrán jako hlavní', MessageType::SUCCESS);
        
        if ($presenter->isAjax()) {
            $presenter->redrawControl('gallerySnippet');
            $presenter->redrawControl('backgeroundSnippet');
            $presenter->redrawControl('ajaxNotification');
        } else {
            $presenter->redirect('this');
        }
    }

}

interface IImagesFactory {

    /**
     * @return ImagesControl
     */
    public function create();
}
