<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Components;

use App\MediaModule\Model\FileRelationsManager;
use Nette\Application\UI\Control;
use Tracy\Debugger;

/**
 * Class MainImageControl
 * @package App\MediaModule\Components
 */
class MainImageControl extends Control
{
	/**
	 * @var FileRelationsManager
	 */
	protected $fileRelationsManager;

	/** Cesta k souboru šablony pro tuto komponentu. */
	const TEMPLATE = '/../templates/components/MainImage/image.latte';

	/**
	 * GalleryControl constructor.
	 * @param FileRelationsManager $fileRelationsManager
	 */
	public function __construct(FileRelationsManager $fileRelationsManager)
	{
		parent::__construct();
		$this->fileRelationsManager = $fileRelationsManager;
	}

    /**
     * @param $entity
     * @param $entityId
     * @param string $size
     * @param string $method
     * @param null $alt
     * @param null $class
     */
	public function render($entity, $entityId, $size = 'original', $method = 'fit', $alt = null, $class = null)
	{
        $this->template->image = null;

		// Nastaví šablonu komponenty.
		$this->template->setFile(__DIR__ . self::TEMPLATE);

		// Předává parametry do šablony.
		$this->template->entity = $entity;
		$this->template->entityId = $entityId;
		$this->template->size = $size;
        $this->template->method = $method;
        $this->template->alt = $alt;
        $this->template->class = $class;

		$images = $this->fileRelationsManager->getEntityImages($entity, $entityId);
		foreach ($images as $image) {
			if($image->main == 1) {
				$this->template->image = $image;
			}
		}

		if(count($images) > 0 && !isset($this->template->image)) {
			$this->template->image = $images[0];
		}

		// Vykreslí komponentu.
		$this->template->render();
	}

}

interface IMainImageFactory
{
	/**
	 * @return MainImageControl
	 */
	public function create();
}
