<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Components;

use App\Forms\BaseFormFactory;
use App\MediaModule\Model\FileManager;
use App\MediaModule\Model\FileRelationsManager;
use App\Model\Enum\MessageType;
use Nette\Application\UI\Control;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use Tracy\Debugger;

/**
 * Component for uploading files and editing file properties
 * @package App\MediaModule\Components
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class UploadFormControl extends Control
{

    const TEMPLATE = '/../templates/components/UploadForm/form.latte';

    /**
     * @var FileManager
     */
    private $fileManager;

    /**
     * @var BaseFormFactory
     */
    private $formFactory;

    /**
     * @var FileRelationsManager
     */
    private $fileRelationsManager;

    /**
     * UploadFormControl constructor.
     * @param FileManager $fileManager
     * @param BaseFormFactory $formFactory
     * @param FileRelationsManager $fileRelationsManager
     */
    public function __construct(FileManager $fileManager, BaseFormFactory $formFactory, FileRelationsManager $fileRelationsManager)
    {
        parent::__construct();
        $this->fileManager = $fileManager;
        $this->formFactory = $formFactory;
        $this->fileRelationsManager = $fileRelationsManager;
    }

    public function render($entity = null, $entity_id = null, $type = null)
    {
        $this->template->setFile(dirname(__FILE__) . self::TEMPLATE);
        $this['uploadForm']->setDefaults([
            'entity_id' => $entity_id,
            'entity' => $entity,
            'type' => $type
        ]);
        $this->template->render();
    }

    protected function createComponentUploadForm()
    {
        $form = $this->formFactory->create();
        $form->elementPrototype->addAttributes(array('class' => 'ajax'));

        $form->addHidden('entity_id');
        $form->addHidden('entity');
        $form->addHidden('type');

        $form->addMultiUpload('files', 'Soubor/y')
            ->setRequired();

        $form->addSubmit('submit', 'Nahrát')
                ->setAttribute('class', 'uploadSubmit');

        $form->onSuccess[] = [$this, 'uploadFormSuccess'];
        return $form;
    }

    public function uploadFormSuccess(Form $form, ArrayHash $values)
    {

        $ids = $this->fileManager->uploadFiles($values->files);

        if (isset($values->entity) && isset($values->entity_id)) {
            foreach ($ids as $fileId) {
                $this->fileRelationsManager->assignImage($fileId, $values->entity, $values->entity_id, $values->type);
            }
        }

        $images = $this->fileRelationsManager->getEntityImages($values->entity, $values->entity_id)->fetchAll();
        $main = 0;
        foreach ($images as $image) {
            if($image->main == 1) {
                $main = 1;
            }
        }

        if($main === 0) {
            $image = reset($images);
            $this->fileRelationsManager->setMain($values->entity, $values->entity_id, $image->{FileRelationsManager::COLUMN_FILE});
        }

        //Získam si presenter, ve ktereém byla komponenta vyvolána
        $presenter = $this->getPresenter();

        $presenter->flashMessage('Přidání obrázků proběhlo úspěšně', MessageType::SUCCESS);

        if ($presenter->isAjax()) {
            $presenter->redrawControl('gallerySnippet');
            $presenter->redrawControl('backgeroundSnippet');
            $presenter->redrawControl('ajaxNotification');
        } else {
            $presenter->redirect('this');
        }
    }

}

interface IUploadFormFactory
{

    /**
     * @return UploadFormControl
     */
    public function create();
}
