<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Model;

use App\Model\BaseManager;
use League\Flysystem\FileExistsException;
use League\Flysystem\MountManager;
use Nette\Database\Context;
use Nette\Http\FileUpload;
use Nette\Utils\ArrayHash;
use Nette\Utils\DateTime;

/**
 * Správce souborů
 * @package App\MediaModule\Model
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class FileManager extends BaseManager
{

	/** Konstanty pro manipulaci s modelem. */
	const
		TABLE_NAME = 'media',
		COLUMN_ID = 'media_id',
		COLUMN_NAME = 'media_filename',
		COLUMN_TYPE = 'media_filetype',
		COLUMN_DATE = 'media_date',
		COLUMN_TITLE = 'media_title',
		COLUMN_ALT = 'media_alt';

	CONST
		MOUNT_FILESYSTEM = 'media';

	/**
	 * @var MountManager
	 */
	private $mountManager;

	public function __construct(Context $database, MountManager $mountManager)
	{
		parent::__construct($database);
		$this->mountManager = $mountManager;
	}

	/**
	 * @return \Nette\Database\Table\Selection
	 */
	public function getTable()
	{
		return $this->database->table(self::TABLE_NAME);
	}

    /**
     * @param $id
     * @return \Nette\Database\Table\IRow
     */
	public function findById($id)
    {
        return $this->database->table(self::TABLE_NAME)->get($id);
    }

	/**
	 * @param ArrayHash $values
	 * @return int
	 */
	public function save(ArrayHash $values)
	{
		/** if ID is not set, create new */
		if(!isset($values->{self::COLUMN_ID})) {
			$file = $this->database->table(self::TABLE_NAME)->insert($values);
		} else {

		}
		return $file->{self::COLUMN_ID};
	}

	/**
	 * @param FileUpload $file
	 * @return string filename
	 */
	public function uploadFile(FileUpload $file)
	{
		$year = date('Y');
		$month = date('m');
		$filename = $file->getSanitizedName();
		try {
			$this->mountManager->write(self::MOUNT_FILESYSTEM.'://'.$year.'/'.$month.'/'.$filename, $file->getContents());
		} catch (FileExistsException $e) {
			$filename = time().$filename;
			$this->mountManager->write(self::MOUNT_FILESYSTEM.'://'.$year.'/'.$month.'/'.$filename, $file->getContents());
		}

		return $filename;
	}

	/**
	 * Upload multiple files from upload form and save it to database, returns array of ids
	 * @param $files
	 * @return array
	 */
	public function uploadFiles($files)
	{
		$ids = [];
		foreach ($files as $file) {
			$filename = $this->uploadFile($file);
			$values = new ArrayHash();
			$values->offsetSet(self::COLUMN_DATE, new DateTime());
			$values->offsetSet(self::COLUMN_NAME, $filename);
			$values->offsetSet(self::COLUMN_TYPE, $file->getContentType());
			$ids[] = $this->save($values);
		}
		return $ids;
	}

	public function deleteFile($fileId)
	{
		return $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $fileId)->delete();
	}

    /**
     * @param $imageId
     * @param $provider
     * @param string $size
     * @param int $algorithm
     * @return bool
     */
	public function getImageUrl($imageId, $provider, $size = 'original', $algorithm = \Nette\Utils\Image::FIT)
    {
        $image = $this->findById($imageId);
        if($image) {
            /** @var DateTime $date */
            $date = $image->media_date;
            return $provider->request('media', $date->format('Y').'/'.$date->format('m'), $image->media_filename, $size, $algorithm);
        } else {
            return false;
        }
    }



}
