<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Model;

use App\Model\BaseManager;
use Nette\Database\Context;
use Nette\Database\Table\Selection;

/**
 * Správce souborů
 * @package App\MediaModule\Model
 *
 * @author Petr Vojáček <petr at ideatech.cz>
 */
class FileRelationsManager extends BaseManager
{

	/** Konstanty pro manipulaci s modelem. */
	const
		TABLE_NAME = 'media_relations',
		COLUMN_ID = 'media_relations_id',
		COLUMN_FILE = 'media_id',
		COLUMN_PRODUCT = 'product_id',
		COLUMN_ARTICLE = 'article_id',
        COLUMN_SHIPPING_METHOD = 'shipping_method_id',
		COLUMN_PAGE = 'page_id',
		COLUMN_TYPE = 'type',
		COLUMN_MAIN = 'main';

	const DEFAULT_TYPE = 'gallery';

	public function __construct(Context $database)
	{
		parent::__construct($database);
	}

	public function getTable()
	{
		return $this->database->table(self::TABLE_NAME);
	}

	public function assignImage($imageId, $entityColumn, $entityId, $type = null)
	{
		$this->database->table(self::TABLE_NAME)->insert([
			'media_id' => $imageId,
			$entityColumn => $entityId,
			self::COLUMN_TYPE => ($type ? $type : self::DEFAULT_TYPE)
		]);
	}

    /**
     * @param $entityColumn
     * @param $entityId
     * @param null $type
     * @return Selection
     */
	public function getEntityImages($entityColumn, $entityId, $type = null)
	{
		$images = $this->database->table(self::TABLE_NAME)
			->where($entityColumn, $entityId);

		if($type !== null) {
			$images->where(self::COLUMN_TYPE, $type);
		}

		return $images->order(self::COLUMN_MAIN." DESC");
	}

	public function removeEntityImage($entity, $entityId, $imageId)
	{
		return $this->database->table(self::TABLE_NAME)
			->where($entity, $entityId)
			->where(self::COLUMN_FILE, $imageId)
			->delete();
	}

	public function removeEntityImages($entity, $entityId)
	{
		return $this->database->table(self::TABLE_NAME)
			->where($entity, $entityId)
			->delete();
	}

	public function setMain($entity, $entityId, $imageId)
	{
		$this->database->table(self::TABLE_NAME)->where($entity, $entityId)->update(['main' => 0]);
		$this->database->table(self::TABLE_NAME)->where($entity, $entityId)->where(self::COLUMN_FILE, $imageId)->update(['main' => 1]);
	}

	public function getPageBackgrounds($pageId)
	{
		return $this->database->table(self::TABLE_NAME)
			->where(self::COLUMN_PAGE, $pageId)
			->where(self::COLUMN_TYPE, 'background');
	}

    /**
     * @param $entityColumn
     * @param $entityId
     * @return bool|mixed|\Nette\Database\Table\IRow
     */
	public function getMainImage($entityColumn, $entityId)
    {
        return $this->database->table(self::TABLE_NAME)
            ->where($entityColumn, $entityId)
            ->where(self::COLUMN_MAIN, 1)->fetch();
    }


}
