<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\MediaModule\Presenters;

use App\MediaModule\Components\IFileDataGridFactory;
use App\MediaModule\Components\IUploadFormFactory;
use League\Flysystem\MountManager;

/**
 * @resourceDescription Základní presenter pro všechny ostatní presentery v MediaModule.
 * Pro RBAC loader metody, které nemají funkci, protože se nepředávají žádné parametry
 * @actionName default
 * @actionDescription Přehled obrázku v media modulu
 * @package App\MediaModule\Presenters
 *
 * @author Petr Vojáček <petr@ideatech.cz>
 */
class FilePresenter extends BaseMediaPresenter {

    /**
     * @var \League\Flysystem\MountManager
     */
    private $mountManager;

    /**
     * @var IUploadFormFactory
     */
    private $uploadFormFactory;

    /**
     * @var IFileDataGridFactory
     */
    private $fileDataGridFactory;

    /**
     * FilePresenter constructor.
     * @param \League\Flysystem\MountManager $mountManager
     * @param IUploadFormFactory $uploadFormFactory
     */
    public function __construct(MountManager $mountManager, IUploadFormFactory $uploadFormFactory, IFileDataGridFactory $fileDataGridFactory) {
        parent::__construct();
        $this->mountManager = $mountManager;
        $this->uploadFormFactory = $uploadFormFactory;
        $this->fileDataGridFactory = $fileDataGridFactory;
    }

    protected function createComponentUploadForm() {
        return $this->uploadFormFactory->create();
    }

    protected function createComponentFileDataGrid() {
        return $this->fileDataGridFactory->create();
    }

}
