<?php

namespace App;

use Nette\Application\Routers\RouteList;
use Nette\Application\Routers\Route;

/**
 * Routovací továrnička.
 * Řídí routování v celé aplikaci.
 * @package App
 */
class RouterFactory {

    /**
     * Vytváří router pro aplikaci.
     * @return RouteList výsledný router pro aplikaci
     */
    public static function createRouter() {
        $router = new RouteList();
        $router[] = new Route('administrace/cms/stranky/', 'Cms:Page:manage');
        $router[] = new Route('administrace/cms/stranky/editor/[<id>]', 'Cms:Page:edit');

        $router[] = new Route('administrace/cms/blog/', 'Blog:Article:manage');
        $router[] = new Route('administrace/cms/blog/kategorie', 'Blog:Category:default');
        $router[] = new Route('administrace/cms/blog/[<action>/][<url>]', array(
            'presenter' => 'Blog:Article',
            'action' => array(
                Route::FILTER_TABLE => array(
                    'editor' => 'editor',
                    'odstranit' => 'remove'
                ),
                Route::FILTER_STRICT => true
            ),
            'url' => null,
        ));
        
        $router[] = new Route('administrace/cms/emaily', 'Email:Email:manage');

        $router[] = new Route('administrace/eshop/produkty/', 'Eshop:Product:management');
        $router[] = new Route('administrace/eshop/produkty/upravit/[<url>]', 'Eshop:Product:manage');
        $router[] = new Route('administrace/eshop/produkty/varianty/<productId>', 'Eshop:ProductVariant:management');
        $router[] = new Route('administrace/eshop/produkty/varianty/smazat/<id>', 'Eshop:ProductVariant:delete');
        $router[] = new Route('administrace/eshop/produkty/varianty/upravit/<product_id>', 'Eshop:ProductVariant:edit');

        $router[] = new Route('administrace/eshop/produkty/sprava-kategorii/', 'Eshop:Category:default');
        $router[] = new Route('administrace/eshop/sprava-objednavek/editace/[<e_order_id>]', 'Eshop:Order:manage');
        $router[] = new Route('administrace/eshop/sprava-objednavek/', 'Eshop:Order:management');

        $router[] = new Route('administrace/eshop/produkty/atributy', 'Eshop:Attribute:default');
        $router[] = new Route('administrace/eshop/produkty/atributy/editace/[<attribute_id>]', 'Eshop:Attribute:editor');
        
        $router[] = new Route('administrace/nastaveni/uzivatele/', 'Core:Users:management');
        $router[] = new Route('administrace/nastaveni/uzivatele/novy', 'Core:Users:registerAccount');
        $router[] = new Route('administrace/nastaveni/uzivatele/editace/<user_id>', 'Core:Users:userDetail');
        
        $router[] = new Route('administrace/nastaveni/uzivatelske-role/', 'Core:UserRole:management');
        $router[] = new Route('administrace/nastaveni/uzivatelske-role/opravneni/<role_id>', 'Core:UserRole:manage');
        
        $router[] = new Route('administrace/nastaveni/moduly/', 'Core:Module:management');
        
        $router[] = new Route('administrace/nastaveni/uzivatelske-logy/', 'Core:UserLog:activityLogManagement');
        $router[] = new Route('administrace/nastaveni/uzivatelske-logy/prehled-loginu', 'Core:UserLog:loginLogManagement');

        $router[] = new Route('administrace/cms/nastaveni/socialni-site/', 'Core:Social:default');
        $router[] = new Route('administrace/cms/nastaveni/socialni-site/editace/[<id>]', 'Core:Social:edit');
        $router[] = new Route('administrace/cms/nastaveni/partneri/', 'Core:Partner:default');
        $router[] = new Route('administrace/cms/nastaveni/partneri/editace/[<id>]', 'Core:Partner:edit');
        $router[] = new Route('administrace/cms/nastaveni/email/', 'Core:EmailSettings:default');
        $router[] = new Route('administrace/cms/nastaveni/email/editace/[<id>]', 'Core:EmailSettings:edit');

        $router[] = new Route('administrace/eshop/zakaznici', 'Eshop:Person:customerManagement');
        $router[] = new Route('administrace/eshop/zakaznici/detail/<person_id>', 'Eshop:Person:personDetail');

        $router[] = new Route('administrace/eshop/nastaveni/ucetni-nastaveni/[<action>/<id>]', 'Eshop:Settings:default');
        $router[] = new Route('administrace/eshop/nastaveni/zpusob-dopravy/', 'Eshop:ShippingMethods:management');
        $router[] = new Route('administrace/eshop/nastaveni/zpusob-dopravy/editace/<id>', 'Eshop:ShippingMethods:manage');
        $router[] = new Route('administrace/eshop/nastaveni/metody-platby/', 'Eshop:PaymentMethods:management');
        $router[] = new Route('administrace/eshop/nastaveni/metody-platby/editace/<id>', 'Eshop:PaymentMethods:manage');
        $router[] = new Route('administrace/eshop/nastaveni/slevove-hladiny/uzivatelske-slevy', 'Eshop:DiscountLevels:userDiscountManagement');
        $router[] = new Route('administrace/eshop/nastaveni/slevove-hladiny/kupony', 'Eshop:DiscountLevels:couponDiscountManagement');
        $router[] = new Route('administrace/eshop/nastaveni/kuryz-men/', 'Eshop:Currency:management');
        $router[] = new Route('administrace/eshop/nastaveni/kurzy-men/editace/<id>', 'Eshop:Currency:manage');
        $router[] = new Route('administrace/eshop/nastaveni/udaje-prodejce', 'Eshop:Person:manage');
 
        $router[] = new Route('administrace/media', 'Media:File:default');

        $router[] = new Route('kosik[/<action>]', 'Front:Order:default');
        $router[] = new Route('objednavka/<action>/', array(
            'presenter' => 'Front:Order',
            'action' => array(
                // řetězec v URL => akce presenteru
                Route::FILTER_TABLE => array(
                    'platba' => 'payment',
                    'rekapitulace' => 'summary',
                    'objednat' => 'buy',
                    'dekujeme' => 'thanks'
                ),
                Route::FILTER_STRICT => true
            )
        ));

        $router[] = new Route('osoby/<action>/', array(
            'presenter' => 'Front:Person',
            'action' => array(
                // řetězec v URL => akce presenteru
                Route::FILTER_TABLE => array(
                    'registrace' => 'register',
                    'registrace-uctu' => 'registerAccount',
                    'sprava' => 'manage',
                    'dodaci-udaje' => 'manageInOrder',
                    'zmena-hesla' => 'changePassword'
                ),
                Route::FILTER_STRICT => true
            )
        ));

        $router[] = new Route('produkty/<action>/[<url>]', array(
            'presenter' => 'Front:Product',
            'action' => array(
                // řetězec v URL => akce presenteru
                Route::FILTER_TABLE => array(
                    'detail' => 'detail',
                    'novinky' => 'news'
                ),
                Route::FILTER_STRICT => true
            )
        ));

        $router[] = new Route('produkty/[<url>]', 'Front:Product:default');

        $router[] = new Route('<action>/', array(
            'presenter' => 'Core:Administration',
            'action' => array(
                // řetězec v URL => akce presenteru
                Route::FILTER_TABLE => array(
                    'administrace' => 'default',
                    'login' => 'login',
                    'logout' => 'logout'
                ),
                Route::FILTER_STRICT => true
            )
        ));

        $router[] = new Route('<action>/', array(
            'presenter' => 'Front:Sign',
            'action' => array(
                // řetězec v URL => akce presenteru
                Route::FILTER_TABLE => array(
                    'prihlaseni' => 'frontLogin',
                    'adminsitrace' => 'login',
                    'odhlasit' => 'logout'
                ),
                Route::FILTER_STRICT => true
            )
        ));

        /**
         * Zobrazi kategorii na blogu podle url
         */
        $router[] = new Route('aktuality/kategorie/<url>', 'Front:Article:list');
        $router[] = new Route('aktuality/<url>', 'Front:Article:default');
        $router[] = new Route('aktuality', 'Front:Article:list');

        $router[] = new Route('email/potvrzeni/<token>', 'Front:Email:confirm');

        /**
         * Zobrazi stranku podle url
         */
        $router[] = new Route('[<url>]', 'Front:Page:default');

        return $router;
    }

}
