<?php

/*
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

namespace App\Services;

use Nette\Security\Permission;
use Nette\Security\IAuthorizator;
use App\CoreModule\Model\UserRoleManager;

/**
 * Pomocná služba pro nastavení oprávnění pro jednotlivé role
 * Získá z databáze všechny role, zdroje a akce
 * Podle vazební tabulky sestaví výsledé opravnění pro všechny role
 * Platí pravdilo - vše co je ve vazební tabulce je dovoleno, co v ní není je zakázáno
 * 
 * @package App\Services
 *
 * @author Jan Vodák <jan at ideatech.cz>
 */
class AuthorizatorFactory {
    
    const RESOURCE_ERROR = 'Error';

    /**
     *  @var UserRoleManager Instance třídy modelu pro práci se s uživatelskými rolemi. 
     */
    private $userRoleManager;

    /**
     * AuthorizatorFactory contructor
     * @param UserRoleManager $userRoleManager
     */
    public function __construct(UserRoleManager $userRoleManager) {
        $this->userRoleManager = $userRoleManager;
    }

    /**
     * @return IAuthorizator
     */
    public function create() {
        $permission = new Permission();
        $permission = $this->getResources($permission);
        $permission = $this->gerRoles($permission);

        // Všechny povolené zdroje a jejich povolené akce pro všechny uživatele
        $rolesActions = $this->userRoleManager->getAllRows(UserRoleManager::TABLE_ROLE_NAME . '_' . UserRoleManager::TABLE_ACTION_NAME);
        
        // Nasetování hodnot
        foreach ($rolesActions as $action){
            $roleSlug = $this->userRoleManager->getById(UserRoleManager::TABLE_ROLE_NAME, UserRoleManager::COLUMN_ROLE_ID, $action[UserRoleManager::COLUMN_ROLE_ID])[UserRoleManager::COLUMN_ROLE_SLUG];
            $resourceName = $this->userRoleManager->getById(UserRoleManager::TABLE_NAME_RESOURCE, UserRoleManager::COLUMN_RESOURCE_ID, $action[UserRoleManager::COLUMN_RESOURCE_ID])[UserRoleManager::COLUMN_RESOURCE_NAME];
            $actionName = $this->userRoleManager->getById(UserRoleManager::TABLE_ACTION_NAME, UserRoleManager::COLUMN_ACTION_ID, $action[UserRoleManager::COLUMN_ACTION_ID])[UserRoleManager::COLUMN_ACTION_NAME];
            $permission->allow($roleSlug, $resourceName, $actionName);
        }

        // Roli Super Admin se oprávnění v systému nemění - defaultně má práva na všechno
        $permission->allow(UserRoleManager::ROLE_TYPE_SUPERADMIN, Permission::ALL, Permission::ALL);
        
        return $permission;
    }

    /**
     * getResources - pomocná funkce, která přidá všechny role z db do persmission
     * @param IAuthorizator $permission oprávnění
     * @return IAuthorizator $permission
     */
    private function gerRoles($permission) {
        $roles = $this->userRoleManager->getAllRows(UserRoleManager::TABLE_ROLE_NAME);
        
        foreach ($roles as $role){
            $permission->addRole($role[UserRoleManager::COLUMN_ROLE_SLUG]);
            $permission->allow($role[UserRoleManager::COLUMN_ROLE_SLUG], self::RESOURCE_ERROR);
        }

        return $permission;
    }

    /**
     * getResources - pomocná funkce, která přidá všechny zdroje z db do persmission
     * @param IAuthorizator $permission oprávnění
     * @return IAuthorizator $permission
     */
    private function getResources($permission) {
        $resources = $this->userRoleManager->getAllRows(UserRoleManager::TABLE_NAME_RESOURCE);
        
        foreach ($resources as $resource){
            $permission->addResource($resource[UserRoleManager::COLUMN_RESOURCE_NAME]);
        }
        // Error presenter
        $permission->addResource(self::RESOURCE_ERROR);

        return $permission;
    }

}
