<?php

use \Step\Acceptance\AdminLogin as AdminTester;

class MainSettingsCest {

    /**
     * Try if user logs page is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function userLogsTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if user activity logs page is working');
        $I->loginAsAdmin();
        $I->wait(2);
        $I->amOnPage('/administrace/nastaveni/uzivatelske-logy/');
        $I->wait(2);
        $I->see('Logování uživatelských', '.header');

        // User login log
        $I->wantTo('try if user log logs page is working');
        $I->click('#userLogs');
        $I->wait(2);
        $I->see('Logování uživatelských loginů', '.header');
    }

    /**
     * Try if create new role with no information filled in form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function createRoleNoFilTest(AdminTester $I) {
        $I->wantTo('try if create new role with no information filled in form is working');
        $I->wait(2);
        $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
        $I->wait(2);
        $I->click('.datagrid-settings');
        $I->wait(1);
        $I->click('inline_add[submit]');
        $I->wait(2);
        $I->see('Nebyly vyplněny všechny potřebné údaje pro uložení.', '.alert-danger');
    }

    /**
     * Try if create new role is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function createRoleTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if create new role is working');
        $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
        $I->wait(2);
        $I->click('.datagrid-settings');
        $I->wait(1);
        $I->fillField('#frm-userRoleDatagrid-dataGrid-filter-inline_add-role_name', 'Pokusná role');
        $I->fillField('#frm-userRoleDatagrid-dataGrid-filter-inline_add-role_slug', 'pokusrole');
        $I->fillField('#frm-userRoleDatagrid-dataGrid-filter-inline_add-role_description', 'Atutomatický test, jestli lze vytvořit roli.');
        $I->click('inline_add[submit]');
        $I->wait(2);
        $I->see('Byla úspěšně přidána nová role Pokusná role.', '.alert-success');
    }

    /**
     * Try if edit role is working
     * @param  AdminTester $I
     * @return boolean
     */
    /*
      public function editRoleTest(AdminTester $I) {
      // New settings
      $I->wantTo('try if edit role is working');
      $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
      $I->wait(2);
      $I->click('#snippet-userRoleDatagrid-dataGrid-table tbody tr:nth-last-child(2) td:last-child a.datagrid-inline-edit-trigger');
      $I->wait(1);
      $I->fillField('#frm-userRoleDatagrid-dataGrid-filter-inline_edit-role_description', 'Atutomatický test, zda se dá role upravit.');
      $I->wait(1);
      $I->click('inline_add[submit]');
      $I->wait(2);
      $I->see('byla úspěšně upravena.', '.alert-success');
      }
     */

    /**
     * Try if set role persmission is working
     * @param  AdminTester $I
     * @return boolean
     * @depends createRoleTest
     */
    public function setRolePermissionTest(AdminTester $I) {
        $I->wantTo('try if set role persmission is working');
        $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
        $I->wait(2);
        $I->click('#snippet-userRoleDatagrid-dataGrid-table tbody tr:nth-last-child(2) td:last-child a.btn-primary');
        $I->wait(1);
        $I->click('#frm-permissionForm-permissionForm a:first-child');
        $I->wait(1);
        $I->click('.slider');
        $I->wait(1);
        $I->click('_submit');
        $I->wait(2);
        $I->see('byla úspěšně upravena.', '.alert-success');
    }
    
    /**
     * Try if delete role with permission is working
     * @param  AdminTester $I
     * @return boolean
     * @depends setRolePermissionTest
     */
    public function deleteRoleWithPermissionTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete role with permission is working');
        $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
        $I->wait(2);
        $I->click('#snippet-userRoleDatagrid-dataGrid-table tbody tr:nth-last-child(2) td:last-child a.btn-danger');
        $I->wait(1);
        $I->acceptPopup();
        $I->wait(2);
        $I->see('Pro smazání role je potřeba nejprve odstranit všechny její povolená oprávnění.', '.alert-danger');
    }

    /**
     * Try if unset role persmission is working
     * @param  AdminTester $I
     * @return boolean
     * @depends setRolePermissionTest
     */
    public function unsetRolePermissionTest(AdminTester $I) {
        $I->wantTo('try if unset role persmission is working');
        $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
        $I->wait(2);
        $I->click('#snippet-userRoleDatagrid-dataGrid-table tbody tr:nth-last-child(2) td:last-child a.btn-primary');
        $I->wait(1);
        $I->click('#frm-permissionForm-permissionForm a:first-child');
        $I->wait(1);
        $I->click('.slider');
        $I->wait(1);
        $I->click('_submit');
        $I->wait(2);
        $I->see('byla úspěšně upravena.', '.alert-success');
    }

    /**
     * Try if delete role is working
     * @param  AdminTester $I
     * @return boolean
     * @depends createRoleTest
     */
    public function deleteRoleTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete role is working');
        $I->amOnPage('/administrace/nastaveni/uzivatelske-role/');
        $I->wait(2);
        $I->click('#snippet-userRoleDatagrid-dataGrid-table tbody tr:nth-last-child(2) td:last-child a.btn-danger');
        $I->wait(1);
        $I->acceptPopup();
        $I->wait(2);
        $I->see('byla úspěšně smazána.', '.alert-success');
    }

    /**
     * Try if create new module with no information filled in form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function createModuleNoFillTest(AdminTester $I) {
        $I->wantTo('try if create new module with no information filled in form is working');
        $I->wait(2);
        $I->amOnPage('/administrace/nastaveni/moduly/');
        $I->wait(2);
        $I->click('.datagrid-settings');
        $I->wait(1);
        $I->click('inline_add[submit]');
        $I->wait(2);
        $I->see('Nebyly vyplněny všechny potřebné údaje pro uložení.', '.alert-danger');
    }

    /**
     * Try if edit modul activity is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function editModuleActivityTest(AdminTester $I) {
        // New settings
        $I->wantTo('try if edit modul activity is working');
        $I->wait(2);
        $I->amOnPage('/administrace/nastaveni/moduly/');
        $I->wait(2);
        $I->click('#snippet-moduleDatagrid-dataGrid-table tbody tr:nth-last-child(2) button');
        $I->wait(1);
        $I->click('#snippet-moduleDatagrid-dataGrid-table tbody tr:nth-last-child(2) .open ul li:last-child a');
        $I->wait(2);
        $I->see('byl úspěšně upraven.', '.alert-success');

        // Back to default settings
        $I->wantTo('set modul activity back to default setting');
        $I->click('#snippet-moduleDatagrid-dataGrid-table tbody tr:nth-last-child(2) button');
        $I->wait(1);
        $I->click('#snippet-moduleDatagrid-dataGrid-table tbody tr:nth-last-child(2) .open ul li:first-child a');
        $I->wait(2);
        $I->see('byl úspěšně upraven.', '.alert-success');
    }

    /**
     * Try if edit module is working
     * @param  AdminTester $I
     * @return boolean
     */
    /*
      public function editModuleTest(AdminTester $I) {
      // New settings
      $I->wantTo('try if edit module is working');
      $I->amOnPage('/administrace/nastaveni/moduly/');
      $I->wait(2);
      $I->click('#snippet-moduleDatagrid-dataGrid-table tbody tr:nth-last-child(2) td:last-child a.datagrid-inline-edit-trigger');
      $I->wait(1);
      $I->fillField('#frm-moduleDatagrid-dataGrid-filter-inline_edit-name', 'Media modul test upravy');
      $I->wait(2);
      $I->click('.btn-primary');
      $I->wait(2);
      $I->see('byla úspěšně upravena.', '.alert-success');
      }
     */
}
