<?php

use \Step\Acceptance\AdminLogin as AdminTester;

class EshopSettinsCest {

    /**
     * Try if create settings form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function createSettingsTest(AdminTester $I) {
        $I->wantTo('try if create settings form is working');
        $I->loginAsAdmin();
        $I->wait(2);
        $I->amOnPage('/administrace/eshop/nastaveni/ucetni-nastaveni/');
        $I->wait(1);
        $I->fillField('valid_from', date("d.m.Y"));
        $I->fillField('valid_to', Date('d.m.Y', strtotime("+7 days")));
        $I->click('add');
        $I->wait(2);
        $I->see('Nastavení bylo přidáno', '.alert-success');
    }

    /**
     * Try if delete settings form is working
     * @param  AdminTester $I
     * @return boolean
     * @depends createSettingsTest
     */
    public function deleteSettingsTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete settings form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/ucetni-nastaveni/');
        $I->wait(1);
        $I->click('.table tbody tr:nth-child(2) td:last-child a.btn-danger');
        $I->wait(1);
        //$I->acceptPopup();
        $I->wait(2);
        $I->see('Nastavení bylo úspěšně odstraněno', '.alert-success');
    }

    /**
     * Try if seller settings form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function sellerSettingsTest(AdminTester $I) {
        $I->wantTo('try if seller settings form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/udaje-prodejce');
        $I->wait(1);
        $I->click('send');
        $I->wait(2);
        $I->see('Osoba byla úspěšně uložena', '.alert-success');
    }

    /**
     * Try if order transport form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function trasponrtMethodFormTest(AdminTester $I) {
        $I->wantTo('try if order transport form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/zpusob-dopravy/');
        $I->wait(1);
        $I->fillField('shipping_name', 'Pokusná doprava');
        $I->click('_submit');
        $I->wait(2);
        $I->see('byla úspěšně uložena', '.alert-success');
    }
    
    /**
     * Try if delete order transport method form is working
     * @param  AdminTester $I
     * @return boolean
     * @depends trasponrtMethodFormTest
     */
    public function deleteOrderTransportMethodTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete order transport method form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/zpusob-dopravy/');
        $I->wait(1);
        $I->click('.table tbody tr:last-child td:last-child a.btn-danger');
        $I->wait(1);
        //$I->acceptPopup();
        $I->wait(2);
        $I->see('byla smazána', '.alert-success');
    }
    
    /**
     * Try if order payment form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function paymentMethodFormTest(AdminTester $I) {
        $I->wantTo('try if order payment form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/metody-platby/');
        $I->wait(1);
        $I->fillField('payment_name', 'Pokusná platba');
        $I->click('_submit');
        $I->wait(2);
        $I->see('byla úspěšně uložena', '.alert-success');
    }
    
    /**
     * Try if delete order payment method form is working
     * @param  AdminTester $I
     * @return boolean
     * @depends paymentMethodFormTest
     */
    public function deleteOrderPaymentMethodTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete order payment method form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/metody-platby/');
        $I->wait(1);
        $I->click('.table tbody tr:last-child td:last-child a.btn-danger');
        $I->wait(1);
        //$I->acceptPopup();
        $I->wait(2);
        $I->see('byla smazána', '.alert-success');
    }
    
    /**
     * Try if user discount form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function userSalesFormTest(AdminTester $I) {
        $I->wantTo('try if user discount form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/slevove-hladiny/uzivatelske-slevy');
        $I->wait(1);
        $I->fillField('discount', '0');
        $I->fillField('price', '10000');
        $I->click('_submit');
        $I->wait(2);
        $I->see('Sleva byla úspěšně uložena.', '.alert-success');
    }
    
    /**
     * Try if delete user discount form is working
     * @param  AdminTester $I
     * @return boolean
     * @depends userSalesFormTest
     */
    public function deleteUserDiscoutMethodTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete user discount form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/slevove-hladiny/uzivatelske-slevy');
        $I->wait(1);
        $I->click('.table tbody tr:nth-child(2) td:last-child a.btn-danger');
        $I->wait(1);
        //$I->acceptPopup();
        $I->wait(2);
        $I->see('Sleva byla smazána', '.alert-success');
    }
    
    /**
     * Try if coupone discount form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function couponeSalesFormTest(AdminTester $I) {
        $I->wantTo('try if coupone discount form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/slevove-hladiny/kupony');
        $I->wait(1);
        $I->fillField('discount', '0');
        $I->fillField('coupon_code', 'automatTestCoupone');
        $I->fillField('coupon_code', 'automatTestCoupone');
        $I->click('_submit');
        $I->wait(2);
        $I->see('Sleva byla úspěšně uložena.', '.alert-success');
    }
    
    /**
     * Try if delete coupone discount form is working
     * @param  AdminTes'ter $I
     * @return boolean
     * @depends userSalesFormTest
     */
    public function deleteCouponeDiscoutMethodTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete coupone discount form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/slevove-hladiny/kupony');
        $I->wait(1);
        $I->click('.table tbody tr:nth-child(2) td:last-child a.btn-danger');
        $I->wait(1);
        //$I->acceptPopup();
        $I->wait(2);
        $I->see('Sleva byla smazána', '.alert-success');
    }
    
    /**
     * Try if default currency form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function defaultCurrencyFormTest(AdminTester $I) {
        $I->wantTo('try if default currency form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/kuryz-men');
        $I->wait(1);
        $I->click('#defaultCurrencySubmit');
        $I->wait(2);
        $I->see('byla úspěšně nastavena jako hlavní', '.alert-success');
    }
    
    /**
     * Try if default currency form is working
     * @param  AdminTester $I
     * @return boolean
     */
    public function newCurrencyFormTest(AdminTester $I) {
        $I->wantTo('try if new currency form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/kuryz-men');
        $I->wait(1);
        $I->fillField('currency_name', 'Testovací měna');
        $I->fillField('currency_code', 'TST');
        $I->fillField('currency_symbol', 'T');
        $I->click('#currencySubmit');
        $I->wait(2);
        $I->see('byla úspěšně uložena', '.alert-success');
    }
    
    /**
     * Try if delete currency form is working
     * @param  AdminTes'ter $I
     * @return boolean
     * @depends newCurrencyFormTest
     */
    public function deleteCurrencyTest(AdminTester $I) {
        // User activity log
        $I->wantTo('try if delete currency form is working');
        $I->amOnPage('/administrace/eshop/nastaveni/kuryz-men');
        $I->wait(1);
        $I->click('.table tbody tr:last-child td:last-child a.btn-danger');
        $I->wait(1);
        //$I->acceptPopup();
        $I->wait(2);
        $I->see('byla smazána', '.alert-success');
    }

}
