<?php

use Step\Acceptance\FrontLogin as FrontTester;

class LoggedUserActionsCest {
    
    
     /**
     * Try if user front log in with wrong password is working
     * @param  FrontTester $I
     * @return boolean
     */
    public function frontLoginBadPasswordTest(FrontTester $I) {
        $I->wantTo('try if user front log in with wrong password is working');
        $I->wrongPassword();
        $I->wait(2);
        $I->see('Zadané heslo není správně.', '.alert-danger');
    }

    /**
     * Try if front login is working
     * @param  FrontTester $I
     * @return boolean
     */
    public function frontLoginTest(FrontTester $I) {
        $I->wantTo('try if front login is working');
        $I->frontLogin();
        $I->wait(2);
        $I->see('Byl jste úspěšně přihlášen.', '.alert-success');
    }

    /**
     * Try if user has access to register accont if is logged in
     * @param  AdminTester $I
     * @return boolean
     */
    public function registerUserAccess(AcceptanceTester $I) {
        $I->wantTo('try if user has access to register accont if is logged in');
        $I->amOnPage('/osoby/registrace-uctu/');
        $I->wait(2);
        $I->see('Uživatel nemůže být přihlášen a zároveň vidět formulář s povinnou registrací.', '.alert-danger');
    }
    
    /**
     * Try if user has access to register accont in order if is logged in
     * @param  AdminTester $I
     * @return boolean
     */
    public function registerUserInOrderAccess(AcceptanceTester $I) {
        $I->wantTo('try if user has access to register accont in order if is logged in');
        $I->amOnPage('/osoby/registrace/');
        $I->wait(2);
        $I->see('Uživatel nemůže být přihlášen a zároveň vidět formulář s povinnou registrací.', '.alert-danger');
    }

    /**
     * Try if user change detail is working
     * @param FrontTester $I
     * @return boolean
     */
    public function changeUserDetailTest(FrontTester $I) {
        $I->wantTo('try if user change detail is working');
        $I->amOnPage('/osoby/sprava');
        $I->wait(1);
        $I->click('#changeUserDetailSubmit');
        $I->wait(2);
        $I->see('Osoba byla úspěšně uložena.', '.alert-success');
    }

    /**
     * Try if user change detail is working
     * @param FrontTester $I
     * @return boolean
     */
    public function changeUserPasswordTest(FrontTester $I) {
        $I->wantTo('try if change user password is working');
        $I->amOnPage('/osoby/zmena-hesla');
        $I->fillField('old_password', 'testheslo');
        $I->fillField('password', 'testheslo');
        $I->fillField('password_repeat', 'testheslo');
        $I->click('#changeUserPasswordSubmit');
        $I->wait(2);
        $I->see('Heslo bylo úspěšně změněno', '.alert-success');
    }

    /**
     * Try if product review is working
     * @param FrontTester $I
     * @return boolean
     */
    public function productReviewTest(FrontTester $I) {
        $I->wantTo('try if product review is working');
        $I->amOnPage('/produkty/detail/komplexni-webove-administracni-rozhrani');
        $I->wait(2);
        $I->click('#write-review');
        $I->wait(1);
        $I->fillField('#frm-productDetail-reviewForm-reviewForm-content', 'Testovací reference pro produkt.');
        $I->click('#productReviewSubmit');
        $I->wait(2);
        $I->see('Tento produkt jsi již hodnotil.', '.alert-danger');
    }

    /**
     * Try if front logout is working
     * @param FrontTester $I
     * @return boolean
     */
    public function frontLogoutTest(FrontTester $I) {
        $I->wantTo('try if front logout is working');
        $I->frontLogout();
        $I->wait(2);
        $I->see('Byl jste úspěšně odhlášen.', '.alert-success');
    }

}
