<?php

use Step\Acceptance\Product as ProductTester;

class OrderProcessCest {

    /**
     * Try if add product to cart is working
     * @param  ProductTester $I
     * @return boolean
     */
    public function addProcutToCartTest(ProductTester $I) {
        $I->wantTo('try if add product to cart is working');
        $I->addProcutToCart();
        $I->wait(1);
        $I->see('Přidali jste do košíku', '#add-cart-modal');
    }

    /**
     * Try if coupone form is working
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function couponeTest(ProductTester $I) {
        $I->wantTo('try if order process is working');
        $I->amOnPage('/kosik');
        $I->fillField('#frm-cartManagementForm-cartManagementForm-coupon_code', 'slevovyKupon');
        $I->click('useCoupone');
        $I->wait(2);
        $I->see('Kupón byl přičten k Vaší objednávce', '.alert-success');
    }

    /**
     * Try if cart submit form is working
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function cartSubmitTest(ProductTester $I) {
        // Submit cart to another part
        $I->wantTo('try if submit order cart is working');
        $I->amOnPage('/kosik');
        $I->wait(1);
        $I->click('checkout');
        $I->wait(1);
        $I->see('Profil', '#registration-form');
    }

    /**
     * Try if user detail form is working
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function userDetailTest(ProductTester $I) {
        // User detail
        $I->wantTo('try if order registration is working');
        $I->amOnPage('/osoby/registrace/');
        $I->wait(1);
        $I->fillField('#frm-personForm-personForm-person_detail-email', 'test@test.cz');
        $I->fillField('#frm-personForm-personForm-person_detail-first_name', 'Test jmeno');
        $I->fillField('#frm-personForm-personForm-person_detail-last_name', 'Test prijmeni');
        $I->fillField('#frm-personForm-personForm-address-street', 'Testovaci ulice');
        $I->fillField('#frm-personForm-personForm-address-city', 'Testovaci mesto');
        $I->fillField('#frm-personForm-personForm-address-zip', '12345');
        $I->fillField('#frm-personForm-personForm-address-registry_number', '4');
        $I->click('register');
        $I->wait(1);
        $I->see('Způsob dopravy', '#order-methods');
    }

    /**
     * Try if user have access to order summary if not set order methods
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function orderSummaryAccessTest(ProductTester $I) {
        // Order methods
        $I->wantTo('try if user have access to order summary if not set order methods');
        $I->amOnPage('/kosik/summary');
        $I->wait(2);
        $I->see('Vyberte prosím způsob dopravy', '.alert-danger');
    }

    /**
     * Try if select order methods is working'
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function orderMethodsTest(ProductTester $I) {
        // Order methods
        $I->wantTo('try if select order methods is working');
        $I->amOnPage('/kosik/payment');
        $I->wait(1);
        $I->click('#orderMethodsSubmit');
        $I->wait(1);
        $I->see('Rekapitulace objednávky', '.container');
    }
    
    /**
     * Try if confirm order in order summary is working without agreements
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function cofinrmOrderWithoutAgreementsTest(ProductTester $I) {
        $I->wantTo('try if confirm order in order summary is working without agreements');
        $I->amOnPage('/kosik/summary');
        $I->wait(1);
        $I->click('#completeOrder');
        $I->wait(2);
        $I->seeInPopup('Musíte souhlasit s obchodními podmínkami');
        $I->acceptPopup();
    }

    /**
     * Try if order confirm form in order summary is working
     * @param  ProductTester $I
     * @return boolean
     * @depends addProcutToCartTest
     */
    public function cofinrmAgrementsTest(ProductTester $I) {
        // Summary with agree terms
        $I->wantTo('try if confirm order summary with agree terms is working');
        $I->amOnPage('/kosik/summary');
        $I->wait(1);
        $I->click('#agree_terms');
        $I->seeCheckboxIsChecked('#agree_terms');
        $I->wait(1);
        $I->click('#completeOrder');
        $I->wait(5);
        $I->see('A je to!', '#thanks-page');
    }

}
