<?php

namespace Test\Unit\Eshop;

use Tester;
use Tester\Assert;
use Nette\DI\Container;
use App\EshopModule\Model\OrderManager;

$container = require __DIR__ . '/../../bootstrap.php';

/**
 * OrderManagerTest: Basic database query tests for order calculating.
 *
 * @phpVersion >= 7.0
 */
class OrderTest extends Tester\TestCase {

    /**
     * @var Container 
     */
    private $container;

    /**
     * @var OrderManager 
     */
    private $orderManager;

    function __construct(Container $container) {
        $this->container = $container;
    }

    public function setUp() {
        $this->orderManager = $this->container->getByType(OrderManager::class);
    }

    public function tearDown() {
        # Úklid
    }

    /**
     * 
     * @return ArrayHash order summary
     */
    public function getOrderSummary() {
        return array(
            OrderManager::ATTR_PRODUCTS => 1,
            OrderManager::ATTR_PRICE => 25000.0
        );
    }

    public function testCalculateDiscountsFormOrderSum() {
        $order = $this->getOrderSummary();
        // Non-existent order
        Assert::equal(25000.0, $this->orderManager->calculateDiscountsFormOrderSum(0, $order, TRUE)[OrderManager::ATTR_PRICE]);
        // Exist order
        Assert::equal(22500.0, $this->orderManager->calculateDiscountsFormOrderSum(51, $order, TRUE)[OrderManager::ATTR_PRICE]);
    }

    public function testOrderSummary() {
        // None-existent order
        Assert::equal(0, $this->orderManager->getOrderSummary(0)[OrderManager::ATTR_PRICE]);
        // Exist order with all - order methods, discount levels, coupone discount
        Assert::equal(22500.0, $this->orderManager->getOrderSummary(51)[OrderManager::ATTR_PRICE]);
        // Order without order methods - payments and shipping methods prices
        Assert::equal(22500.0, $this->orderManager->getOrderSummary(51, FALSE)[OrderManager::ATTR_PRICE]);
        // Order without order methods and discounts
        Assert::equal(25000.0, $this->orderManager->getOrderSummary(51, FALSE, FALSE)[OrderManager::ATTR_PRICE]);
        // Order without order methods, discounts and coupon discount
        Assert::equal(25000.0, $this->orderManager->getOrderSummary(51, FALSE, FALSE, FALSE)[OrderManager::ATTR_PRICE]);
    }

}

$test = new OrderTest($container);
$test->run();
