<?php

namespace Test\Unit\Eshop;

use Tester;
use Tester\Assert;
use Nette\DI\Container;
use App\EshopModule\Model\CurrencyManager;
use App\EshopModule\Model\DiscountLevelsManager;
use App\EshopModule\Model\SettingsManager;

$container = require __DIR__ . '/../../bootstrap.php';

/**
 * PriceTest: Basic database query tests for price calculating
 *
 * @phpVersion >= 7.0
 */
class PriceTest extends Tester\TestCase {

    /**
     * @var Container 
     */
    private $container;

    /**
     * @var DiscountLevelsManager 
     */
    private $discountManager;

    function __construct(Container $container) {
        $this->container = $container;
    }

    public function setUp() {
        $this->discountManager = $this->container->getByType(DiscountLevelsManager::class);
    }

    public function tearDown() {
        # Úklid
    }

    /**
     * 
     * @return ArrayHash order summary
     */
    public function getCurrency() {
        return array(
            CurrencyManager::COLUMN_EXCHANGE_RATE => 1
        );
    }

    /**
     * 
     * @return array order summary
     */
    public function getSettings() {
        return array(
            SettingsManager::COLUMN_VAT => 21,
            SettingsManager::COLUMN_ACCOUNTANT => 55
        );
    }

    public function testCalculatePrice() {
        $currency = $this->getCurrency();
        $settings = $this->getSettings();
        // Non-existent settings, user, aditional price
        Assert::equal(100.0, $this->discountManager->calculatePrice(100.0, $currency, null, null, null));
        // Non-existent user, aditional price
        Assert::equal(121.0, $this->discountManager->calculatePrice(100.0, $currency, $settings, null, null));
        // Non-existent aditional price
        Assert::equal(121.0, $this->discountManager->calculatePrice(100.0, $currency, $settings, 1, null));
        // Complete price
        Assert::equal(242.0, $this->discountManager->calculatePrice(100.0, $currency, $settings, 1, 100));
    }

}

$test = new PriceTest($container);
$test->run();
