/* 
 * (C) Ideatech.cz
 * 2016
 * https://www.ideatech.cz/
 * Tento kód nesmí být šířen ani používán v open-source projektech.
 */

/**
 * Editor stromového menu
 */
var editors = [];

window.onload = function () {
    CreateTreeEditor();
};

HTMLElement.prototype.destroy = function () {
    this.parentElement.removeChild(this);
};

Array.prototype.remove = function (item) {
    this.splice(this.indexOf(item), 1);
}

/**
 * Vytvoří editory okolo inputu s attributem data-tree-editor
 */
function CreateTreeEditor() {
    var elements = document.querySelectorAll("input[data-tree-editor]");
    for (var i = 0; i < elements.length; i++) {
        editors.push(new TreeEditor(elements[i]));
    }
}

/**
 * Konstruktor editoru stromové struktury
 * @param element div, ve kterém bude vytvořen editor
 * @constructor
 */
function TreeEditor(element) {
    this.output = element;
    this.lastId = 0;
    var self = this;

    this.submit = element.parentElement.parentElement.querySelector("input[type=submit]");
    this.submit.onclick = function () { // obsluha ukládání
        self.exportJson();
    };

    this.rootElement = document.createElement("div");
    this.rootElement.classList.add("tree-menu-editor-root");
    element.parentElement.appendChild(this.rootElement);

    this.root = new TreeNode(null, this, true); // kořenová položka
    this.rootElement.appendChild(this.root.element);

    // načtení dat
    var dataSource = element.getAttribute("data-source");
    if (dataSource) {
        var ajaj = new XMLHttpRequest();
        var self = this;
        ajaj.open("GET", dataSource);
        ajaj.onreadystatechange = function () {
            if (ajaj.status == 200 && ajaj.readyState == 4) {
                self.loadJson(ajaj.responseText);
            } else if (ajaj.readyState == 4) { // neexistující data
                console.error("Data se nepovedlo načíst. Pravděpodobně neexistují nebo server obsluhující data nefunguje. Stavový kód odpovědi:" + ajaj.status);
                self.loadJson("[]");
            }
        };
        ajaj.send();
    }
}

/**
 * Konstruktor uzlu editoru stromové struktury
 * @param parent předek elementu
 * @param editor editor, kterému prvek náleží
 * @param root udává zdali je předek hlavní (root)
 * @constructor
 */
function TreeNode(parent, editor, root) {
    var self = this;

    this.parent = parent;
    this.editor = editor;
    this.hidden = 0;
    this.element;
    this.nodes = [];
    this.ul;
    this.prepareNodeEditor(root);

    this.urlEl;
    this.titleEl;
    this.id;
}

/**
 * Vkládá do sebe položku editoru
 * @param node
 */
TreeNode.prototype.appendNode = function (node) {
    var indexOfFirstHidden = this.indexOfFirstHidden();
    if (indexOfFirstHidden != -1) {
        this.nodes.splice(indexOfFirstHidden, 0, node);
    } else {
        this.nodes.push(node);
    }
    this.ul.appendChild(node.element);
};

TreeNode.prototype.indexOfFirstHidden = function () {
    for (var i = 0; i < this.nodes.length; i++) {
        if (this.nodes[i].element.classList.contains("tree-menu-hidden")) {
            return i;
        }
    }
    return -1;
}

/**
 * Připraví DOM editoru dané položky
 * @param root udává zdali je položka hlavní (root)
 */
TreeNode.prototype.prepareNodeEditor = function (root) {
    // vytváření ovl. prvků
    var header = document.createElement("div");
    header.classList.add("editor-node");
    var title = document.createElement("input");
    var url = document.createElement("input");
    var del = document.createElement("button");
    var addNode = document.createElement("button");

    // nastavení popisku nebo editoru titulku
    if (root) {
        title = document.createElement("label");
        title.textContent = "Editor kategoríí";
        header.appendChild(title);
    } else {
        header.appendChild(title);
        header.appendChild(del);
        header.appendChild(url);
        url.classList.add("tree-menu-url-editor");
    }

    header.appendChild(addNode);
    title.value = "Nová kategorie";
    title.classList.add("tree-menu-title-editor");

    // tlačítko odstranit
    del.classList.add("btn-editor");
    del.classList.add("glyphicon");
    del.classList.add("glyphicon-trash");
    del.classList.add("btn");
    del.classList.add("btn-xs");
    del.classList.add("btn-danger");
    del.setAttribute("type", "button");
    del.node = this;
    del.onclick = this.btnRemoveMeClick;

    // tlačítko přidat
    addNode.classList.add("btn-editor");
    addNode.classList.add("glyphicon");
    addNode.classList.add("glyphicon-plus");
    addNode.classList.add("btn");
    addNode.classList.add("btn-xs");
    addNode.classList.add("btn-default");
    addNode.setAttribute("type", "button");
    addNode.node = this;
    addNode.onclick = this.btnAddNodeClick;

    this.element = document.createElement("li");
    if (this.hidden) { // skrytí skrytých položek
        this.element.classList.add("tree-menu-hidden")
    }
    this.element.appendChild(header);
    this.titleEl = title;
    this.urlEl = url;

    this.ul = document.createElement("ul");
    this.ul.classList.add("nav");
    this.ul.classList.add("nav-list");
    this.ul.classList.add("tree");
    if (root) {
        this.ul.id = 'root';
    }
    this.element.appendChild(this.ul);
};

/**
 * Obsluha tlačítka pro přidání položky
 */
TreeNode.prototype.btnAddNodeClick = function (e) {
    var node = new TreeNode(this.node, this.node.editor, false);
    // nastavení nového volného ID
    if (!node.id) {
        node.id = ++this.node.editor.lastId;
    }
    this.node.appendNode(node);
    e.preventDefault();
};

/**
 * Obsluha odstranění položky
 */
TreeNode.prototype.btnRemoveMeClick = function () {
    this.node.parent.nodes.remove(this.node);
    this.parentElement.parentElement.destroy();
};

/**
 * Vyhledá a vrátí položku podle ID i v podúrovních
 * @param id
 * @returns TreeNode
 */
TreeNode.prototype.findNode = function (id) {
    if (!id) {
        return this;
    }
    if (this.id == id) {
        return this;
    }

    for (var i = 0; i < this.nodes.length; i++) {
        var found = this.nodes[i].findNode(id);
        if (found) {
            return found;
        }
    }

    return null;
};

/**
 * Načte do editoru data ve formátu JSON
 * @param rawData
 */
TreeEditor.prototype.loadJson = function (rawData) {
    var obj = JSON.parse(rawData);

    for (var i = 0; i < obj.length; i++) {
        var parent = this.root.findNode(obj[i].parent_category_id);
        var node = new TreeNode(parent, this, false);
        node.titleEl.value = obj[i].title;
        node.urlEl.value = obj[i].url;
        node.hidden = obj[i].hidden;
        node.id = obj[i].category_id;
        if (node.hidden) {
            node.element.classList.add("tree-menu-hidden");
        }
        if (this.lastId < obj[i].category_id) {
            this.lastId = obj[i].category_id;
        }
        parent.appendNode(node);
    }
};

/**
 * Vytvoří JSON položky
 * @param output kolekce, do které má přidat položka přidat sebe a rekurzivně zavolat to stejné na podpoložkách
 */
TreeNode.prototype.getJson = function (output) {
    var obj = {
        category_id: this.id,
        title: this.titleEl.value,
        url: this.urlEl.value,
        parent_category_id: this.parent ? this.parent.id : null,
        order_no: output.length + 1,
        hidden: this.hidden
    };
    output.push(obj);
    for (var i = 0; i < this.nodes.length; i++) {
        this.nodes[i].getJson(output);
    }
};

/**
 * Vygeneruje JSON a uloží jej do políčka input ve formuláři
 */
TreeEditor.prototype.exportJson = function () {
    var output = [];
    this.root.getJson(output);
    output.shift();
    this.output.value = JSON.stringify(output);
};